@@ -22,7 +22,7 @@
 AlcoholTool::AlcoholTool(QWidget* parent)
     : QDialog(parent)
 {
-    setWindowTitle(Resource::TITLE + " - Alcohol Tool");
+    setWindowTitle(Resource::TITLE + tr(" - Alcohol Tool"));
 
     ui.setupUi(this);
 
