@@ -34,10 +34,15 @@
 #define CONFIGSTATE_H
 
 #include <QStringList>
+#include "hop.h"
 #include "resource.h"
 
 struct WinConfigState {
-    WinConfigState() : statusbar(false) { ; }
+#if defined (Q_WS_MAC)
+   WinConfigState() : statusbar(true) { ; }
+#else
+   WinConfigState() : statusbar(false) { ; }
+#endif
     bool statusbar;
 };
 
@@ -57,18 +62,17 @@ struct GenConfigState {
 
 struct RecipeConfigState {
     RecipeConfigState()
-        : batch(5.00), style("Generic Ale"), hopform("Pellet"),
-         mash(false) { ; }
+        : batch(5.00), style("Generic Ale"), hoptype(Hop::PELLET_STRING) { ; }
     double batch;
     QString style;
-    QString hopform;
-    bool mash;
+    QString hoptype;
 };
 
 struct CalcConfigState {
     CalcConfigState()
-        : efficiency(0.75), morey(false), tinseth(false),
-         units(Resource::UNIT_US) { ; }
+        : steepyield(0.5), efficiency(0.75), morey(false), tinseth(false),
+          units(Resource::UNIT_US) { ; }
+    double steepyield;
     double efficiency;
     bool morey;
     bool tinseth;
