@@ -7,7 +7,7 @@
   Please see the header file for copyright and licehnse information
  ***************************************************************************/
 
-#include <QPushButton>
+#include <QDialogButtonBox>
 #include <QStyleFactory>
 
 #include "configure.h"
@@ -30,36 +30,36 @@ enum {
 Configure::Configure(QWidget* parent)
     : QDialog(parent), calc_(0), general_(0), recipe_(0)
 {
-    setWindowTitle(TITLE + " - Configure");
+    setWindowTitle(TITLE + tr(" - Configure"));
 
     // tab widget
     tabwidget_ = new QTabWidget(this);
 
     // buttons
-    QPushButton *okbutton = new QPushButton("&OK");
-    QPushButton *applybutton = new QPushButton("&Apply");
-    QPushButton *cancelbutton = new QPushButton("&Cancel");
-    QPushButton *defaultsbutton = new QPushButton("&Defaults");
-    okbutton->setAutoDefault(true);
+    buttonbox_ = new QDialogButtonBox(Qt::Horizontal, this);
+    buttonbox_->addButton(QDialogButtonBox::Ok);
+    buttonbox_->addButton(QDialogButtonBox::Cancel);
+    buttonbox_->addButton(QDialogButtonBox::Apply);
+    buttonbox_->addButton(QDialogButtonBox::Reset);
 
-    connect(okbutton, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(cancelbutton, SIGNAL(clicked()), this, SLOT(reject()));
-    connect(applybutton, SIGNAL(clicked()), this, SLOT(slotApply()));
-    connect(defaultsbutton, SIGNAL(clicked()), this, SLOT(slotDefault()));
+    connect(buttonbox_, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonbox_, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonbox_, SIGNAL(clicked(QAbstractButton*)),
+            this, SLOT(slotClicked(QAbstractButton*)));
 
     // pages
     QWidget *page = new QWidget();
     general_ = new Ui::GeneralConfig();
     general_->setupUi(page);
-    tabwidget_->insertTab(GENERAL_PAGE, page, "&General");
+    tabwidget_->insertTab(GENERAL_PAGE, page, tr("&General"));
     page = new QWidget();
     calc_ = new Ui::CalcConfig();
     calc_->setupUi(page);
-    tabwidget_->insertTab(CALC_PAGE, page, "&Calculations");
+    tabwidget_->insertTab(CALC_PAGE, page, tr("&Calculations"));
     page = new QWidget();
     recipe_ = new Ui::RecipeConfig();
     recipe_->setupUi(page);
-    tabwidget_->insertTab(RECIPE_PAGE, page, "&Recipe");
+    tabwidget_->insertTab(RECIPE_PAGE, page, tr("&Recipe"));
 
     // additional setup
     recipe_->batch->
@@ -67,17 +67,9 @@ Configure::Configure(QWidget* parent)
     connect(calc_->units, SIGNAL(activated(const QString&)),
             this, SLOT(convertBatchSpin(const QString&)));
 
-    // layout
-    QHBoxLayout *buttonlayout = new QHBoxLayout();
-    buttonlayout->addStretch(1);
-    buttonlayout->addWidget(okbutton);
-    buttonlayout->addWidget(defaultsbutton);
-    buttonlayout->addWidget(applybutton);
-    buttonlayout->addWidget(cancelbutton);
-
     QVBoxLayout *mainlayout = new QVBoxLayout();
     mainlayout->addWidget(tabwidget_);
-    mainlayout->addLayout(buttonlayout);
+    mainlayout->addWidget(buttonbox_);
     setLayout(mainlayout);
 }
 
@@ -139,6 +131,7 @@ void Configure::setGeneralState(const GenConfigState &state)
 void Configure::setCalcState(const CalcConfigState &state)
 {
     if (calc_) {
+        calc_->steepyield->setValue(state.steepyield);
         calc_->efficiency->setValue(state.efficiency);
         calc_->morey->setChecked(state.morey);
         calc_->tinseth->setChecked(state.tinseth);
@@ -167,9 +160,8 @@ void Configure::setRecipeState(const RecipeConfigState &state)
         recipe_->batch->setValue(state.batch);
         recipe_->stylebox->clear();
         recipe_->stylebox->addItems(Data::instance()->stylesList());
-        recipe_->hopform->clear();
-        recipe_->hopform->addItems(Data::instance()->formsList());
-        recipe_->mash->setChecked(state.mash);
+        recipe_->hoptype->clear();
+        recipe_->hoptype->addItems(Hop::typeStringList());
 
         // set combo for style string
         int index = recipe_->stylebox->findText(state.style, Qt::MatchExactly);
@@ -178,12 +170,12 @@ void Configure::setRecipeState(const RecipeConfigState &state)
         } else {
             recipe_->stylebox->addItem(state.style);
         }
-        // set combo for hopform string
-        index =  recipe_->hopform->findText(state.hopform, Qt::MatchExactly);
+        // set combo for hoptype string
+        index =  recipe_->hoptype->findText(state.hoptype, Qt::MatchExactly);
         if (index >= 0) {
-            recipe_->hopform->setCurrentIndex(index);
+            recipe_->hoptype->setCurrentIndex(index);
         } else {
-            recipe_->hopform->addItem(state.hopform);
+            recipe_->hoptype->addItem(state.hoptype);
         }
     }
 }
@@ -192,24 +184,43 @@ void Configure::setRecipeState(const RecipeConfigState &state)
 // Slots                                                                    //
 //////////////////////////////////////////////////////////////////////////////
 
+//////////////////////////////////////////////////////////////////////////////
+// clicked()
+// ---------
+// QDialogButtonBox clicked
+
+void Configure::slotClicked(QAbstractButton *button)
+{
+    switch (buttonbox_->buttonRole(button)) {
+      case QDialogButtonBox::ApplyRole:
+          apply();
+          break;
+      case QDialogButtonBox::ResetRole:
+          defaults();
+          break;
+      default:
+          break;
+    }
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // accept()
 // --------
-// OK button was pressed (QTabDialog doesn't have accept signal)
+// OK button was pressed
 
 void Configure::accept()
 {
-    slotApply();
+    apply();
     QDialog::accept();
     emit configureAccept();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotDefault()
-// -------------
+// defauls()
+// ---------
 // Set dialog to default values
 
-void Configure::slotDefault()
+void Configure::defaults()
 {
     // only default the current page
     switch (tabwidget_->currentIndex()) {
@@ -223,11 +234,11 @@ void Configure::slotDefault()
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotApply()
-// -----------
+// apply()
+// -------
 // Apply values
 
-void Configure::slotApply()
+void Configure::apply()
 {
     if (general_) {
         // general page
@@ -243,6 +254,7 @@ void Configure::slotApply()
 
     if (calc_) {
         // calc page
+        state_.calc.steepyield = calc_->steepyield->value();
         state_.calc.efficiency = calc_->efficiency->value();
         state_.calc.morey = calc_->morey->isChecked();
         state_.calc.tinseth = calc_->tinseth->isChecked();
@@ -254,8 +266,7 @@ void Configure::slotApply()
         // recipe page
         state_.recipe.batch = recipe_->batch->value();
         state_.recipe.style = recipe_->stylebox->currentText();
-        state_.recipe.hopform = recipe_->hopform->currentText();
-        state_.recipe.mash = recipe_->mash->isChecked();
+        state_.recipe.hoptype = recipe_->hoptype->currentText();
         emit recipeApply(state_.recipe);
     }
 }
