@@ -39,6 +39,7 @@
 #include "ui_recipeconfig.h"
 #include "configstate.h"
 
+class QDialogButtonBox;
 class QTabWidget;
 
 class Configure : public QDialog
@@ -66,17 +67,19 @@ private:
     void setCalcState(const CalcConfigState &state);
     void setGeneralState(const GenConfigState &state);
     void setRecipeState(const RecipeConfigState &state);
+    void defaults();
+    void apply();
 
 private slots:
     // standard modeless dialog slots
     void accept();
-    void slotDefault();
-    void slotApply();
+    void slotClicked(QAbstractButton *button);
     // convert the batch size when units have changed
     void convertBatchSpin(const QString &selection);
 
 private:
     QTabWidget *tabwidget_;
+    QDialogButtonBox *buttonbox_;
     Ui::CalcConfig *calc_;
     Ui::GeneralConfig *general_;
     Ui::RecipeConfig *recipe_;
