@@ -30,10 +30,10 @@ static QMutex instancelock;
 // Private constructor
 Data::Data()
     : defaultsize_(Volume(5.0, Volume::gallon)), defaultstyle_(),
-      defaultmash_(false), defaulthopform_(HOP_PELLET),
-      defaultgrainunit_(&Weight::pound), defaulthopunit_(&Weight::ounce),
-      defaultmiscunit_(&Quantity::generic), grainmap_(), hopmap_(), miscmap_(),
-      stylemap_(), utable_(), efficiency_(0.75), tinseth_(true), morey_(true)
+      defaulthoptype_(Hop::PELLET_STRING), defaultgrainunit_(&Weight::pound),
+      defaulthopunit_(&Weight::ounce),  defaultmiscunit_(&Quantity::generic),
+      grainmap_(), hopmap_(), miscmap_(), stylemap_(), utable_(),
+      steepyield_(0.5), efficiency_(0.75), tinseth_(true), morey_(true)
 { ; }
 
 // Private destructor
@@ -57,22 +57,24 @@ void Data::initialize(const ConfigState &state)
         setDefaultSize(Volume(state.recipe.batch, Volume::liter));
         setDefaultGrainUnit(Weight::kilogram);
         setDefaultHopUnit(Weight::gram);
+        setDefaultTempUnit(Temperature::celsius);
     } else if (state.calc.units == UNIT_US) {
         setDefaultSize(Volume(state.recipe.batch, Volume::gallon));
         setDefaultGrainUnit(Weight::pound);
         setDefaultHopUnit(Weight::ounce);
+        setDefaultTempUnit(Temperature::fahrenheit);
     }
     setDefaultStyle(state.recipe.style);
-    setDefaultMash(state.recipe.mash);
-    setDefaultHopForm(state.recipe.hopform);
+    setDefaultHopType(state.recipe.hoptype);
     setDefaultMiscUnit(Quantity::generic);
+    setEfficiency(state.calc.efficiency);
 
     // load data file - try user home directory first, quietly...
     if (!loadData(QDIR_HOME + "/." + DATA_FILE, true)) {
         // then try the default data file
         if (!loadData(QBrew::instance()->dataBase() + DATA_FILE)) {
-            qWarning("Warning: could not open data file");
-            QMessageBox::warning(0, TITLE, QString("Could not open data file"));
+            qWarning() << "Warning: could not open data file";
+            QMessageBox::warning(0, TITLE, QObject::tr("Could not open data file"));
         }
     }
 }
@@ -86,26 +88,6 @@ void Data::setDefaultStyle(const QString &style)
     if (stylemap_.contains(style)) defaultstyle_ = stylemap_.value(style);
 }
 
-//////////////////////////////////////////////////////////////////////////////
-// formsList()
-// ----------
-// Return string list of available hop forms
-
-QStringList Data::formsList()
-{
-    QStringList list;
-    list << HOP_PELLET << HOP_PLUG << HOP_WHOLE;
-
-    // search through existing hopdb for other forms
-    foreach(Hop hop, hopmap_) {
-        if ((!hop.form().isEmpty()) && (!list.contains(hop.form())))
-            list += hop.form();
-    }
-
-    list.sort();
-    return list;
-}
-
 //////////////////////////////////////////////////////////////////////////////
 // style()
 // -------
@@ -140,7 +122,7 @@ Hop Data::hop(const QString &name)
     Hop hop;
     if (hopmap_.contains(name)) hop = hopmap_.value(name);
     hop.setWeight(Weight(1.0, *defaulthopunit_));
-    hop.setForm(defaulthopform_);
+    hop.setType(defaulthoptype_);
     return hop;
 }
 
@@ -205,9 +187,9 @@ bool Data::loadData(const QString &filename, bool quiet)
     if (!datafile.open(QFile::ReadOnly | QFile::Text)) {
         // error opening file
         if (!quiet) {
-            qWarning("Error: Cannot open %s", qPrintable(filename));
+            qWarning() << "Error: Cannot read" << filename;
             QMessageBox::warning(0, TITLE,
-                                 QString("Cannot read file %1:\n%2")
+                                 QObject::tr("Cannot read file %1:\n%2")
                                  .arg(filename)
                                  .arg(datafile.errorString()));
         }
@@ -226,9 +208,9 @@ bool Data::loadData(const QString &filename, bool quiet)
     QDomElement root = doc.documentElement();
     if (root.tagName() != tagDoc) {
         // wrong file type
-        qWarning("Error: Wrong file type %s", qPrintable(filename));
+        qWarning() << "Error: Wrong file type" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Wrong file type for %1").arg(filename));
+                             QObject::tr("Wrong file type for %1").arg(filename));
         QApplication::restoreOverrideCursor();
         return false;
     }
@@ -236,120 +218,97 @@ bool Data::loadData(const QString &filename, bool quiet)
     // check file version
     if (root.attribute(attrVersion) < DATA_PREVIOUS) {
         // too old of a version
-        qWarning("Error: Unsupported version %s", qPrintable(filename));
-        QMessageBox::warning(0, TITLE,
-                             QString("Unsupported version %1").arg(filename));
+        qWarning() << "Error: Unsupported version" << filename;
+        QMessageBox::warning(0, TITLE, QObject::tr("Unsupported version %1")
+                                       .arg(filename));
         QApplication::restoreOverrideCursor();
         return false;
     }
 
-    QDomNodeList nodes, subnodes;
-    QDomElement element, subelement;
-    int n, m;
+    QDomNodeList nodes;
+    QDomElement element, sub;
 
     // get all styles tags
     stylemap_.clear();
-    nodes = root.elementsByTagName(tagStyles);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all style tags
-            subnodes = element.elementsByTagName(tagStyle);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    stylemap_.insert(subelement.text(), Style(subelement.text(),
-                        subelement.attribute(attrOGLow).toDouble(),
-                        subelement.attribute(attrOGHigh).toDouble(),
-                        subelement.attribute(attrFGLow, "0.0").toDouble(),
-                        subelement.attribute(attrFGHigh, "0.0").toDouble(),
-                        subelement.attribute(attrIBULow).toInt(),
-                        subelement.attribute(attrIBUHigh).toInt(),
-                        subelement.attribute(attrSRMLow).toInt(),
-                        subelement.attribute(attrSRMHigh).toInt()));
-                }
-            }
+    element = root.firstChildElement(tagStyles);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagStyles)) {
+        // get all style tags
+        sub = element.firstChildElement(tagStyle);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagStyle)) {
+            stylemap_.insert(sub.text(),
+                             Style(sub.text(),
+                                   sub.attribute(attrOGLow).toDouble(),
+                                   sub.attribute(attrOGHigh).toDouble(),
+                                   sub.attribute(attrFGLow, "0.0").toDouble(),
+                                   sub.attribute(attrFGHigh, "0.0").toDouble(),
+                                   sub.attribute(attrIBULow).toInt(),
+                                   sub.attribute(attrIBUHigh).toInt(),
+                                   sub.attribute(attrSRMLow).toInt(),
+                                   sub.attribute(attrSRMHigh).toInt()));
         }
     }
 
-   // get all grains tags
+    // get all grains tags
     grainmap_.clear();
-    nodes = root.elementsByTagName(tagGrains);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all grain tags
-            subnodes = element.elementsByTagName(tagGrain);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    grainmap_.insert(subelement.text(), Grain(subelement.text(),
-                        Weight(1.0, *defaultgrainunit_),
-                        subelement.attribute(attrExtract).toDouble(),
-                        subelement.attribute(attrColor).toDouble(),
-                        subelement.attribute(attrUse)));
-                }
-            }
+    element = root.firstChildElement(tagGrains);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagGrains)) {
+        // get all grain tags
+        sub = element.firstChildElement(tagGrain);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagGrain)) {
+            // TODO: grain type deprecates data file format (0.4.0)
+            grainmap_.insert(sub.text(),
+                             Grain(sub.text(),
+                                   Weight(1.0, *defaultgrainunit_),
+                                   sub.attribute(attrExtract).toDouble(),
+                                   sub.attribute(attrColor).toDouble(),
+                                   sub.attribute(attrType, Grain::OTHER_STRING),
+                                   sub.attribute(attrUse)));
         }
     }
 
     // get all hops tags
     hopmap_.clear();
-    nodes = root.elementsByTagName(tagHops);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all hop tags
-            subnodes = element.elementsByTagName(tagHop);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    hopmap_.insert(subelement.text(), Hop(subelement.text(),
-                        Weight(1.0, *defaulthopunit_), QString(),
-                        subelement.attribute(attrAlpha).toDouble(), 60));
-                }
-            }
+    element = root.firstChildElement(tagHops);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagHops)) {
+        // get all hop tags
+        sub = element.firstChildElement(tagHop);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagHop)) {
+            hopmap_.insert(sub.text(),
+                           Hop(sub.text(),
+                               Weight(1.0, *defaulthopunit_), QString(),
+                               sub.attribute(attrAlpha).toDouble(), 60));
         }
     }
 
     // get all miscingredients tags
     miscmap_.clear();
-    nodes = root.elementsByTagName(tagMiscIngredients);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all miscingredient tags
-            subnodes = element.elementsByTagName(tagMiscIngredient);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    miscmap_.insert(subelement.text(),Misc(subelement.text(),
-                        Quantity(1.0, *defaultmiscunit_),
-                        subelement.attribute(attrNotes)));
-                }
-            }
+    element = root.firstChildElement(tagMiscs);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagMiscs)) {
+        // get all hop tags
+        sub = element.firstChildElement(tagMisc);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagMisc)) {
+                    miscmap_.insert(sub.text(),
+                                    Misc(sub.text(),
+                                         Quantity(1.0, *defaultmiscunit_),
+                                         sub.attribute(attrType, Misc::OTHER_STRING),
+                                         sub.attribute(attrNotes)));
         }
     }
 
     // get all utilization tags
     utable_.clear();
-    nodes = root.elementsByTagName(tagUtilization);
     UEntry entry;
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all entry tags
-            subnodes = element.elementsByTagName(tagEntry);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    entry.time = subelement.attribute(attrTime).toUInt();
-                    entry.utilization = subelement.attribute(attrUtil).toUInt();
-                    addUEntry(entry);
-                }
-            }
+    element = root.firstChildElement(tagUtilization);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagUtilization)) {
+        // get all entry tags
+        sub = element.firstChildElement(tagEntry);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagEntry)) {
+            entry.time = sub.attribute(attrTime).toUInt();
+            entry.utilization = sub.attribute(attrUtil).toUInt();
+            addUEntry(entry);
         }
     }
+
     QApplication::restoreOverrideCursor();
     return true;
 }
@@ -398,7 +357,8 @@ bool Data::saveData(const QString &filename)
         subelement.appendChild(doc.createTextNode(grain.name()));
         subelement.setAttribute(attrExtract, grain.extract());
         subelement.setAttribute(attrColor, grain.color());
-        subelement.setAttribute(attrUse, grain.useString());
+        subelement.setAttribute(attrType, grain.type());
+        subelement.setAttribute(attrUse, grain.use());
         element.appendChild(subelement);
     }
     root.appendChild(element);
@@ -415,11 +375,12 @@ bool Data::saveData(const QString &filename)
     root.appendChild(element);
 
     // miscingredients elements
-    element = doc.createElement(tagMiscIngredients);
+    element = doc.createElement(tagMiscs);
     foreach(Misc misc, miscmap_) {
         // iterate through misc list
-        subelement = doc.createElement(tagMiscIngredient);
+        subelement = doc.createElement(tagMisc);
         subelement.appendChild(doc.createTextNode(misc.name()));
+        subelement.setAttribute(attrType, misc.type());
         subelement.setAttribute(attrNotes, misc.notes());
         element.appendChild(subelement);
     }
@@ -440,9 +401,9 @@ bool Data::saveData(const QString &filename)
     QFile datafile(filename);
     if (!datafile.open(QFile::WriteOnly | QFile::Text)) {
         // error opening file
-        qWarning("Error: Cannot open file %s", qPrintable(filename));
+        qWarning() << "Error: Cannot open file" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Cannot write file %1:\n%2")
+                             QObject::tr("Cannot write file %1:\n%2")
                              .arg(filename)
                              .arg(datafile.errorString()));
         datafile.close();
