@@ -69,12 +69,9 @@ public:
     const Style &defaultStyle() const;
     void setDefaultStyle(const QString &s);
     void setDefaultStyle(const Style &s);
-    // get/set default mash
-    bool defaultMash() const;
-    void setDefaultMash(bool mash);
-    // get/set default hop form
-    const QString &defaultHopForm() const;
-    void setDefaultHopForm(const QString &form);
+    // get/set default hop type
+    const QString &defaultHopType() const;
+    void setDefaultHopType(const QString &t);
     // get/set the default grain units
     const Unit &defaultGrainUnit() const;
     void setDefaultGrainUnit(Unit &u);
@@ -84,13 +81,15 @@ public:
     // get/set the default misc units
     const Unit &defaultMiscUnit() const;
     void setDefaultMiscUnit(Unit &u);
+    // get/set the default temperature unit
+    const Unit &defaultTempUnit() const;
+    void setDefaultTempUnit(Unit &u);
 
     // return stringlists of data
     QStringList stylesList();
     QStringList grainsList();
     QStringList hopsList();
     QStringList miscList();
-    QStringList formsList();
 
     // return given data
     Style style(const QString &name);
@@ -117,6 +116,9 @@ public:
     // efficiency
     double efficiency();
     void setEfficiency(double e);
+    // steep yield
+    double steepYield();
+    void setSteepYield(double y);
     // set ibu calc method
     bool tinseth();
     void setTinseth(bool tinseth);
@@ -134,11 +136,11 @@ private:
 
     Volume defaultsize_;
     Style defaultstyle_;
-    bool defaultmash_;
-    QString defaulthopform_;
+    QString defaulthoptype_;
     Unit *defaultgrainunit_;
     Unit *defaulthopunit_;
     Unit *defaultmiscunit_;
+    Unit *defaulttempunit_;
 
     GrainMap grainmap_;
     HopMap hopmap_;
@@ -146,6 +148,7 @@ private:
     StyleMap stylemap_;
 
     QList<UEntry> utable_;
+    double steepyield_;
     double efficiency_;
     bool tinseth_;
     bool morey_;
@@ -153,13 +156,9 @@ private:
 
 // Inlined Methods ///////////////////////////////////////////////////////////
 
-inline bool Data::defaultMash() const { return defaultmash_; }
+inline const QString &Data::defaultHopType() const { return defaulthoptype_; }
 
-inline void Data::setDefaultMash(bool mash) { defaultmash_ = mash; }
-
-inline const QString &Data::defaultHopForm() const { return defaulthopform_; }
-
-inline void Data::setDefaultHopForm(const QString &f) { defaulthopform_ = f; }
+inline void Data::setDefaultHopType(const QString &t) { defaulthoptype_ = t; }
 
 inline const Volume &Data::defaultSize() const { return defaultsize_; }
 
@@ -181,6 +180,10 @@ inline const Unit &Data::defaultMiscUnit() const { return *defaultmiscunit_; }
 
 inline void Data::setDefaultMiscUnit(Unit &u) { defaultmiscunit_ = &u; }
 
+inline const Unit &Data::defaultTempUnit() const { return *defaulttempunit_; }
+
+inline void Data::setDefaultTempUnit(Unit &u) { defaulttempunit_ = &u; }
+
 inline QStringList Data::stylesList() { return stylemap_.keys(); }
 
 inline QStringList Data::grainsList() { return grainmap_.keys(); }
@@ -213,6 +216,10 @@ inline double Data:: efficiency() { return efficiency_; }
 
 inline void Data::setEfficiency(double e) { efficiency_ = e; }
 
+inline double Data:: steepYield() { return steepyield_; }
+
+inline void Data::setSteepYield(double y) { steepyield_ = y; }
+
 inline bool Data:: tinseth() { return tinseth_; }
 
 inline void Data::setTinseth(bool tinseth) { tinseth_ = tinseth; }
