@@ -49,12 +49,13 @@ DatabaseTool::DatabaseTool(QWidget* parent)
 
     // get current font information, for sizing
     QFontMetrics fm(font());
+    unsigned mh = (unsigned)(fm.lineSpacing() * 1.5);
     unsigned mw = fm.width('M');
 
     // grain page
     QWidget *widget = new QWidget();
     grainpage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Grains");
+    ui.ingredients->addTab(widget, tr("&Grains"));
 
     grains_ = Data::instance()->grainmap_.values();
     grainmodel_ = new GrainModel(this, &grains_);
@@ -62,20 +63,22 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     QItemDelegate *delegate = new GrainDelegate(this);
     grainpage.view->setItemDelegate(delegate);
 
+    grainpage.view->verticalHeader()->setDefaultSectionSize(mh);
     grainpage.view->verticalHeader()->hide();
     grainpage.view->horizontalHeader()->setClickable(true);
     grainpage.view->horizontalHeader()->setHighlightSections(false);
 
-    grainpage.view->setColumnWidth(Grain::NAME, 20*mw);
-    grainpage.view->setColumnWidth(Grain::QUANTITY, 8*mw);
-    grainpage.view->setColumnWidth(Grain::EXTRACT, 8*mw);
-    grainpage.view->setColumnWidth(Grain::COLOR, 8*mw);
-    grainpage.view->setColumnWidth(Grain::USE, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::NAME, 20*mw);
+    grainpage.view->setColumnHidden(GrainModel::WEIGHT, true);
+    grainpage.view->setColumnWidth(GrainModel::EXTRACT, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::COLOR, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::TYPE, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::USE, 8*mw);
 
     // hop page
     widget = new QWidget();
     hoppage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Hops");
+    ui.ingredients->addTab(widget, tr("&Hops"));
 
     hops_ = Data::instance()->hopmap_.values();
     hopmodel_ = new HopModel(this, &hops_);
@@ -83,20 +86,21 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     delegate = new HopDelegate(this);
     hoppage.view->setItemDelegate(delegate);
 
+    hoppage.view->verticalHeader()->setDefaultSectionSize(mh);
     hoppage.view->verticalHeader()->hide();
     hoppage.view->horizontalHeader()->setClickable(true);
     hoppage.view->horizontalHeader()->setHighlightSections(false);
 
-    hoppage.view->setColumnHidden(Hop::QUANTITY, true);
-    hoppage.view->setColumnHidden(Hop::TIME, true);
-    hoppage.view->setColumnHidden(Hop::FORM, true);
-    hoppage.view->setColumnWidth(Hop::NAME, 20*mw);
-    hoppage.view->setColumnWidth(Hop::ALPHA, 8*mw);
+    hoppage.view->setColumnHidden(HopModel::WEIGHT, true);
+    hoppage.view->setColumnHidden(HopModel::TIME, true);
+    hoppage.view->setColumnHidden(HopModel::TYPE, true);
+    hoppage.view->setColumnWidth(HopModel::NAME, 20*mw);
+    hoppage.view->setColumnWidth(HopModel::ALPHA, 8*mw);
 
     // misc page
     widget = new QWidget();
     miscpage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Miscellaneous");
+    ui.ingredients->addTab(widget, tr("&Miscellaneous"));
 
     miscs_ = Data::instance()->miscmap_.values();
     miscmodel_ = new MiscModel(this, &miscs_);
@@ -104,18 +108,20 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     delegate = new MiscDelegate(this);
     miscpage.view->setItemDelegate(delegate);
 
+    miscpage.view->verticalHeader()->setDefaultSectionSize(mh);
     miscpage.view->verticalHeader()->hide();
     miscpage.view->horizontalHeader()->setClickable(true);
     miscpage.view->horizontalHeader()->setHighlightSections(false);
 
-    miscpage.view->setColumnHidden(Misc::QUANTITY, true);
-    miscpage.view->setColumnWidth(Misc::NAME, 20*mw);
+    miscpage.view->setColumnHidden(MiscModel::QUANTITY, true);
+    miscpage.view->setColumnWidth(MiscModel::NAME, 20*mw);
+    miscpage.view->setColumnWidth(MiscModel::TYPE, 8*mw);
     miscpage.view->horizontalHeader()->setStretchLastSection(true);
 
     // style page
     widget = new QWidget();
     stylepage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Styles");
+    ui.ingredients->addTab(widget, tr("&Styles"));
 
     styles_ = Data::instance()->stylemap_.values();
     stylemodel_ = new StyleModel(this, &styles_);
@@ -123,23 +129,22 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     delegate = new StyleDelegate(this);
     stylepage.view->setItemDelegate(delegate);
 
+    stylepage.view->verticalHeader()->setDefaultSectionSize(mh);
     stylepage.view->verticalHeader()->hide();
     stylepage.view->horizontalHeader()->setClickable(true);
     stylepage.view->horizontalHeader()->setHighlightSections(false);
 
-    stylepage.view->setColumnWidth(Style::NAME, 20*mw);
-    stylepage.view->setColumnWidth(Style::OGLOW, 8*mw);
-    stylepage.view->setColumnWidth(Style::OGHI, 8*mw);
-    stylepage.view->setColumnWidth(Style::FGLOW, 8*mw);
-    stylepage.view->setColumnWidth(Style::FGHI, 8*mw);
-    stylepage.view->setColumnWidth(Style::IBULOW, 8*mw);
-    stylepage.view->setColumnWidth(Style::IBUHI, 8*mw);
-    stylepage.view->setColumnWidth(Style::SRMLOW, 8*mw);
-    stylepage.view->setColumnWidth(Style::SRMHI, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::NAME, 20*mw);
+    stylepage.view->setColumnWidth(StyleModel::OGLOW, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::OGHI, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::FGLOW, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::FGHI, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::IBULOW, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::IBUHI, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::SRMLOW, 8*mw);
+    stylepage.view->setColumnWidth(StyleModel::SRMHI, 8*mw);
 
     // setup connections
-    connect(grainmodel_, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-            grainpage.view, SLOT(resizeRowsToContents()));
     connect(grainmodel_, SIGNAL(modified()),
             this, SLOT(dataModified()));
     connect(grainpage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -149,8 +154,6 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     connect(grainpage.removebutton, SIGNAL(clicked()),
             grainpage.view, SLOT(removeIngredient()));
 
-    connect(hopmodel_, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-            hoppage.view, SLOT(resizeRowsToContents()));
     connect(hopmodel_, SIGNAL(modified()),
             this, SLOT(dataModified()));
     connect(hoppage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -160,8 +163,6 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     connect(hoppage.removebutton, SIGNAL(clicked()),
             hoppage.view, SLOT(removeIngredient()));
 
-    connect(miscmodel_, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-            miscpage.view, SLOT(resizeRowsToContents()));
     connect(miscmodel_, SIGNAL(modified()),
             this, SLOT(dataModified()));
     connect(miscpage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -171,8 +172,6 @@ DatabaseTool::DatabaseTool(QWidget* parent)
     connect(miscpage.removebutton, SIGNAL(clicked()),
             miscpage.view, SLOT(removeIngredient()));
 
-    connect(stylemodel_, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-            stylepage.view, SLOT(resizeRowsToContents()));
     connect(stylemodel_, SIGNAL(modified()),
             this, SLOT(dataModified()));
     connect(stylepage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -181,6 +180,11 @@ DatabaseTool::DatabaseTool(QWidget* parent)
             stylepage.view, SLOT(addIngredient()));
     connect(stylepage.removebutton, SIGNAL(clicked()),
             stylepage.view, SLOT(removeIngredient()));
+
+    grainmodel_->flush();
+    hopmodel_->flush();
+    miscmodel_->flush();
+    stylemodel_->flush();
 }
 
 DatabaseTool::~DatabaseTool() {}
@@ -193,9 +197,9 @@ void DatabaseTool::fileSave()
     if (finfo.exists() && !finfo.isWritable()) {
         // no write permission
         QMessageBox::warning(this, Resource::TITLE,
-                             QString("<p>Unable to save the database."
-                                     "You do not have permission "
-                                     "to write to %1").arg(localbase));
+                             tr("<p>Unable to save the database."
+                                "You do not have permission "
+                                "to write to %1").arg(localbase));
     } else {
         // sync with Data...
         foreach(Grain grain, grains_) {
@@ -214,8 +218,8 @@ void DatabaseTool::fileSave()
         if (!Data::instance()->saveData(localbase)) {
             // error in saving file
             QMessageBox::warning(this, Resource::TITLE,
-                                 QString("<p>Unable to save the database."
-                                         "Error in saving %1").arg(localbase));
+                                 tr("<p>Unable to save the database."
+                                    "Error in saving %1").arg(localbase));
         }
         ui.actionsave->setEnabled(false);
         modified_ = false;
