@@ -10,11 +10,14 @@
 #include <QApplication>
 #include <QDomDocument>
 #include <QFile>
+#include <QInputDialog>
 #include <QLocale>
 #include <QMessageBox>
 #include <QPrinter>
+#include <QTextDocument>
 #include <QTextStream>
 
+#include "textprinter.h"
 #include "resource.h"
 #include "data.h"
 #include "recipe.h"
@@ -58,9 +61,9 @@ bool Recipe::exportHtml(const QString &filename)
         QFile datafile(filename);
         if (!datafile.open(QFile::WriteOnly | QFile::Text)) {
             // error opening file
-            qWarning("Error: Cannot open file %s", qPrintable(filename));
+            qWarning() << "Error: Cannot open file" << filename;
             QMessageBox::warning(0, TITLE,
-                                 QString("Cannot write file %1:\n%2")
+                                 QObject::tr("Cannot write file %1:\n%2")
                                  .arg(filename)
                                  .arg(datafile.errorString()));
             datafile.close();
@@ -96,85 +99,90 @@ const QString Recipe::recipeHTML()
     html += "<meta name=\"generator\" content=\"" + TITLE + " " + VERSION + " \">\n";
     html += "<title>" + escape(title_) + "</title>\n";
     html += "<meta name=\"author\" content=\"" + escape(brewer_) + "\">\n";
+    html += "<style type='text/css'>\n";
+    html += "body { font-family: sans-serif; }\n";
+    html += "</style>\n";
     html += "</head>\n\n";
 
     html += "<body>\n";
 
     html += table.arg("header").arg("5 bgcolor=\"#CCCCCC\" width=\"100%\"");
     html += "<tr><td>\n" + header.arg(escape(title_)) + "</td></tr>\n";
-    html += "</table>\n<br>\n\n";
+    html += "</table>\n<p>\n\n";
 
     // recipe table
     html += table.arg("recipe").arg(0);
     html += "<tbody>\n<tr>\n";
-    html += th.arg("Recipe");
+    html += th.arg(tr("Recipe"));
     html += "<td width=\"15\"></td>\n";
     html += "<td>" + escape(title_) + "</td>\n";
     html += "<td width=\"25\"></td>\n";
 
-    html += th.arg("Style");
+    html += th.arg(tr("Style"));
     html += "<td width=\"15\"></td>\n";
     html += "<td>" + escape(style_.name()) + "</td>\n";
     html += "</tr>\n<tr>\n";
 
-    html += th.arg("Brewer");
+    html += th.arg(tr("Brewer"));
     html += "<td></td>\n";
     html += "<td>" + escape(brewer_) + "</td>\n";
     html += "<td></td>\n";
 
-    html += th.arg("Batch");
+    html += th.arg(tr("Batch"));
     html += "<td></td>\n";
     html += "<td>" + size_.toString(2) + "</td>\n";
 
-    if (mashed()) html += "</tr>\n<tr>\n" + th.arg("Mashed");
-    html += "</tr>\n</tbody>\n</table>\n<br>\n\n";
+    html += "</tr>\n<tr>\n" + th.arg(tr(method().toUtf8()));
+    html += "</tr>\n</tbody>\n</table>\n<p>\n\n";
 
     // characteristics table
-    html += header.arg("Recipe Characteristics");
+    html += header.arg(tr("Recipe Characteristics"));
     html += table.arg("characteristics").arg(0);
     html += "<tbody>\n<tr>\n";
 
-    html += th.arg("Recipe Gravity");
+    html += th.arg(tr("Recipe Gravity"));
     html += "<td width=\"15\"></td>\n";
-    html += "<td>" + QString::number(og_, 'f', 3) + " OG</td>\n";
+    html += "<td>" + QString::number(og_, 'f', 3) + tr(" OG</td>\n");
     html += "<td width=\"25\"></td>\n";
 
-    html += th.arg("Estimated FG");
+    html += th.arg(tr("Estimated FG"));
     html += "<td width=\"15\"></td>\n";
-    html += "<td>" + QString::number(FGEstimate(), 'f', 3) + " FG</td>\n";
+    html += "<td>" + QString::number(FGEstimate(), 'f', 3) + tr(" FG</td>\n");
     html += "</tr>\n<tr>\n";
 
-    html += th.arg("Recipe Bitterness");
+    html += th.arg(tr("Recipe Bitterness"));
     html += "<td></td>\n";
-    html += "<td>" + QString::number(ibu_, 'f', 0) + " IBU</td>\n";
+    html += "<td>" + QString::number(ibu_, 'f', 0) + tr(" IBU</td>\n");
     html += "<td></td>\n";
 
-    html += th.arg("Alcohol by Volume");
+    html += th.arg(tr("Alcohol by Volume"));
     html += "<td></td>\n";
-    html += "<td>" + QString::number(ABV() * 100.0, 'f', 1) + "%</td>\n";
+    html += "<td>" + QString::number(ABV() * 100.0, 'f', 1) + tr("%</td>\n");
     html += "</tr>\n<tr>\n";
 
-    html += th.arg("Recipe Color");
+    html += th.arg(tr("Recipe Color"));
     html += "<td></td>\n";
-    html += "<td>" + QString::number(srm_, 'f', 0) + DEGREE + " SRM</td>\n";
+    html += "<td>" + QString::number(srm_, 'f', 0) + DEGREE + tr(" SRM</td>\n");
     html += "<td></td>\n";
 
-    html += th.arg("Alcohol by Weight");
+    html += th.arg(tr("Alcohol by Weight"));
     html += "<td></td>\n";
-    html += "<td>" + QString::number(ABW() * 100.0, 'f', 1) + "%</td>\n";
-    html += "</tr>\n</tbody>\n</table>\n<br>\n\n";
+    html += "<td>" + QString::number(ABW() * 100.0, 'f', 1) + tr("%</td>\n");
+    html += "</tr>\n</tbody>\n</table>\n<p>\n\n";
 
     // ingredients table
-    html += header.arg("Ingredients");
+    html += header.arg(tr("Ingredients"));
     html += table.arg("ingredients").arg(0);
     html += "<tbody>\n";
 
     // grains
-    html += "<tr>\n" + th.arg("Quantity");
+    html += "<tr>\n" + th.arg(tr("Quantity"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Grain");
+    html += th.arg(tr("Grain"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Use");
+    html += th.arg(tr("Type"));
+    html += "<td width=\"15\"></td>\n";
+    html += th.arg(tr("Use"));
     html += "</tr>\n\n";
 
     // presort
@@ -186,17 +194,19 @@ const QString Recipe::recipeHTML()
         html += "<td></td>\n";
         html += "<td>" + escape(grain.name()) + "</td>\n";
         html += "<td></td>\n";
-        html += "<td colspan=3>" + grain.useString() + "</td>\n</tr>\n\n";
+        html += "<td>" + grain.type() + "</td>\n";
+        html += "<td></td>\n";
+        html += "<td>" + grain.use() + "</td>\n</tr>\n\n";
     }
 
     // hops
-    html += "<tr>\n" + th.arg("Quantity");
+    html += "<tr>\n" + th.arg(tr("Quantity"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Hop");
+    html += th.arg(tr("Hop"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Form");
+    html += th.arg(tr("Type"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Time");
+    html += th.arg(tr("Time"));
     html += "</tr>\n\n";
 
     // presort
@@ -208,17 +218,17 @@ const QString Recipe::recipeHTML()
         html += "<td></td>\n";
         html += "<td>" + escape(hop.name()) + "</td>\n";
         html += "<td></td>\n";
-        html += "<td>" + hop.form() + "</td>\n";
+        html += "<td>" + hop.type() + "</td>\n";
         html += "<td></td>\n";
-        html += "<td>" + QString::number(hop.time()) + " minutes</td>\n</tr>\n\n";
+        html += "<td colspan=2>" + QString::number(hop.time()) + tr(" minutes</td>\n</tr>\n\n");
     }
 
     // misc ingredients
-    html += "<tr>\n" + th.arg("Quantity");
+    html += "<tr>\n" + th.arg(tr("Quantity"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Misc");
+    html += th.arg(tr("Misc"));
     html += "<td width=\"15\"></td>\n";
-    html += th.arg("Notes");
+    html += th.arg(tr("Notes"));
     html += "</tr>\n\n";
 
     // presort
@@ -230,18 +240,20 @@ const QString Recipe::recipeHTML()
         html += "<td></td>\n";
         html += "<td>" + escape(misc.name()) + "</td>\n";
         html += "<td></td>\n";
+        html += "<td>" + misc.type() + "</td>\n";
+        html += "<td></td>\n";
         html += "<td colspan=3>" + escape(misc.notes()) + "</td>\n</tr>\n\n";
     }
 
-    html += "</tbody>\n</table>\n<br>\n\n";
+    html += "</tbody>\n</table>\n<p>\n\n";
 
     // notes
     // TODO: using replace() might be dangerous if we ever use richtext in notes
-    html += header.arg("Recipe Notes") + "\n";
-    html += "<p>" + escape(recipenotes_).replace('\n', "<br>\n") + "\n</p>\n<br>\n";
+    html += header.arg(tr("Recipe Notes")) + "\n";
+    html += "<p>" + escape(recipenotes_).replace('\n', "<br>\n") + "\n</p>\n<p>\n";
 
-    html += header.arg("Batch Notes") + "\n";
-    html += "<p>" + escape(batchnotes_).replace('\n', "<br>\n") + "\n</p>\n<br>\n";
+    html += header.arg(tr("Batch Notes")) + "\n";
+    html += "<p>" + escape(batchnotes_).replace('\n', "<br>\n") + "\n</p>\n";
 
     html += "</body>\n</html>\n";
 
@@ -259,9 +271,9 @@ bool Recipe::exportText(const QString &filename)
         QFile datafile(filename);
         if (!datafile.open(QFile::WriteOnly | QFile::Text)) {
         // error opening file
-            qWarning("Error: Cannot open file %s", qPrintable(filename));
+            qWarning() << "Error: Cannot open file" << filename;
             QMessageBox::warning(0, TITLE,
-                                 QString("Cannot write file %1:\n%2")
+                                 QObject::tr("Cannot write file %1:\n%2")
                                  .arg(filename)
                                  .arg(datafile.errorString()));
             datafile.close();
@@ -289,29 +301,29 @@ const QString Recipe::recipeText()
 {
     // title stuff
     QString text = underline(title());
-    text += "Brewer: " + brewer_ + '\n';
-    text += "Style: " +  style_.name() + '\n';
-    text += "Batch: " + size_.toString(2);
-    if (mashed()) text += ", Mashed";
+    text += tr("Brewer: ") + brewer_ + '\n';
+    text += tr("Style: ") +  style_.name() + '\n';
+    text += tr("Batch: ") + size_.toString(2);
+    text += tr(method().toUtf8());
     text += "\n\n";
 
     // style stuff
-    text += underline("Characteristics");
-    text += "Recipe Gravity: " +
-        QString::number(og_, 'f', 3) + " OG\n";
-    text += "Recipe Bitterness: " +
-        QString::number(ibu_, 'f', 0) + " IBU\n";
-    text += "Recipe Color: " +
-        QString::number(srm_, 'f', 0) + DEGREE + " SRM\n";
-    text += "Estimated FG: " +
+    text += underline(tr("Characteristics"));
+    text += tr("Recipe Gravity: ") +
+        QString::number(og_, 'f', 3) + tr(" OG\n");
+    text += tr("Recipe Bitterness: ") +
+        QString::number(ibu_, 'f', 0) + tr(" IBU\n");
+    text += tr("Recipe Color: ") +
+        QString::number(srm_, 'f', 0) + DEGREE + tr(" SRM\n");
+    text += tr("Estimated FG: ") +
         QString::number(FGEstimate(), 'f', 3) + '\n';
-    text += "Alcohol by Volume: " +
-        QString::number(ABV() * 100.0, 'f', 1) + "%\n";
-    text += "Alcohol by Weight: " +
-        QString::number(ABW() * 100.0, 'f', 1) + "%\n\n";
+    text += tr("Alcohol by Volume: ") +
+        QString::number(ABV() * 100.0, 'f', 1) + tr("%\n");
+    text += tr("Alcohol by Weight: ") +
+        QString::number(ABW() * 100.0, 'f', 1) + tr("%\n\n");
 
     // ingredients
-    text += underline("Ingredients");
+    text += underline(tr("Ingredients"));
 
     // grains
     // using a map will sort the grains
@@ -321,7 +333,8 @@ const QString Recipe::recipeText()
     foreach (Grain grain, gmap.values()) {
         text += grain.name().leftJustified(30, ' ');
         text += grain.weight().toString(2) + ", ";
-        text += grain.useString() + '\n';
+        text += grain.type() + ", ";
+        text += grain.use() + '\n';
     }
     text += '\n';
 
@@ -333,8 +346,8 @@ const QString Recipe::recipeText()
     foreach (Hop hop, hmap.values()) {
         text += hop.name().leftJustified(30, ' ');
         text += hop.weight().toString(2) + ", ";
-        text += hop.form() + ", ";
-        text += QString::number(hop.time()) + " minutes\n";
+        text += hop.type() + ", ";
+        text += QString::number(hop.time()) + tr(" minutes\n");
     }
     text += '\n';
 
@@ -346,16 +359,17 @@ const QString Recipe::recipeText()
     foreach (Misc misc, mmap.values()) {
         text += misc.name().leftJustified(30, ' ');
         text += misc.quantity().toString(2) + ", ";
+        text += misc.type() + ", ";
         text += misc.notes() + '\n';
     }
     text += '\n';
 
     // notes
-    text += underline("Notes");
+    text += underline(tr("Notes"));
 
     // TODO: wrap long notes
-    text += "Recipe Notes:\n" + recipenotes_ + "\n\n";
-    text += "Batch Notes:\n" + batchnotes_ + "\n\n";
+    text += tr("Recipe Notes:\n") + recipenotes_ + "\n\n";
+    text += tr("Batch Notes:\n") + batchnotes_ + "\n\n";
 
     return text;
 }
@@ -372,9 +386,9 @@ bool Recipe::exportBeerXML(const QString &filename)
     QFile datafile(filename);
     if (!datafile.open(QFile::WriteOnly | QFile::Text)) {
         // error opening file
-        qWarning("Error: Cannot open file %s", qPrintable(filename));
+        qWarning() << "Error: Cannot open file" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Cannot write file %1:\n%2")
+                             QObject:: tr("Cannot write file %1:\n%2")
                              .arg(filename)
                              .arg(datafile.errorString()));
         datafile.close();
@@ -410,17 +424,7 @@ bool Recipe::exportBeerXML(const QString &filename)
 
     // type
     element = doc.createElement(tagTYPE);
-    switch (recipeType()) {
-      case Recipe::TypeExtract:
-          element.appendChild(doc.createTextNode(TYPE_EXTRACT));
-          break;
-      case Recipe::TypePartial:
-          element.appendChild(doc.createTextNode(TYPE_PARTIAL));
-          break;
-      case Recipe::TypeAllGrain:
-          element.appendChild(doc.createTextNode(TYPE_ALLGRAIN));
-          break;
-    }
+    element.appendChild(doc.createTextNode(method()));
     record.appendChild(element);
 
     // brewer
@@ -489,13 +493,10 @@ bool Recipe::exportBeerXML(const QString &filename)
     element.appendChild(doc.createTextNode(QString::number(size,'f',8)));
     record.appendChild(element);
 
-    if (mashed()) {
-        // efficiency
-        element = doc.createElement(tagEFFICIENCY);
-        element.appendChild(doc.createTextNode
-            (QString::number(Data::instance()->efficiency()*100.0,'f',1)));
-        record.appendChild(element);
-    }
+    // efficiency
+    element = doc.createElement(tagEFFICIENCY);
+    element.appendChild(doc.createTextNode(QString::number(Data::instance()->efficiency()*100.0,'f',1)));
+    record.appendChild(element);
 
     // fermentables list
     element = doc.createElement(tagFERMENTABLES);
@@ -512,7 +513,6 @@ bool Recipe::exportBeerXML(const QString &filename)
         subelement = doc.createElement(tagNAME);
         subelement.appendChild(doc.createTextNode(grain.name()));
         subrecord.appendChild(subelement);
-        // type // TODO: ???
         // amount
         subelement = doc.createElement(tagAMOUNT);
         size = grain.weight().amount(Weight::kilogram);
@@ -528,7 +528,11 @@ bool Recipe::exportBeerXML(const QString &filename)
         double yield = extractToYield(grain.extract()) * 100.0;
         subelement.appendChild(doc.createTextNode(QString::number(yield,'f',2)));
         subrecord.appendChild(subelement);
-        // use??? // TODO: beerxml doesn't have this
+        // type
+        subelement = doc.createElement(tagTYPE);
+        subelement.appendChild(doc.createTextNode(grain.type()));
+        subrecord.appendChild(subelement);
+ 
         element.appendChild(subrecord);
     }
     record.appendChild(element);
@@ -567,11 +571,11 @@ bool Recipe::exportBeerXML(const QString &filename)
         subelement.appendChild(doc.createTextNode
                                (QString::number(hop.time())));
         subrecord.appendChild(subelement);
-        // form
+        // form/type
         subelement = doc.createElement(tagFORM);
         buf = "Leaf";;
-        if (hop.form() == HOP_PELLET) buf = "Pellet";
-        if (hop.form() == HOP_PLUG) buf = "Plug";
+        if (hop.type() == Hop::PELLET_STRING) buf = "Pellet";
+        if (hop.type() == Hop::PLUG_STRING) buf = "Plug";
         subelement.appendChild(doc.createTextNode(buf));
         subrecord.appendChild(subelement);
         element.appendChild(subrecord);
@@ -581,9 +585,8 @@ bool Recipe::exportBeerXML(const QString &filename)
     // yeasts
     element = doc.createElement(tagYEASTS);
     // iterate through list looking for yeasts
-    // TODO: need to separate yeasts from other miscs in database
     foreach (Misc misc, miscs_) {
-        if (misc.name().contains("yeast", Qt::CaseInsensitive)) {
+        if (misc.type() == Misc::YEAST_STRING) {
             // yeast
             subrecord = doc.createElement(tagYEAST);
             // version
@@ -598,12 +601,16 @@ bool Recipe::exportBeerXML(const QString &filename)
             subelement = doc.createElement(tagAMOUNT);
             subelement.appendChild(doc.createTextNode("0.00")); // TODO: fixup for miscs
             subrecord.appendChild(subelement);
+            // type
+            subelement = doc.createElement(tagTYPE);
+            subelement.appendChild(doc.createTextNode(Misc::YEAST_STRING));
+            subrecord.appendChild(subelement);
+            // TODO: form???
             // notes
             subelement = doc.createElement(tagNOTES);
             subelement.appendChild(doc.createTextNode(misc.notes()));
             subrecord.appendChild(subelement);            
-            // type ???
-            // form ???
+
             element.appendChild(subrecord);
         }
     }
@@ -613,7 +620,7 @@ bool Recipe::exportBeerXML(const QString &filename)
     element = doc.createElement(tagMISCS);
     // iterate through list looking for non-yeast miscs
     foreach (Misc misc, miscs_) {
-        if (!misc.name().contains("yeast", Qt::CaseInsensitive)) {
+        if (misc.type() != Misc::YEAST_STRING) {
             // misc
             subrecord = doc.createElement(tagMISC);
             // version
@@ -628,12 +635,15 @@ bool Recipe::exportBeerXML(const QString &filename)
             subelement = doc.createElement(tagAMOUNT);
             subelement.appendChild(doc.createTextNode("0.00")); // TODO: fixup for miscs
             subrecord.appendChild(subelement);
+            // type
+            subelement = doc.createElement(tagTYPE);
+            subelement.appendChild(doc.createTextNode(misc.type()));
+            subrecord.appendChild(subelement);
             // notes
             subelement = doc.createElement(tagNOTES);
             subelement.appendChild(doc.createTextNode(misc.notes()));
             subrecord.appendChild(subelement);            
             element.appendChild(subrecord);
-            // type ???
             // use ???
             // time ???
         }
@@ -668,34 +678,304 @@ bool Recipe::exportBeerXML(const QString &filename)
     return true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// importBeerXml()
+// ---------------
+// Import recipe from BeerXML format
+
+bool Recipe::importBeerXml(const QString &filename)
+{
+    // open file
+    QFile datafile(filename);
+    if (!datafile.open(QFile::ReadOnly | QFile::Text)) {
+        // error opening file
+        qWarning() << "Error: Cannot open" << filename;
+        QMessageBox::warning(0, TITLE,
+                             QObject::tr("Cannot read file %1:\n%2")
+                             .arg(filename)
+                             .arg(datafile.errorString()));
+        datafile.close();
+        return false;
+    }
+
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+
+    // open dom recipe
+    QDomDocument doc;
+    doc.setContent(&datafile);
+    datafile.close();
+
+    // check the doc type and root tag
+    QDomElement root = doc.documentElement();
+    if (root.tagName() != tagRECIPES) {
+        // wrong file type
+        qWarning() << "Error: Wrong file type" << filename;
+        QMessageBox::warning(0, TITLE,
+                             QObject::tr("Wrong file type for %1").arg(filename));
+        QApplication::restoreOverrideCursor();
+        return false;
+    }
+
+    QDomNodeList nodes;
+    QDomElement element, sub;
+
+    // BeerXML may have more than one recipe
+    QMap<QString, QDomElement> recipes;
+    element = root.firstChildElement(tagRECIPE);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagRECIPE)) {
+        sub = element.firstChildElement(tagNAME);
+        if (!sub.isNull()) {
+            recipes[sub.text()] = element;
+        }
+    }
+    if (recipes.count() == 0) {
+        qWarning() << "Error: No recipes found in" << filename;
+        QMessageBox::warning(0, TITLE,
+            QObject::tr("No recipes found in %1").arg(filename));
+        QApplication::restoreOverrideCursor();
+        return false;
+    }
+
+    if (recipes.count() > 1) {
+        // select just one recipe
+        bool ok;
+        QString item = QInputDialog::getItem(0, TITLE,
+            QObject::tr("Multiple recipes found. Please select one:"),
+            recipes.keys(), 0, false, &ok);
+        if (ok) {
+            root = recipes[item];
+        } else {
+            // bail
+            QApplication::restoreOverrideCursor();
+            return false;
+        }
+    } else {
+        root = recipes.begin().value();
+    }
+    recipes.clear();
+
+    // check recipe version
+    element = root.firstChildElement(tagVERSION);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element";
+    } else {
+        if (element.text() != "1") {
+            qWarning() << "Error: Wrong BeerXML version in" << filename;
+            QMessageBox::warning(0, TITLE,
+                QObject::tr("Cannot process file %1").arg(filename));
+            QApplication::restoreOverrideCursor();
+            return false;
+        }
+    }
+
+    // get title
+    element = root.firstChildElement(tagNAME);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element" << tagNAME;
+    } else {
+        setTitle(element.text());
+    }
+    // get brewer
+    element = root.firstChildElement(tagBREWER);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element" << tagBREWER;
+    } else {
+        setBrewer(element.text());
+    }
+    // get style information
+    element = root.firstChildElement(tagSTYLE);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element" << tagSTYLE;
+    } else {
+        // TODO: load/save entire style
+        sub = element.firstChildElement(tagNAME);
+        if (sub.isNull()) {
+            qDebug() << "Warning:: bad DOM element" << tagNAME;
+        } else {
+            setStyle(sub.text());
+        }
+    }
+
+    // get batch settings
+    bool mashed = false;
+    element = root.firstChildElement(tagTYPE);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element" << tagTYPE;
+    } else {
+        mashed = (element.text() != EXTRACT_STRING);
+    }
+    element = root.firstChildElement(tagBATCHSIZE);
+    if (element.isNull()) {
+        qDebug() << "Warning:: bad DOM element" << tagBATCHSIZE;
+    } else {
+        setSize(Volume(element.text(), Volume::liter));
+    }
+
+    // get notes
+    recipenotes_.clear();
+    batchnotes_.clear();
+    element = root.firstChildElement(tagNOTES);
+    if (!element.isNull()) {
+        setRecipeNotes(element.text());
+    }
+    element = root.firstChildElement(tagTASTENOTES);
+    if (!element.isNull()) {
+        setBatchNotes(element.text());
+    }
+
+    // get fermentables
+    grains_.clear();
+    element = root.firstChildElement(tagFERMENTABLES);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagFERMENTABLES)) {
+        sub = element.firstChildElement(tagFERMENTABLE);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagFERMENTABLE)) {
+            Grain grain;
+            QDomElement el = sub.firstChildElement(tagNAME);
+            grain.setName(el.text());
+            el = sub.firstChildElement(tagAMOUNT);
+            grain.setWeight(Weight(el.text().toDouble(), Weight::kilogram));
+            el = sub.firstChildElement(tagYIELD);
+            grain.setExtract(yieldToExtract(el.text().toDouble() / 100.0));
+            el = sub.firstChildElement(tagCOLOR);
+            grain.setColor(el.text().toDouble());
+            
+            // set type and guess at use
+            el = sub.firstChildElement(tagTYPE);
+            grain.setType(Grain::OTHER_STRING);
+            grain.setUse(Grain::OTHER_STRING);
+            if (el.text() == "Grain") {
+                grain.setType(Grain::GRAIN_STRING);
+                if (mashed) grain.setUse(Grain::MASHED_STRING);
+                else        grain.setUse(Grain::STEEPED_STRING);
+            }
+            if (el.text() == "Sugar") {
+                grain.setType(Grain::SUGAR_STRING);
+                grain.setUse(Grain::OTHER_STRING);
+            }
+            if ((el.text() == "Extract") ||
+                (el.text() == "Dry Extract")) {
+                grain.setType(Grain::EXTRACT_STRING);
+                grain.setUse(Grain::EXTRACT_STRING);
+            }
+            if (el.text() == "Adjunct") {
+                grain.setType(Grain::ADJUNCT_STRING);
+                grain.setUse(Grain::MASHED_STRING);
+            }
+            addGrain(grain);
+        }
+    }
+
+    // get hops
+    hops_.clear();
+    element = root.firstChildElement(tagHOPS);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagHOPS)) {
+        sub = element.firstChildElement(tagHOP);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagHOP)) {
+            Hop hop;
+            QDomElement el = sub.firstChildElement(tagNAME);
+            hop.setName(el.text());
+            el = sub.firstChildElement(tagAMOUNT);
+            hop.setWeight(Weight(el.text().toDouble(), Weight::kilogram));
+            el = sub.firstChildElement(tagALPHA);
+            hop.setAlpha(el.text().toDouble() / 100.0);
+            // TODO: add USE to future hop notes
+            el = sub.firstChildElement(tagTIME);
+            hop.setTime(el.text().toUInt());
+            el = sub.firstChildElement(tagFORM);
+            if (el.text() == "Pellet") {
+                hop.setType(Hop::PELLET_STRING);
+            } else if (el.text() == "Plug") {
+                hop.setType(Hop::PLUG_STRING);
+            } else {
+                hop.setType(Hop::WHOLE_STRING);
+            }
+            addHop(hop);
+        }
+    }
+
+    // get miscs
+    miscs_.clear();
+    element = root.firstChildElement(tagMISCS);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagMISCS)) {
+        sub = element.firstChildElement(tagMISC);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagMISC)) {
+            Misc misc;
+            QDomElement el = sub.firstChildElement(tagNAME);
+            // TODO: put TYPE and USE in notes
+            misc.setName(el.text());
+            bool aiw = (el.text().toLower() == "true");
+            el = sub.firstChildElement(tagAMOUNT);
+            if (aiw) {
+                misc.setQuantity(Weight(el.text().toDouble(), Weight::kilogram));
+            } else {
+                misc.setQuantity(Volume(el.text().toDouble(), Volume::liter));
+            }
+
+            // set type
+            el = sub.firstChildElement(tagTYPE);
+            misc.setType(Misc::OTHER_STRING);
+            if (el.text() == "Spice") misc.setType(Misc::SPICE_STRING);
+            if (el.text() == "Fining") misc.setType(Misc::FINING_STRING);
+            if (el.text() == "Herb") misc.setType(Misc::HERB_STRING);
+            if (el.text() == "Flavor") misc.setType(Misc::FLAVOR_STRING);
+            if (el.text() == "Water Agent") misc.setType(Misc::ADDITIVE_STRING);
+
+            el = sub.firstChildElement(tagNOTES);
+            misc.setNotes(el.text());
+
+            addMisc(misc);
+        }
+    }
+
+    // get yeasts
+    element = root.firstChildElement(tagYEASTS);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagYEASTS)) {
+        sub = element.firstChildElement(tagYEAST);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagYEAST)) {
+            Misc misc;
+            QDomElement el = sub.firstChildElement(tagNAME);
+            misc.setName(el.text());
+            el = sub.firstChildElement(tagAMOUNTISWEIGHT);
+            bool aiw = (el.text().toLower() == "true");
+            el = sub.firstChildElement(tagAMOUNT);
+            if (aiw) {
+                misc.setQuantity(Weight(el.text().toDouble(), Weight::kilogram));
+            } else {
+                misc.setQuantity(Volume(el.text().toDouble(), Volume::liter));
+            }
+            misc.setType(Misc::YEAST_STRING);
+            QString notes;
+            el = sub.firstChildElement(tagFORM);
+            if (!el.isNull()) notes = QString("%1 yeast. ").arg(el.text());
+            el = sub.firstChildElement(tagNOTES);
+            notes += el.text();
+            misc.setNotes(notes);
+            addMisc(misc);
+        }
+    }
+
+    // calculate the numbers
+    recalc();
+
+    // just loaded recipes  are not modified
+    setModified(false);
+    emit (recipeChanged());
+
+    QApplication::restoreOverrideCursor();
+    return true;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // exportPdf()
 // ------------
 // Export recipe as pdf
 
-bool Recipe::exportPdf(const QString &filename)
+bool Recipe::exportPdf(TextPrinter *textprinter, const QString &filename)
 {
-    if (!filename.isEmpty()) {
-        QPrinter printer(QPrinter::HighResolution);
-        printer.setColorMode(QPrinter::GrayScale);
-        printer.setOutputFormat(QPrinter::PdfFormat);
-        printer.setOutputFileName(filename);
-        printer.setCreator(TITLE + ' ' + VERSION);
-        printer.setDocName(title_);
-
-        // for convenience, use US_Letter for C/US/Canada
-        switch (QLocale::system().country()) {
-          case QLocale::AnyCountry:
-          case QLocale::Canada:
-          case QLocale::UnitedStates:
-          case QLocale::UnitedStatesMinorOutlyingIslands:
-              printer.setPageSize(QPrinter::Letter); break;
-          default:
-              printer.setPageSize(QPrinter::A4); break;
-        }
-
-        printRecipe(&printer);
-
+    if (textprinter && (!filename.isEmpty())) {
+        QTextDocument document;
+        document.setHtml(recipeHTML());
+        textprinter->exportPdf(&document, QString(), filename);
         return true;
     }
     return false;
