@@ -12,20 +12,28 @@
 
 using namespace Resource;
 
+const QByteArray Grain::EXTRACT_STRING = QT_TRANSLATE_NOOP("grain", "Extract");
+const QByteArray Grain::MASHED_STRING  = QT_TRANSLATE_NOOP("grain", "Mashed");
+const QByteArray Grain::STEEPED_STRING = QT_TRANSLATE_NOOP("grain", "Steeped");
+const QByteArray Grain::GRAIN_STRING   = QT_TRANSLATE_NOOP("grain", "Grain");
+const QByteArray Grain::ADJUNCT_STRING = QT_TRANSLATE_NOOP("grain", "Adjunct");
+const QByteArray Grain::SUGAR_STRING   = QT_TRANSLATE_NOOP("grain", "Sugar");
+const QByteArray Grain::OTHER_STRING   = QT_TRANSLATE_NOOP("grain", "Other");
+
 //////////////////////////////////////////////////////////////////////////////
 // Grain()
 // -------
 // Constructor
 
 Grain::Grain()
-    : name_("Generic"), weight_(), extract_(1.025), color_(1.0),
-      use_(USE_OTHER), yield_(0.0), hcu_(0.0)
+    : name_(QObject::tr("Generic")), weight_(), extract_(1.025), color_(1.0),
+      type_(GRAIN_STRING), use_(OTHER_STRING), yield_(0.0), hcu_(0.0)
 { ; }
 
 Grain::Grain(const QString &name, const Weight &weight, const double &extract,
-             const double &color, const QString &use)
+             const double &color, const QString &typ, const QString &use)
     : name_(name), weight_(weight), extract_(extract), color_(color),
-      use_(useStringToEnum(use))
+      type_(typ), use_(use)
 {
     recalc();
 }
@@ -39,7 +47,8 @@ Grain::~Grain() { ; }
 
 Grain::Grain(const Grain &g)
     : name_(g.name_), weight_(g.weight_), extract_(g.extract_),
-      color_(g.color_), use_(g.use_), yield_(g.yield_), hcu_(g.hcu_)
+      color_(g.color_), type_(g.type_), use_(g.use_), yield_(g.yield_),
+      hcu_(g.hcu_)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -54,6 +63,7 @@ Grain Grain::operator=(const Grain &g)
         weight_ = g.weight_;
         extract_ = g.extract_;
         color_ = g.color_;
+        type_ = g.type_;
         use_ = g.use_;
         yield_ = g.yield_;
         hcu_ = g.hcu_;
@@ -72,22 +82,23 @@ bool Grain::operator==(const Grain &g) const
         && (weight_ == g.weight_)
         && (extract_ == g.extract_)
         && (color_ == g.color_)
+        && (type_ == g.type_)
         && (use_ == g.use_);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// useString()
-// -----------
-// Return usage as a string
+// typeStringList()
+// ----------------
+// Return string list of grain types
 
-const QString &Grain::useString() const
+QStringList Grain::typeStringList()
 {
-    switch (use_) {
-        case USE_EXTRACT: return GRAIN_EXTRACT;
-        case USE_MASHED:  return GRAIN_MASHED;
-        case USE_STEEPED: return GRAIN_STEEPED;
-    }
-    return GRAIN_OTHER;
+    return (QStringList()
+            << GRAIN_STRING
+            << EXTRACT_STRING
+            << ADJUNCT_STRING
+            << SUGAR_STRING
+            << OTHER_STRING);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -98,26 +109,10 @@ const QString &Grain::useString() const
 QStringList Grain::useStringList()
 {
     return (QStringList()
-            << GRAIN_EXTRACT
-            << GRAIN_MASHED
-            << GRAIN_STEEPED
-            << GRAIN_OTHER);
-}
-
-///////////////////////////////////////////////////////////////////////////////
-// useStringToEnum()
-// -----------------
-// Convert use string to enumeration type
-
-int Grain::useStringToEnum(const QString &name)
-{
-    if ((name.toLower() == GRAIN_MASHED) || (name.toLower() == "mash"))
-        return USE_MASHED;
-    if ((name.toLower() == GRAIN_STEEPED) || (name.toLower() == "steep"))
-        return USE_STEEPED;
-    if (name.toLower() == GRAIN_EXTRACT)
-        return USE_EXTRACT;
-    return USE_OTHER;
+            << EXTRACT_STRING
+            << MASHED_STRING
+            << STEEPED_STRING
+            << OTHER_STRING);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
