@@ -39,23 +39,22 @@
 
 #include "quantity.h"
 
-enum {
-    USE_OTHER,
-    USE_MASHED,
-    USE_STEEPED,
-    USE_EXTRACT
-};
-
 class Grain {
 public:
-    // fields (columns in view)
-    enum { NAME, QUANTITY, EXTRACT, COLOR, USE, COUNT };
+    // grain strings
+    static const QByteArray EXTRACT_STRING;
+    static const QByteArray MASHED_STRING;
+    static const QByteArray STEEPED_STRING;
+    static const QByteArray GRAIN_STRING;
+    static const QByteArray ADJUNCT_STRING;
+    static const QByteArray SUGAR_STRING;
+    static const QByteArray OTHER_STRING;
 
     // default constructor
     Grain();
     // constructor
     Grain(const QString &name, const Weight &quantity, const double &extract,
-          const double &color, const QString &use);
+          const double &color, const QString &typ, const QString &use);
     // copy constructor
     Grain(const Grain &g);
     // operators
@@ -77,9 +76,11 @@ public:
     // get/set color
     double color() const;
     void setColor(double color);
+    // get/set type
+    const QString &type() const;
+    void setType(const QString &typ);
     // get/set usage
-    int use() const;
-    void setUse(int use);
+    const QString &use() const;
     void setUse(const QString &use);
 
     // return the yield (quantity times extract)
@@ -87,12 +88,10 @@ public:
     // return the HCU (quantity times color)
     double HCU() const;
 
-    // return use as string
-    const QString &useString() const;
     // return a list of use strings
     static QStringList useStringList();
-    // convert use string to enum and vice versa
-    static int useStringToEnum(const QString &name);
+    // return a list of type strings
+    static QStringList typeStringList();
 
 private:
     // recalc values
@@ -103,7 +102,8 @@ private:
     Weight weight_;
     double extract_;
     double color_;
-    int use_;
+    QString type_;
+    QString use_;
     double yield_;
     double hcu_;
 };
@@ -141,13 +141,16 @@ inline void Grain::setColor(double color)
 inline double Grain::color() const
     { return color_; }
 
-inline void Grain::setUse(int use)
-    { use_ = use; }
+inline void Grain::setType(const QString &typ)
+    { type_ = typ; }
+
+inline const QString &Grain::type() const
+    { return type_; }
 
 inline void Grain::setUse(const QString &use)
-    { use_ = useStringToEnum(use); }
+    { use_ = use; }
 
-inline int Grain::use() const
+inline const QString &Grain::use() const
     { return use_; }
 
 inline double Grain::yield() const
