@@ -14,6 +14,7 @@
 #include "data.h"
 #include "grain.h"
 #include "graindelegate.h"
+#include "grainmodel.h"
 
 GrainDelegate::GrainDelegate(QObject *parent) : QItemDelegate(parent) {}
 
@@ -32,7 +33,7 @@ QWidget *GrainDelegate::createEditor(QWidget *parent,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Grain::NAME:
+      case GrainModel::NAME:
           combo = new QComboBox(parent);
           combo->setEditable(true);
           combo->addItem(QString());
@@ -40,17 +41,17 @@ QWidget *GrainDelegate::createEditor(QWidget *parent,
           combo->installEventFilter(const_cast<GrainDelegate*>(this));
           return combo;
 
-      case Grain::QUANTITY:
+      case GrainModel::WEIGHT:
           spin = new QDoubleSpinBox(parent);
-          spin->setDecimals(2);
-          spin->setRange(0.00, 100.00);
+          spin->setDecimals(3);
+          spin->setRange(0.00, 1000.00);
           spin->setSingleStep(0.25);
           suffix = " " + Data::instance()->defaultGrainUnit().symbol();
           spin->setSuffix(suffix);
           spin->installEventFilter(const_cast<GrainDelegate*>(this));
           return spin;
 
-      case Grain::EXTRACT:
+      case GrainModel::EXTRACT:
           spin = new QDoubleSpinBox(parent);
           spin->setDecimals(3);
           spin->setRange(1.000, 1.100);
@@ -58,7 +59,7 @@ QWidget *GrainDelegate::createEditor(QWidget *parent,
           spin->installEventFilter(const_cast<GrainDelegate*>(this));
           return spin;
 
-      case Grain::COLOR:
+      case GrainModel::COLOR:
           spin = new QDoubleSpinBox(parent);
           spin->setDecimals(1);
           spin->setRange(0.0, 500.0);
@@ -67,7 +68,14 @@ QWidget *GrainDelegate::createEditor(QWidget *parent,
           spin->installEventFilter(const_cast<GrainDelegate*>(this));
           return spin;
 
-      case Grain::USE:
+      case GrainModel::TYPE:
+          combo = new QComboBox(parent);
+          combo->setEditable(false);
+          combo->addItems(Grain::typeStringList());
+          combo->installEventFilter(const_cast<GrainDelegate*>(this));
+          return combo;
+
+      case GrainModel::USE:
           combo = new QComboBox(parent);
           combo->setEditable(false);
           combo->addItems(Grain::useStringList());
@@ -90,7 +98,7 @@ void GrainDelegate::setEditorData(QWidget *editor,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Grain::NAME:
+      case GrainModel::NAME:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           comboindex = combo->findText(value.toString());
@@ -101,15 +109,16 @@ void GrainDelegate::setEditorData(QWidget *editor,
           }
           break;
 
-      case Grain::QUANTITY:
-      case Grain::EXTRACT:
-      case Grain::COLOR:
+      case GrainModel::WEIGHT:
+      case GrainModel::EXTRACT:
+      case GrainModel::COLOR:
           spin = static_cast<QDoubleSpinBox*>(editor);
           if (!spin) return;
           spin->setValue(value.toDouble());
           break;
 
-      case Grain::USE:
+      case GrainModel::TYPE:
+      case GrainModel::USE:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           combo->setCurrentIndex(combo->findText(value.toString()));
@@ -130,17 +139,18 @@ void GrainDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Grain::NAME:
-      case Grain::USE:
+      case GrainModel::NAME:
+      case GrainModel::TYPE:
+      case GrainModel::USE:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           value = combo->currentText();
           model->setData(index, value);
           break;
 
-      case Grain::QUANTITY:
-      case Grain::EXTRACT:
-      case Grain::COLOR:
+      case GrainModel::WEIGHT:
+      case GrainModel::EXTRACT:
+      case GrainModel::COLOR:
           spin = static_cast<QDoubleSpinBox*>(editor);
           if (!spin) return;
           value = spin->value();
