@@ -16,6 +16,8 @@
 #include "resource.h"
 #include "grainmodel.h"
 
+using namespace Resource;
+
 //////////////////////////////////////////////////////////////////////////////
 // GrainModel()
 // ------------
@@ -55,46 +57,51 @@ QVariant GrainModel::data(const QModelIndex &index, int role) const
     // column is the grain "field"
     if (role == Qt::DisplayRole) {
         switch (index.column()) {
-          case Grain::NAME:
+          case NAME:
               return grain.name();
-          case Grain::QUANTITY:
-              return grain.weight().toString(2);
-          case Grain::EXTRACT:
+          case WEIGHT:
+              return grain.weight().toString(3);
+          case EXTRACT:
               return QString::number(grain.extract(), 'f', 3);
-          case Grain::COLOR:
+          case COLOR:
               return QString::number(grain.color(), 'f', 1) + Resource::DEGREE;
-          case Grain::USE:
-              return grain.useString();
+          case TYPE:
+              return grain.type();
+          case USE:
+              return grain.use();
           default:
               return QVariant();
         }
     } else if (role == Qt::EditRole) {
         switch (index.column()) {
-          case Grain::NAME:
+          case NAME:
               return grain.name();
-          case Grain::QUANTITY: {
+          case WEIGHT: {
               // return converted quantity
               Weight weight = grain.weight();
               weight.convert(Data::instance()->defaultGrainUnit());
               return weight.amount();
           }
-          case Grain::EXTRACT:
+          case EXTRACT:
               return grain.extract();
-          case Grain::COLOR:
+          case COLOR:
               return grain.color();
-          case Grain::USE:
-              return grain.useString();
+          case TYPE:
+              return grain.type();
+          case USE:
+              return grain.use();
           default:
               return QVariant();
         }
     } else if (role == Qt::TextAlignmentRole) {
         switch (index.column()) {
-          case Grain::NAME:
-          case Grain::USE:
+          case NAME:
+          case TYPE:
+          case USE:
               return Qt::AlignLeft;
-          case Grain::QUANTITY:
-          case Grain::EXTRACT:
-          case Grain::COLOR:
+          case WEIGHT:
+          case EXTRACT:
+          case COLOR:
           default:
               return Qt::AlignRight;
         }
@@ -126,7 +133,7 @@ bool GrainModel::setData(const QModelIndex &index,
     grain = list_->value(row);
 
     switch (column) {
-      case Grain::NAME:
+      case NAME:
           // editing name as several special cases
           name = value.toString();
 
@@ -139,10 +146,10 @@ bool GrainModel::setData(const QModelIndex &index,
               deleting = true;
 
               int status = QMessageBox::question(QApplication::activeWindow(),
-                               Resource::TITLE + " - Delete?",
-                               "Do you wish to remove this entry?",
-                               "Remove", "Cancel");
-              if (status == 0) {
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+              if (status == QMessageBox::Yes) {
                   // remove grain
                   beginRemoveRows(index.parent(), row, row);
 
@@ -171,24 +178,29 @@ bool GrainModel::setData(const QModelIndex &index,
               // we don't override weight
               grain.setExtract(newgrain.extract());
               grain.setColor(newgrain.color());
+              grain.setType(newgrain.type());
               grain.setUse(newgrain.use());
           }
           break;
 
-      case Grain::QUANTITY:
+      case WEIGHT:
           grain.setWeight(Weight(value.toDouble(),
                                  Data::instance()->defaultGrainUnit()));
           break;
 
-      case Grain::EXTRACT:
+      case EXTRACT:
           grain.setExtract(value.toDouble());
           break;
 
-      case Grain::COLOR:
+      case COLOR:
           grain.setColor(value.toDouble());
           break;
 
-      case Grain::USE:
+      case TYPE:
+          grain.setType(value.toString());
+          break;
+
+      case USE:
           grain.setUse(value.toString());
           break;
 
@@ -200,8 +212,8 @@ bool GrainModel::setData(const QModelIndex &index,
     emit modified();
 
     // whole row may have changed
-    emit dataChanged(index.sibling(row, Grain::NAME),
-                     index.sibling(row, Grain::USE));
+    emit dataChanged(index.sibling(row, NAME),
+                     index.sibling(row, USE));
 
     return true;
 }
@@ -216,7 +228,7 @@ bool GrainModel::insertRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only insert one row at a time
     if ((row < 0) || (row >= list_->count())) row = list_->count();
 
-    Grain grain = Data::instance()->grain("Generic");
+    Grain grain = Data::instance()->grain(tr("Generic"));
 
     beginInsertRows(QModelIndex(), row, row);
     list_->insert(row, grain);
@@ -235,10 +247,11 @@ bool GrainModel::removeRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only remove one row at a time
     if ((row < 0) || (row >= list_->count())) return false;
 
-    if (QMessageBox::question(QApplication::activeWindow(),
-                              Resource::TITLE + " - Delete?",
-                              "Do you wish to remove this entry?",
-                              "Remove", "Cancel")) {
+    int status = QMessageBox::question(QApplication::activeWindow(),
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+    if (status == QMessageBox::Cancel) {
         return false;
     }
 
@@ -259,16 +272,18 @@ QVariant GrainModel::headerData(int section, Qt::Orientation orientation,
 {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-          case Grain::NAME:
-              return "Grain";
-          case Grain::QUANTITY:
-              return "Quantity";
-          case Grain::EXTRACT:
-              return "Extract";
-          case Grain::COLOR:
-              return "Color";
-          case Grain::USE:
-              return "Use";
+          case NAME:
+              return tr("Grain");
+          case WEIGHT:
+              return tr("Weight");
+          case EXTRACT:
+              return tr("Extract");
+          case COLOR:
+              return tr("Color");
+          case TYPE:
+              return tr("Type");
+          case USE:
+              return tr("Use");
           default:
               return QVariant();
         }
@@ -306,7 +321,7 @@ int GrainModel::rowCount(const QModelIndex &) const
 
 int GrainModel::columnCount(const QModelIndex &) const
 {
-    return Grain::COUNT;
+    return COUNT;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -321,21 +336,24 @@ void GrainModel::sort(int column, Qt::SortOrder order)
     foreach(Grain grain, *list_) {
         QString field;
         switch (column) {
-          case Grain::NAME:
+          case NAME:
               field = grain.name();
               break;
-          case Grain::QUANTITY:
-              field = QString::number(grain.weight().amount()).rightJustified(6,'0');
+          case WEIGHT:
+              field = QString::number(grain.weight().amount()).rightJustified(8,'0');
               break;
-          case Grain::EXTRACT:
-              field = QString::number(grain.extract(),'f',3).rightJustified(6,'0');
+          case EXTRACT:
+              field = QString::number(grain.extract(),'f',3).rightJustified(8,'0');
               break;
-          case Grain::COLOR:
-              field = QString::number(grain.color(),'f',1).rightJustified(6,'0');
+          case COLOR:
+              field = QString::number(grain.color(),'f',1).rightJustified(8,'0');
               break;
-          case Grain::USE:
+          case TYPE:
+              field = grain.type();
+              break;
+          case USE:
           default:
-              field = grain.useString();
+              field = grain.use();
               break;
         }
         sortlist.append(QPair<QString,Grain>(field, grain));
