@@ -42,6 +42,9 @@
 class GrainModel : public QAbstractTableModel {
     Q_OBJECT
 public:
+    // model columns
+    enum { NAME, WEIGHT, EXTRACT, COLOR, TYPE, USE, COUNT };
+
     GrainModel(QObject *parent, GrainList *list);
     ~GrainModel();
 
