@@ -31,6 +31,7 @@ using namespace Resource;
 HelpViewer::HelpViewer(const QString &home, QWidget *parent)
     : QMainWindow(parent), browser_(0), printer_(0)
 {
+    setUnifiedTitleAndToolBarOnMac(true);
     ui.setupUi(this);
 
     browser_ = new QTextBrowser(this);
@@ -85,8 +86,8 @@ HelpViewer::~HelpViewer()
 
 void HelpViewer::textChanged()
 {
-    setWindowTitle(QString("%1 Help - %2")
-                   .arg(TITLE).arg(browser_->documentTitle()));
+    QString title = browser_->documentTitle().simplified(); // cleanup
+    setWindowTitle(tr("%1 Help - %2").arg(TITLE.constData()).arg(title));
 }
 
 //////////////////////////////////////////////////////////////////////////////
