@@ -15,8 +15,7 @@
 #include "data.h"
 #include "hop.h"
 #include "hopdelegate.h"
-
-const int extra = 1; // always display one extra blank row
+#include "hopmodel.h"
 
 HopDelegate::HopDelegate(QObject *parent) : QItemDelegate(parent) {}
 
@@ -31,12 +30,12 @@ QWidget *HopDelegate::createEditor(QWidget *parent,
     QDoubleSpinBox *dspin;
     QString suffix;
     // can only edit name on blank row
-    bool blank = index.row() >= index.model()->rowCount() - extra;
+    bool blank = index.row() >= index.model()->rowCount();
 
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Hop::NAME:
+      case HopModel::NAME:
           combo = new QComboBox(parent);
           combo->setEditable(true);
           combo->addItem(QString());
@@ -44,18 +43,18 @@ QWidget *HopDelegate::createEditor(QWidget *parent,
           combo->installEventFilter(const_cast<HopDelegate*>(this));
           return combo;
 
-      case Hop::QUANTITY:
+      case HopModel::WEIGHT:
           if (blank) return 0;
           dspin = new QDoubleSpinBox(parent);
-          dspin->setDecimals(2);
-          dspin->setRange(0.00, 100.00);
+          dspin->setDecimals(3);
+          dspin->setRange(0.00, 1000.00);
           dspin->setSingleStep(0.25);
           suffix = " " + Data::instance()->defaultHopUnit().symbol();
           dspin->setSuffix(suffix);
           dspin->installEventFilter(const_cast<HopDelegate*>(this));
           return dspin;
 
-      case Hop::ALPHA:
+      case HopModel::ALPHA:
           if (blank) return 0;
           dspin = new QDoubleSpinBox(parent);
           dspin->setDecimals(1);
@@ -65,20 +64,20 @@ QWidget *HopDelegate::createEditor(QWidget *parent,
           dspin->installEventFilter(const_cast<HopDelegate*>(this));
           return dspin;
 
-      case Hop::TIME:
+      case HopModel::TIME:
           if (blank) return 0;
           spin = new QSpinBox(parent);
           spin->setRange(0, 120);
           spin->setSingleStep(5);
-          spin->setSuffix(" min");
+          spin->setSuffix(tr(" min", "minutes"));
           spin->installEventFilter(const_cast<HopDelegate*>(this));
           return spin;
 
-      case Hop::FORM:
+      case HopModel::TYPE:
           if (blank) return 0;
           combo = new QComboBox(parent);
           combo->setEditable(true);
-          combo->addItems(Data::instance()->formsList());
+          combo->addItems(Hop::typeStringList());
           combo->installEventFilter(const_cast<HopDelegate*>(this));
           return combo;
 
@@ -99,7 +98,7 @@ void HopDelegate::setEditorData(QWidget *editor,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Hop::NAME:
+      case HopModel::NAME:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           comboindex = combo->findText(value.toString());
@@ -110,20 +109,20 @@ void HopDelegate::setEditorData(QWidget *editor,
           }
           break;
 
-      case Hop::QUANTITY:
-      case Hop::ALPHA:
+      case HopModel::WEIGHT:
+      case HopModel::ALPHA:
           dspin = static_cast<QDoubleSpinBox*>(editor);
           if (!dspin) return;
           dspin->setValue(value.toDouble());
           break;
 
-      case Hop::TIME:
+      case HopModel::TIME:
           spin = static_cast<QSpinBox*>(editor);
           if (!spin) return;
           spin->setValue(value.toUInt());
           break;
 
-      case Hop::FORM:
+      case HopModel::TYPE:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           comboindex = combo->findText(value.toString());
@@ -150,23 +149,23 @@ void HopDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Hop::NAME:
-      case Hop::FORM:
+      case HopModel::NAME:
+      case HopModel::TYPE:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           value = combo->currentText();
           model->setData(index, value);
           break;
 
-      case Hop::QUANTITY:
-      case Hop::ALPHA:
+      case HopModel::WEIGHT:
+      case HopModel::ALPHA:
           dspin = static_cast<QDoubleSpinBox*>(editor);
           if (!dspin) return;
           value = dspin->value();
           model->setData(index, value);
           break;
 
-      case Hop::TIME:
+      case HopModel::TIME:
           spin = static_cast<QSpinBox*>(editor);
           if (!spin) return;
           value = spin->value();
