@@ -14,6 +14,8 @@
 #include "data.h"
 #include "hopmodel.h"
 
+using namespace Resource;
+
 //////////////////////////////////////////////////////////////////////////////
 // HopModel()
 // ------------
@@ -51,46 +53,46 @@ QVariant HopModel::data(const QModelIndex &index, int role) const
     // column is the hop "field"
     if (role == Qt::DisplayRole) {
         switch (index.column()) {
-          case Hop::NAME:
+          case NAME:
               return hop.name();
-          case Hop::QUANTITY:
-              return hop.weight().toString(2);
-          case Hop::ALPHA:
+          case WEIGHT:
+              return hop.weight().toString(3);
+          case ALPHA:
               return QString::number(hop.alpha(), 'f', 1) + '%';
-          case Hop::TIME:
-              return QString::number(hop.time()) + " min";
-          case Hop::FORM:
-              return hop.form();
+          case TIME:
+              return QString::number(hop.time()) + tr(" min", "minutes");
+          case TYPE:
+              return hop.type();
           default:
               return QVariant();
         }
     } else if (role == Qt::EditRole) {
         switch (index.column()) {
-          case Hop::NAME:
+          case NAME:
               return hop.name();
-          case Hop::QUANTITY: {
+          case WEIGHT: {
               // return converted quantity
               Weight weight = hop.weight();
               weight.convert(Data::instance()->defaultHopUnit());
               return weight.amount();
           }
-          case Hop::ALPHA:
+          case ALPHA:
               return hop.alpha();
-          case Hop::TIME:
+          case TIME:
               return hop.time();
-          case Hop::FORM:
-              return hop.form();
+          case TYPE:
+              return hop.type();
           default:
               return QVariant();
         }
     } else if (role == Qt::TextAlignmentRole) {
         switch (index.column()) {
-          case Hop::NAME:
-          case Hop::FORM:
+          case NAME:
+          case TYPE:
               return Qt::AlignLeft;
-          case Hop::QUANTITY:
-          case Hop::ALPHA:
-          case Hop::TIME:
+          case WEIGHT:
+          case ALPHA:
+          case TIME:
           default:
               return Qt::AlignRight;
         }
@@ -122,7 +124,7 @@ bool HopModel::setData(const QModelIndex &index,
     if (row < list_->count()) hop = list_->value(row);
 
     switch (column) {
-      case Hop::NAME:
+      case NAME:
           // editing name as several special cases
           name = value.toString();
 
@@ -135,10 +137,10 @@ bool HopModel::setData(const QModelIndex &index,
               deleting = true;
 
               int status = QMessageBox::question(QApplication::activeWindow(),
-                               Resource::TITLE + " - Delete?",
-                               "Do you wish to remove this entry?",
-                               "Remove", "Cancel");
-              if (status == 0) {
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+              if (status == QMessageBox::Yes) {
                   // remove hop
                   beginRemoveRows(index.parent(), row, row);
 
@@ -165,26 +167,26 @@ bool HopModel::setData(const QModelIndex &index,
           if (Data::instance()->hasHop(name)) {
               Hop newhop = Data::instance()->hop(name);
               // we don't override weight or time
-              hop.setForm(newhop.form());
+              hop.setType(newhop.type());
               hop.setAlpha(newhop.alpha());
           }
           break;
 
-      case Hop::QUANTITY:
+      case WEIGHT:
           hop.setWeight(Weight(value.toDouble(),
                                Data::instance()->defaultHopUnit()));
           break;
 
-      case Hop::ALPHA:
+      case ALPHA:
           hop.setAlpha(value.toDouble());
           break;
 
-      case Hop::TIME:
+      case TIME:
           hop.setTime(value.toUInt());
           break;
 
-      case Hop::FORM:
-          hop.setForm(value.toString());
+      case TYPE:
+          hop.setType(value.toString());
           break;
 
       default:
@@ -195,8 +197,8 @@ bool HopModel::setData(const QModelIndex &index,
     emit modified();
 
     // whole row may have changed
-    emit dataChanged(index.sibling(row, Hop::NAME),
-                     index.sibling(row, Hop::TIME));
+    emit dataChanged(index.sibling(row, NAME),
+                     index.sibling(row, TIME));
 
     return true;
 }
@@ -211,7 +213,7 @@ bool HopModel::insertRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only insert one row at a time
     if ((row < 0) || (row >= list_->count())) row = list_->count();
 
-    Hop hop = Data::instance()->hop("Generic");
+    Hop hop = Data::instance()->hop(tr("Generic"));
 
     beginInsertRows(QModelIndex(), row, row);
     list_->insert(row, hop);
@@ -230,10 +232,11 @@ bool HopModel::removeRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only remove one row at a time
     if ((row < 0) || (row >= list_->count())) return false;
 
-    if (QMessageBox::question(QApplication::activeWindow(),
-                              Resource::TITLE + " - Delete?",
-                              "Do you wish to remove this entry?",
-                              "Remove", "Cancel")) {
+    int status = QMessageBox::question(QApplication::activeWindow(),
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+    if (status == QMessageBox::Cancel) {
         return false;
     }
 
@@ -254,16 +257,16 @@ QVariant HopModel::headerData(int section, Qt::Orientation orientation,
 {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-          case Hop::NAME:
-              return "Hop";
-          case Hop::QUANTITY:
-              return "Quantity";
-          case Hop::ALPHA:
-              return "Alpha";
-          case Hop::TIME:
-              return "Time";
-          case Hop::FORM:
-              return "Form";
+          case NAME:
+              return tr("Hop");
+          case WEIGHT:
+              return tr("Weight");
+          case ALPHA:
+              return tr("Alpha");
+          case TIME:
+              return tr("Time");
+          case TYPE:
+              return tr("Type");
           default:
               return QVariant();
         }
@@ -301,7 +304,7 @@ int HopModel::rowCount(const QModelIndex &) const
 
 int HopModel::columnCount(const QModelIndex &) const
 {
-    return Hop::COUNT;
+    return COUNT;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -316,21 +319,21 @@ void HopModel::sort(int column, Qt::SortOrder order)
     foreach(Hop hop, *list_) {
         QString field;
         switch (column) {
-          case Hop::NAME:
+          case NAME:
               field = hop.name();
               break;
-          case Hop::QUANTITY:
-              field = QString::number(hop.weight().amount()).rightJustified(6,'0');
+          case WEIGHT:
+              field = QString::number(hop.weight().amount()).rightJustified(8,'0');
               break;
-          case Hop::ALPHA:
-              field = QString::number(hop.alpha(),'f',1).rightJustified(6,'0');
+          case ALPHA:
+              field = QString::number(hop.alpha(),'f',1).rightJustified(8,'0');
               break;
-          case Hop::FORM:
-              field = hop.form();
+          case TYPE:
+              field = hop.type();
               break;
-          case Hop::TIME:
+          case TIME:
           default:
-              field = QString::number(hop.time()).rightJustified(6,'0');
+              field = QString::number(hop.time()).rightJustified(8,'0');
               break;
         }
         sortlist.append(QPair<QString,Hop>(field, hop));
