@@ -42,6 +42,9 @@
 class HopModel : public QAbstractTableModel {
     Q_OBJECT
 public:
+    // model columns
+    enum { NAME, WEIGHT, ALPHA, TIME, TYPE, COUNT };
+
     HopModel(QObject *parent, HopList *list);
     ~HopModel();
 
