@@ -11,8 +11,11 @@
 #include <QLabel>
 
 #include "resource.h"
+#include "data.h"
 #include "hydrometertool.h"
 
+using Resource::TITLE;
+
 //////////////////////////////////////////////////////////////////////////////
 // HydrometerTool()
 // ----------------
@@ -23,11 +26,11 @@ HydrometerTool:: HydrometerTool(QWidget* parent)
 {
     ui.setupUi(this);
 
-    // TODO: use appropriate units (F or C)
-    QString SUFFIX(Resource::DEGREE);
-    SUFFIX += " F";
+    QString SUFFIX = QString(" %1%2")
+        .arg(Resource::DEGREE)
+        .arg(Data::instance()->defaultTempUnit().symbol());
 
-    setWindowTitle(Resource::TITLE + " - Hydrometer Tool");
+    setWindowTitle(TITLE + tr(" - Hydrometer Tool"));
 
     // additional setup
     QFont fnt(font());
@@ -37,6 +40,16 @@ HydrometerTool:: HydrometerTool(QWidget* parent)
     ui.calibrated->setSuffix(SUFFIX);
     ui.sample->setSuffix(SUFFIX);
 
+    // convert UI properties of celsius
+    if (Data::instance()->defaultTempUnit() == Temperature::celsius) {
+        ui.calibrated->setMinimum(0.0);
+        ui.calibrated->setMaximum(100.0);
+        ui.calibrated->setValue(15.0);
+        ui.sample->setMinimum(0.0);
+        ui.sample->setMaximum(100.0);
+        ui.sample->setValue(15.0);
+    }
+
     // connections
     connect(ui.sample, SIGNAL(valueChanged(double)), this, SLOT(recalc()));
     connect(ui.calibrated, SIGNAL(valueChanged(double)), this, SLOT(recalc()));
@@ -61,10 +74,17 @@ void HydrometerTool::recalc()
 
     double calterm;   // E is the correction factor for the calibration temp
     double corr;      // the corrected reading
-    double temp = ui.sample->value();
+
+    double samp = ui.sample->value();
     double cal = ui.calibrated->value();
     double read = ui.reading->value();
 
+    // calc needs to be in fahrenheit
+    if (Data::instance()->defaultTempUnit() == Temperature::celsius) {
+        samp = celsius2fahrenheit(samp);
+        cal = celsius2fahrenheit(cal);
+    }
+
     // Correction(@59F) = 1.313454 - 0.132674*T + 2.057793e-3*T**2 - 2.627634e-6*T**3
     // the equation is set up for 59F (15C)
     calterm = (COEFF1
@@ -72,9 +92,9 @@ void HydrometerTool::recalc()
                + (COEFF3 * (cal*cal))
                - (COEFF4 * (cal*cal*cal)));
     corr = (COEFF1
-            - (COEFF2 * temp)
-            + (COEFF3 * (temp*temp))
-            - (COEFF4 * (temp*temp*temp))) - calterm;
+            - (COEFF2 * samp)
+            + (COEFF3 * (samp*samp))
+            - (COEFF4 * (samp*samp*samp))) - calterm;
 
     corr /= 1000.0;
     corr = 1.0 - corr;
