@@ -31,11 +31,14 @@
 ****************************************************************************/
 
 #include <cstdlib>
-#include <iostream>
 
 #include <QApplication>
+#include <QLibraryInfo>
+#include <QLocale>
 #include <QMainWindow>
 #include <QStringList>
+#include <QTextStream>
+#include <QTranslator>
 
 #if defined(Q_WS_MACX)
 extern void qt_mac_set_menubar_icons(bool enable);
@@ -52,14 +55,14 @@ using namespace Resource;
 // -----------
 // Print out copyright and version info to stdout
 
-void doversion()
+void doversion(QTextStream &stream)
 {
-    cout << PACKAGE << ' ' << VERSION << '\n';
-    cout << qPrintable(DESCRIPTION) << '\n';
-    cout << qPrintable(COPYRIGHT);
-    cout << ' ' << qPrintable(AUTHOR);
-    cout << " <" << qPrintable(AUTHOR_EMAIL) << ">";
-    cout << endl;
+    stream << PACKAGE << ' ' << VERSION << '\n';
+    stream << QObject::tr(DESCRIPTION) << '\n';
+    stream << QObject::tr(COPYRIGHT);
+    stream << ' ' << AUTHOR;
+    stream << " <" << AUTHOR_EMAIL << ">";
+    stream << endl;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -67,20 +70,20 @@ void doversion()
 // --------
 // Print out help info to stdout
 
-void dohelp()
+void dohelp(QTextStream &stream)
 {
-    cout << "Usage: " << PACKAGE << " [options] [file]\n";
-    cout << qPrintable(DESCRIPTION) << '\n';
+    stream << QObject::tr("Usage: %1 [options] [file]\n").arg(PACKAGE);
+    stream << QObject::tr(DESCRIPTION) << "\n\n";
 
     // arguments
-    cout << "\nArguments:\n";
-    cout << "    file                  File to open\n";
+    stream << QObject::tr("Arguments\n");
+    stream << QObject::tr("    file                  File to open") << "\n\n";
 
     // general options
-    cout << "\nOptions\n";
-    cout << "    --help                Print the command line options.\n";
-    cout << "    --version             Print the application version.\n";
-    cout << endl;
+    stream << QObject::tr("Options\n");
+    stream << QObject::tr("    --help                Print the command line options.\n");
+    stream << QObject::tr("    --version             Print the application version.\n");
+    stream << endl;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -88,30 +91,30 @@ void dohelp()
 // --------
 // Process the arguments that QApplication doesn't take care of
 
-QString doargs(QStringList arguments)
+QString doargs(QStringList arguments, QTextStream &stream)
 {
     QString arg;
     for (int n=1; n<arguments.count(); ++n) {
         arg = arguments.at(n);
         if ((arg == "-h")  || (arg == "-help") ||
             (arg == "--help")) {
-            dohelp();
+            dohelp(stream);
             exit(0);
         } else if ((arg == "-v") || (arg == "-version") ||
                    (arg == "--version")) {
-            doversion();
+            doversion(stream);
             exit(0);
         } else if (arg[0] == '-') {
             // no other valid options
-            cout << "Invalid parameter \"" << qPrintable(arg) << "\"\n";
-            dohelp();
+            stream << QObject::tr("Invalid parameter \"%1\"\n") .arg(arg);
+            dohelp(stream);
             exit(1);
         } else {
             // it must be a filename
             return arg;
         }
     }
-    return (DEFAULT_FILE);
+    return (QObject::tr(DEFAULT_FILE));
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -130,8 +133,22 @@ int main(int argc, char **argv)
     qt_mac_set_menubar_icons(false);
 #endif
 
+    // load qbrew translations
+    QString transdir = QBrew::instance()->dataBase() + "translations";
+    QTranslator translator;
+    if (translator.load("qbrew_" + QLocale::system().name(), transdir)) {
+        app.installTranslator(&translator);
+    }
+    // load qt translations
+    QString qttransdir = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+    QTranslator qttranslator;
+    if (qttranslator.load("qt_" + QLocale::system().name(), qttransdir)) {
+        app.installTranslator(&qttranslator);
+    }
+
     // check for additional command line arguments
-    QString filename = doargs(app.arguments());
+    QTextStream stream(stdout);
+    QString filename = doargs(app.arguments(), stream);
 
     QBrew* mainwindow = QBrew::instance();
     mainwindow->initialize(filename);
