@@ -40,14 +40,20 @@
 
 class Misc {
 public:
-    // fields (columns in view)
-    enum { NAME, QUANTITY, NOTES, COUNT };
+    // misc strings
+    static const QByteArray YEAST_STRING;
+    static const QByteArray FINING_STRING;
+    static const QByteArray HERB_STRING;
+    static const QByteArray SPICE_STRING;
+    static const QByteArray FLAVOR_STRING;
+    static const QByteArray ADDITIVE_STRING;
+    static const QByteArray OTHER_STRING;
 
     // default constructor
     Misc();
     // full constructor
     Misc(const QString &name, const Quantity &quantity,
-         const QString &notes);
+         const QString &typ, const QString &notes);
     // copy constructor
     Misc(const Misc &m);
     // assignment operator
@@ -64,13 +70,20 @@ public:
     // get/set quantity
     const Quantity &quantity() const;
     void setQuantity(const Quantity &quantity);
+    // get/set type
+    const QString &type() const;
+    void setType(const QString &typ);
     // get/set notes
     const QString &notes() const;
     void setNotes(const QString &notes);
 
+    // list of misc type
+    static QStringList typeStringList();
+
 private:
     QString name_;
     Quantity quantity_;
+    QString type_;
     QString notes_;
 };
 
@@ -90,6 +103,10 @@ inline void Misc::setQuantity(const Quantity &quantity) { quantity_ = quantity;
 
 inline const Quantity &Misc::quantity() const { return quantity_; }
 
+inline void Misc::setType(const QString &typ) { type_ = typ; }
+
+inline const QString &Misc::type() const  { return type_; }
+
 inline void Misc::setNotes(const QString &notes) { notes_ = notes; }
 
 inline const QString &Misc::notes() const{ return notes_; }
