@@ -15,8 +15,7 @@
 #include "data.h"
 #include "misc.h"
 #include "miscdelegate.h"
-
-const int extra = 1; // always display one extra blank row
+#include "miscmodel.h"
 
 MiscDelegate::MiscDelegate(QObject *parent) : QItemDelegate(parent) {}
 
@@ -32,11 +31,11 @@ QWidget *MiscDelegate::createEditor(QWidget *parent,
     QString suffix;
 
     // can only edit name on blank row
-    bool blank = index.row() >= index.model()->rowCount() - extra;
+    bool blank = index.row() >= index.model()->rowCount();
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Misc::NAME:
+      case MiscModel::NAME:
           combo = new QComboBox(parent);
           combo->setEditable(true);
           combo->addItem(QString());
@@ -44,18 +43,25 @@ QWidget *MiscDelegate::createEditor(QWidget *parent,
           combo->installEventFilter(const_cast<MiscDelegate*>(this));
           return combo;
 
-      case Misc::QUANTITY:
+      case MiscModel::QUANTITY:
           if (blank) return 0;
           spin = new QDoubleSpinBox(parent);
-          spin->setDecimals(2);
-          spin->setRange(0.00, 100.00);
+          spin->setDecimals(3);
+          spin->setRange(0.00, 1000.00);
           spin->setSingleStep(0.25);
           suffix = " " + Data::instance()->defaultMiscUnit().symbol();
           spin->setSuffix(suffix);
           spin->installEventFilter(const_cast<MiscDelegate*>(this));
           return spin;
 
-      case Misc::NOTES:
+      case MiscModel::TYPE:
+          combo = new QComboBox(parent);
+          combo->setEditable(false);
+          combo->addItems(Misc::typeStringList());
+          combo->installEventFilter(const_cast<MiscDelegate*>(this));
+          return combo;
+
+      case MiscModel::NOTES:
           if (blank) return 0;
           edit = new QLineEdit(parent);
           edit->installEventFilter(const_cast<MiscDelegate*>(this));
@@ -78,7 +84,7 @@ void MiscDelegate::setEditorData(QWidget *editor,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Misc::NAME:
+      case MiscModel::NAME:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           comboindex = combo->findText(value.toString());
@@ -89,18 +95,24 @@ void MiscDelegate::setEditorData(QWidget *editor,
           }
           break;
 
-      case Misc::QUANTITY:
+      case MiscModel::QUANTITY:
           spin = static_cast<QDoubleSpinBox*>(editor);
           if (!spin) return;
           spin->setValue(value.toDouble());
           break;
 
-      case Misc::NOTES:
+      case MiscModel::NOTES:
           edit = static_cast<QLineEdit*>(editor);
           if (!edit) return;
           edit->setText(value.toString());
           break;
 
+      case MiscModel::TYPE:
+          combo = static_cast<QComboBox*>(editor);
+          if (!combo) return;
+          combo->setCurrentIndex(combo->findText(value.toString()));
+          break;
+
       default:
           QItemDelegate::setEditorData(editor, index);
           break;
@@ -117,21 +129,22 @@ void MiscDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Misc::NAME:
+      case MiscModel::NAME:
+      case MiscModel::TYPE:
           combo = static_cast<QComboBox*>(editor);
           if (!combo) return;
           value = combo->currentText();
           model->setData(index, value);
           break;
 
-      case Misc::NOTES:
+      case MiscModel::NOTES:
           edit = static_cast<QLineEdit*>(editor);
           if (!edit) return;
           value = edit->text();
           model->setData(index, value);
           break;
 
-      case Misc::QUANTITY:
+      case MiscModel::QUANTITY:
           spin = static_cast<QDoubleSpinBox*>(editor);
           if (!spin) return;
           value = spin->value();
