@@ -14,6 +14,8 @@
 #include "data.h"
 #include "miscmodel.h"
 
+using namespace Resource;
+
 //////////////////////////////////////////////////////////////////////////////
 // MiscModel()
 // ------------
@@ -51,36 +53,41 @@ QVariant MiscModel::data(const QModelIndex &index, int role) const
     // column is the ingredient "field"
     if (role == Qt::DisplayRole) {
         switch (index.column()) {
-          case Misc::NAME:
+          case NAME:
               return misc.name();
-          case Misc::QUANTITY:
-              return misc.quantity().toString(2);
-          case Misc::NOTES:
+          case QUANTITY:
+              return misc.quantity().toString(3);
+          case TYPE:
+              return misc.type();
+          case NOTES:
               return misc.notes();
           default:
               return QVariant();
         }
     } else if (role == Qt::EditRole) {
         switch (index.column()) {
-          case Misc::NAME:
+          case NAME:
               return misc.name();
-          case Misc::QUANTITY: {
+          case QUANTITY: {
               // return converted quantity
               Quantity quantity = misc.quantity();
               quantity.convert(Data::instance()->defaultMiscUnit());
               return quantity.amount();
           }
-          case Misc::NOTES:
+          case TYPE:
+              return misc.type();
+          case NOTES:
               return misc.notes();
           default:
               return QVariant();
         }
     } else if (role == Qt::TextAlignmentRole) {
         switch (index.column()) {
-          case Misc::NAME:
-          case Misc::NOTES:
+          case NAME:
+          case TYPE:
+          case NOTES:
               return Qt::AlignLeft;
-          case Misc::QUANTITY:
+          case QUANTITY:
           default:
               return Qt::AlignRight;
         }
@@ -112,7 +119,7 @@ bool MiscModel::setData(const QModelIndex &index,
     if (row < list_->count()) misc = list_->value(row);
 
     switch (column) {
-      case Misc::NAME:
+      case NAME:
           // editing name as several special cases
           name = value.toString();
 
@@ -125,10 +132,10 @@ bool MiscModel::setData(const QModelIndex &index,
               deleting = true;
 
               int status = QMessageBox::question(QApplication::activeWindow(),
-                               Resource::TITLE + " - Delete?",
-                               "Do you wish to remove this entry?",
-                               "Remove", "Cancel");
-              if (status == 0) {
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+              if (status == QMessageBox::Yes) {
                   // remove misc
                   beginRemoveRows(index.parent(), row, row);
 
@@ -155,16 +162,21 @@ bool MiscModel::setData(const QModelIndex &index,
           if (Data::instance()->hasMisc(name)) {
               Misc newmisc = Data::instance()->misc(name);
               // we don't override weight
+              misc.setType(newmisc.type());
               misc.setNotes(newmisc.notes());
           }
           break;
 
-      case Misc::QUANTITY:
+      case QUANTITY:
           misc.setQuantity(Quantity(value.toDouble(),
                                     Data::instance()->defaultMiscUnit()));
           break;
 
-      case Misc::NOTES:
+      case TYPE:
+          misc.setType(value.toString());
+          break;
+
+      case NOTES:
           misc.setNotes(value.toString());
           break;
 
@@ -176,8 +188,8 @@ bool MiscModel::setData(const QModelIndex &index,
     emit modified();
 
     // whole row may have changed
-    emit dataChanged(index.sibling(row, Misc::NAME),
-                     index.sibling(row, Misc::NOTES));
+    emit dataChanged(index.sibling(row, NAME),
+                     index.sibling(row, NOTES));
 
     return true;
 }
@@ -192,7 +204,7 @@ bool MiscModel::insertRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only insert one row at a time
     if ((row < 0) || (row >= list_->count())) row = list_->count();
 
-    Misc misc = Data::instance()->misc("Generic");
+    Misc misc = Data::instance()->misc(tr("Generic"));
 
     beginInsertRows(QModelIndex(), row, row);
     list_->insert(row, misc);
@@ -211,10 +223,11 @@ bool MiscModel::removeRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only remove one row at a time
     if ((row < 0) || (row >= list_->count())) return false;
 
-    if (QMessageBox::question(QApplication::activeWindow(),
-                              Resource::TITLE + " - Delete?",
-                              "Do you wish to remove this entry?",
-                              "Remove", "Cancel")) {
+    int status = QMessageBox::question(QApplication::activeWindow(),
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+    if (status == QMessageBox::Cancel) {
         return false;
     }
 
@@ -235,12 +248,14 @@ QVariant MiscModel::headerData(int section, Qt::Orientation orientation,
 {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-          case Misc::NAME:
-              return "Misc";
-          case Misc::QUANTITY:
-              return "Quantity";
-          case Misc::NOTES:
-              return "Notes";
+          case NAME:
+              return tr("Misc");
+          case QUANTITY:
+              return tr("Quantity");
+          case TYPE:
+              return tr("Type");
+          case NOTES:
+              return tr("Notes");
           default:
               return QVariant();
         }
@@ -278,7 +293,7 @@ int MiscModel::rowCount(const QModelIndex &) const
 
 int MiscModel::columnCount(const QModelIndex &) const
 {
-    return Misc::COUNT;
+    return COUNT;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -293,13 +308,16 @@ void MiscModel::sort(int column, Qt::SortOrder order)
     foreach(Misc misc, *list_) {
         QString field;
         switch (column) {
-          case Misc::NAME:
+          case NAME:
               field = misc.name();
               break;
-          case Misc::QUANTITY:
-              field = QString::number(misc.quantity().amount()).rightJustified(6,'0');
+          case QUANTITY:
+              field = QString::number(misc.quantity().amount()).rightJustified(8,'0');
               break;
-          case Misc::NOTES:
+          case TYPE:
+              field = misc.type();
+              break;
+          case NOTES:
           default:
               field = misc.notes();
               break;
