@@ -42,6 +42,9 @@
 class MiscModel : public QAbstractTableModel {
     Q_OBJECT
 public:
+    // model columns
+    enum { NAME, QUANTITY, TYPE, NOTES, COUNT };
+
     MiscModel(QObject *parent, MiscList *list);
     ~MiscModel();
 
