@@ -17,6 +17,7 @@
 #include "helpviewer.h"
 #include "hydrometertool.h"
 #include "resource.h"
+#include "textprinter.h"
 #include "view.h"
 
 #include "qbrew.h"
@@ -39,7 +40,7 @@ QBrew::QBrew()
     : data_(0), recipe_(0), view_(0), alcoholtool_(0), databasetool_(0),
       hydrometertool_(0), configure_(0), handbook_(0), primer_(0), state_(),
       filename_(), newflag_(false), backed_(false), autosave_(0),
-      autosavename_(), printer_(0)
+      autosavename_(), textprinter_(0)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -54,8 +55,8 @@ void QBrew::initialize(const QString &filename)
 
     // show splashscreen
     if (state_.general.showsplash
-        && QFile::exists(dataBase() + "splash.png")) {
-      QSplashScreen *splash  = new QSplashScreen(dataBase() + "splash.png",
+        && QFile::exists(dataBase() + tr("splash.png"))) {
+        QSplashScreen *splash = new QSplashScreen(dataBase() + tr("splash.png"),
 						 Qt::WindowStaysOnTopHint);
         splash->show();
         QApplication::flush();
@@ -72,6 +73,11 @@ void QBrew::initialize(const QString &filename)
     // setup UI
     ui.setupUi(this);
     initActions();
+#if defined (Q_WS_MAC)
+    // initial defaults for mac
+    setUnifiedTitleAndToolBarOnMac(false);
+    ui.maintoolbar->setVisible(false);
+#endif
 
     // restore window state
     restoreState();
@@ -81,7 +87,7 @@ void QBrew::initialize(const QString &filename)
     data_->initialize(state_);
 
     // initialize calculations
-    data_->setEfficiency(state_.calc.efficiency);
+    data_->setSteepYield(state_.calc.steepyield);
     data_->setTinseth(state_.calc.tinseth);
     data_->setMorey(state_.calc.morey);
 
@@ -93,7 +99,8 @@ void QBrew::initialize(const QString &filename)
     view_ = new View(this, recipe_);
 
     // load or create a recipe
-    bool emptyfilename = (filename.isEmpty() || (filename == DEFAULT_FILE));
+    bool emptyfilename = (filename.isEmpty() ||
+                          (filename == tr(DEFAULT_FILE)));
     if (emptyfilename &&
         (state_.general.loadlast && !state_.general.recentfiles.isEmpty())) {
         if (QFile::exists(state_.general.recentfiles.first())) {
@@ -102,14 +109,15 @@ void QBrew::initialize(const QString &filename)
     } else {
         filename_ = filename;
     }
-    emptyfilename = (filename_.isEmpty() || (filename_ == DEFAULT_FILE));
+    emptyfilename = (filename_.isEmpty() ||
+                     (filename_ == tr(DEFAULT_FILE)));
     if (!emptyfilename) {
         openFile(filename_);
     } else {
         recipe_->newRecipe();
         newflag_ = true;
         backed_ = false;
-        filename_ = DEFAULT_FILE + "." + FILE_EXT;
+        filename_ = tr(DEFAULT_FILE) + "." + FILE_EXT;
         setWindowTitle(TITLE + " " + VERSION + " [*]");
     }
 
@@ -121,6 +129,7 @@ void QBrew::initialize(const QString &filename)
     initAutoSave();
     setCentralWidget(view_);
     view_->refresh();
+    textprinter_ = new TextPrinter(this);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -162,27 +171,48 @@ QBrew *QBrew::instance()
 
 void QBrew::initActions()
 {
-    connect(ui.actionfilenew, SIGNAL(triggered()), this, SLOT(fileNew()));
-    connect(ui.actionfileopen, SIGNAL(triggered()), this,  SLOT(fileOpen()));
-    connect(ui.actionfilesave, SIGNAL(triggered()), this, SLOT(fileSave()));
-    connect(ui.actionfilesaveas, SIGNAL(triggered()), this, SLOT(fileSaveAs()));
-    connect(ui.actionfileprint, SIGNAL(triggered()), this, SLOT(filePrint()));
-    connect(ui.actionfileexport, SIGNAL(triggered()), this, SLOT(fileExport()));
-    connect(ui.actionexit, SIGNAL(triggered()), qApp, SLOT(closeAllWindows()));
+    connect(ui.actionfilenew, SIGNAL(triggered()),
+            this, SLOT(fileNew()));
+    connect(ui.actionfileopen, SIGNAL(triggered()),
+            this,  SLOT(fileOpen()));
+    connect(ui.actionfilesave, SIGNAL(triggered()),
+            this, SLOT(fileSave()));
+    connect(ui.actionfilesaveas, SIGNAL(triggered()),
+            this, SLOT(fileSaveAs()));
+    // TODO: disable for now...
+    ui.actionfileprintpreview->setVisible(false);
+    // connect(ui.actionfileprintpreview, SIGNAL(triggered()),
+    //        this, SLOT(filePrintPreview()));
+    connect(ui.actionfileprint, SIGNAL(triggered()),
+            this, SLOT(filePrint()));
+    connect(ui.actionfileexport, SIGNAL(triggered()),
+            this, SLOT(fileExport()));
+    connect(ui.actionexit, SIGNAL(triggered()), qApp,
+            SLOT(closeAllWindows()));
 
-    connect(ui.actionalcoholtool, SIGNAL(triggered()), this, SLOT(toolsAlcohol()));
-    connect(ui.actionhydrometertool, SIGNAL(triggered()), this, SLOT(toolsHydrometer()));
-    connect(ui.actiondatabasetool, SIGNAL(triggered()), this, SLOT(toolsDatabase()));
+    connect(ui.actionalcoholtool, SIGNAL(triggered()),
+            this, SLOT(toolsAlcohol()));
+    connect(ui.actionhydrometertool, SIGNAL(triggered()),
+            this, SLOT(toolsHydrometer()));
+    connect(ui.actiondatabasetool, SIGNAL(triggered()),
+            this, SLOT(toolsDatabase()));
 
-    connect(ui.actiontogglestatusbar, SIGNAL(toggled(bool)), this, SLOT(optionsStatusbar(bool)));
-    connect(ui.actionconfigure, SIGNAL(triggered()), this, SLOT(optionsConfigure()));
+    connect(ui.actiontogglestatusbar, SIGNAL(toggled(bool)),
+            this, SLOT(optionsStatusbar(bool)));
+    connect(ui.actionconfigure, SIGNAL(triggered()),
+            this, SLOT(optionsConfigure()));
 
-    connect(ui.actionhelpcontents, SIGNAL(triggered()), this, SLOT(helpContents()));
-    connect(ui.actionprimer, SIGNAL(triggered()), this, SLOT(helpPrimer()));
-    connect(ui.actioncontexthelp, SIGNAL(triggered()), this, SLOT(helpContext()));
+    connect(ui.actionhelpcontents, SIGNAL(triggered()),
+            this, SLOT(helpContents()));
+    connect(ui.actionprimer, SIGNAL(triggered()),
+            this, SLOT(helpPrimer()));
+    connect(ui.actioncontexthelp, SIGNAL(triggered()),
+            this, SLOT(helpContext()));
     connect(ui.actionabout, SIGNAL(triggered()), this, SLOT(helpAbout()));
 
     // insert toolbar toggle action
+    ui.maintoolbar->toggleViewAction()->setStatusTip(tr("Toggle the toolbar"));
+    ui.maintoolbar->toggleViewAction()->setWhatsThis(tr("Enable or disable the Toolbar"));
     ui.menuoptions->insertAction(ui.actiontogglestatusbar,
                                  ui.maintoolbar->toggleViewAction());
 }
@@ -201,8 +231,7 @@ void QBrew::initAutoSave()
         delete autosave_; autosave_ = 0;
     }
 
-    autosavename_ = QDir::currentPath()
-        + QString("/autosave.%1").arg(FILE_EXT);
+    autosavename_ = QDir::currentPath() + tr("/autosave.") + FILE_EXT;
 
     if (state_.general.autosave) {
         autosave_ = new QTimer(this);
@@ -231,7 +260,7 @@ void QBrew::fileNew()
           case QMessageBox::No:
               break;
           case QMessageBox::Cancel:
-              statusBar()->showMessage("Canceled...", 2000);
+              statusBar()->showMessage(tr("Canceled..."), 2000);
               // exit function
               return;
         }
@@ -244,9 +273,9 @@ void QBrew::fileNew()
 
     ui.actionfilesave->setEnabled(true);
 
-    filename_ = DEFAULT_FILE;
+    filename_ = tr(DEFAULT_FILE);
     setFileCaption(filename_);
-    statusBar()->showMessage("Created new recipe", 2000);
+    statusBar()->showMessage(tr("Created new recipe"), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -265,26 +294,26 @@ void QBrew::fileOpen(const QString &filename)
           case QMessageBox::No:
               break;
           case QMessageBox::Cancel:
-              statusBar()->showMessage("Canceled...", 2000);
+              statusBar()->showMessage(tr("Canceled..."), 2000);
               return;
         }
     }
 
     // open the file
-    statusBar()->showMessage("Opening recipe...");
+    statusBar()->showMessage(tr("Opening recipe..."));
     QString fname;
     if (filename.isEmpty()) {
         fname = QFileDialog::getOpenFileName(this,
-                                             "Open...",
+                                             tr("Open..."),
                                              QString(),
-                                             OPEN_FILTER);
+                                             tr(OPEN_FILTER));
     } else {
         fname = filename;
     }
     if (openFile(fname)) {
-        statusBar()->showMessage("Loaded recipe", 2000);
+        statusBar()->showMessage(tr("Loaded recipe"), 2000);
     } else {
-        statusBar()->showMessage("Load failed", 2000);
+        statusBar()->showMessage(tr("Load failed"), 2000);
     }
 }
 
@@ -307,7 +336,7 @@ void QBrew::fileRecent()
           case QMessageBox::No:
               break;
           case QMessageBox::Cancel:
-              statusBar()->showMessage("Canceled...", 2000);
+              statusBar()->showMessage(tr("Canceled..."), 2000);
               return;
         }
     }
@@ -315,7 +344,7 @@ void QBrew::fileRecent()
     // open the file
     QString fname = action->text();
     if (openFile(fname)) {
-        statusBar()->showMessage("Loaded recipe", 2000);
+        statusBar()->showMessage(tr("Loaded recipe"), 2000);
         addRecent(fname);
     }
 }
@@ -333,7 +362,7 @@ void QBrew::fileSave()
         if (state_.general.autobackup) {
             if (!backupFile())
                 QMessageBox::warning(this, TITLE,
-                    QString("%1 was unable to make a backup of %2")
+                    tr("%1 was unable to make a backup of %2")
                                      .arg(PACKAGE).arg(filename_));
         }
         if (saveFile(filename_)) {
@@ -341,13 +370,13 @@ void QBrew::fileSave()
             newflag_ = false;
             ui.actionfilesave->setEnabled(false);
             setFileCaption(filename_);
-            statusBar()->showMessage("Saved recipe", 2000);
+            statusBar()->showMessage(tr("Saved recipe"), 2000);
         } else {
             // error in saving file
             QMessageBox::warning(this, TITLE,
-                                 QString("%1 was unable to save %2")
+                                 tr("%1 was unable to save %2")
                                  .arg(PACKAGE).arg(filename_));
-            statusBar()->showMessage("Error in saving recipe", 2000);
+            statusBar()->showMessage(tr("Error in saving recipe"), 2000);
         }
     }
 }
@@ -359,11 +388,15 @@ void QBrew::fileSave()
 
 void QBrew::fileSaveAs()
 {
-    statusBar()->showMessage("Saving recipe under new filename...");
-    QString fname = QFileDialog::getSaveFileName(this,
-                                                 "Save As...",
-                                                 QString(),
-                                                 SAVE_FILTER);
+    statusBar()->showMessage(tr("Saving recipe under new filename..."));
+    QString selected;
+    QString fname;
+    fname = QFileDialog::getSaveFileName(this,
+                                         tr("Save As..."),
+                                         QString(),
+                                         tr(SAVE_FILTER),
+                                         &selected,
+                                         QFileDialog::DontConfirmOverwrite);
     if (!fname.isEmpty()) { // we got a filename
         // add suffix if there is none
         if (!QFile::exists(fname)) {
@@ -377,7 +410,7 @@ void QBrew::fileSaveAs()
               case QMessageBox::Yes:
                   break;
               case QMessageBox::Cancel:
-                  statusBar()->showMessage("Canceled...", 2000);
+                  statusBar()->showMessage(tr("Canceled..."), 2000);
                   return;
             }
         }
@@ -388,19 +421,19 @@ void QBrew::fileSaveAs()
             addRecent(fname);
             ui.actionfilesave->setEnabled(false);
             setFileCaption(fname);
-            statusBar()->showMessage("Saved recipe", 2000);
+            statusBar()->showMessage(tr("Saved recipe"), 2000);
             // save name of file
             filename_ = fname;
         } else {
             // error in saving
             QMessageBox::warning(this, TITLE,
-                                 QString("Unable to save to %1")
+                                 tr("Unable to save to %1")
                                  .arg(QFileInfo(filename_).fileName()));
-            statusBar()->showMessage("Error in saving recipe", 2000);
+            statusBar()->showMessage(tr("Error in saving recipe"), 2000);
         }
     } else {
         // no file chosen
-        statusBar()->showMessage("Saving aborted", 2000);
+        statusBar()->showMessage(tr("Saving aborted"), 2000);
     }
 }
 
@@ -413,24 +446,23 @@ void QBrew::fileExport()
 {
     bool status = false;
     QString selected;
+    QString fname;
+    QString dirfile;
 
-    // file dialog will swap extensions as necessary
-    QString dirfile = filename_.left(filename_.lastIndexOf('.'))
-        + '.' + EXPORT_EXT;
-    QString fname  = QFileDialog::getSaveFileName(this,
-                                                  "Export...",
-                                                  dirfile,
-                                                  EXPORT_FILTER,
-                                                  &selected);
-
+    fname = QFileDialog::getSaveFileName(this,
+                                         tr("Export..."),
+                                         QString(),
+                                         tr(EXPORT_FILTER),
+                                         &selected,
+                                         QFileDialog::DontConfirmOverwrite);
 
     if (!fname.isEmpty()) { // we got a filename
         // add suffix if there is none
         if (!QFile::exists(fname)) {
             if (fname.indexOf('.') == -1) {
-               if (selected == HTML_FILTER) fname += ".html";
-               else if (selected == PDF_FILTER) fname += ".pdf";
-               else if (selected == TEXT_FILTER) fname += ".txt";
+               if (selected == tr(HTML_FILTER)) fname += ".html";
+               else if (selected == tr(PDF_FILTER)) fname += ".pdf";
+               else if (selected == tr(TEXT_FILTER)) fname += ".txt";
             }
         }
 
@@ -440,37 +472,51 @@ void QBrew::fileExport()
               case QMessageBox::Yes:
                   break;
               case QMessageBox::Cancel:
-                  statusBar()->showMessage("Canceled...", 2000);
+                  statusBar()->showMessage(tr("Canceled..."), 2000);
                   return;
             }
         }
 
-        // export character
-        if (selected == HTML_FILTER) {
+        // export recipe
+        if (selected == tr(HTML_FILTER)) {
             status = recipe_->exportHtml(fname);
-        } else if (selected == BEERXML_FILTER) {
+        } else if (selected == tr(BEERXML_FILTER)) {
             status = recipe_->exportBeerXML(fname);
-        } else if (selected == PDF_FILTER) {
-            status = recipe_->exportPdf(fname);
-        } else if (selected == TEXT_FILTER) {
+        } else if (selected == tr(PDF_FILTER)) {
+            status = recipe_->exportPdf(textprinter_, fname);
+        } else if (selected == tr(TEXT_FILTER)) {
             status = recipe_->exportText(fname);
         }
         if (status) {
             // successfully exported
-            statusBar()->showMessage("Exported recipe", 2000);
+            statusBar()->showMessage(tr("Exported recipe"), 2000);
         } else {
             // error in exporting
             QMessageBox::warning(this, TITLE,
-                                 QString("Unable to export to %1")
+                                 tr("Unable to export to %1")
                                  .arg(QFileInfo(filename_).fileName()));
-            statusBar()->showMessage("Error exporting recipe", 2000);
+            statusBar()->showMessage(tr("Error exporting recipe"), 2000);
         }
     } else {
         // no file chosen
-        statusBar()->showMessage("Export aborted", 2000 );
+        statusBar()->showMessage(tr("Export aborted"), 2000 );
     }
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// filePrintPreview()
+// ------------
+// Print the recipe
+
+void QBrew::filePrintPreview()
+{
+    // TODO: waiting for Qt 4.4.0, and hopefully a better print infrastructure
+    statusBar()->showMessage(tr("Print preview..."));
+
+    recipe_->previewRecipe(textprinter_);
+    statusBar()->showMessage(tr(READY), 2000);
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // filePrint()
 // ------------
@@ -478,33 +524,10 @@ void QBrew::fileExport()
 
 void QBrew::filePrint()
 {
-    statusBar()->showMessage("Printing...");
+    statusBar()->showMessage(tr("Printing..."));
 
-    if (!printer_) {
-        printer_ = new QPrinter(QPrinter::HighResolution);
-        printer_->setFullPage(true);
-        printer_->setColorMode(QPrinter::GrayScale);
-
-        // for convenience, default to US_Letter for C/US/Canada
-        switch (QLocale::system().country()) {
-          case QLocale::AnyCountry:
-          case QLocale::Canada:
-          case QLocale::UnitedStates:
-          case QLocale::UnitedStatesMinorOutlyingIslands:
-              printer_->setPageSize(QPrinter::Letter); break;
-          default:
-              printer_->setPageSize(QPrinter::A4); break;
-        }
-    }
-
-    QPrintDialog pdialog(printer_, this);
-    if (pdialog.exec() == QDialog::Accepted) {
-        recipe_->printRecipe(printer_);
-        statusBar()->showMessage(READY, 2000);
-    } else {
-        // cancelled
-        statusBar()->showMessage("Printing cancelled", 2000);
-    }
+    recipe_->printRecipe(textprinter_);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -514,7 +537,7 @@ void QBrew::filePrint()
 //////////////////////////////////////////////////////////////////////////////
 // toolsAlcohol()
 // --------------
-// A utility dialog for hydrometer correction
+// A utility dialog for alchohol calculation
 
 void QBrew::toolsAlcohol()
 {
@@ -523,7 +546,7 @@ void QBrew::toolsAlcohol()
     alcoholtool_->raise();
     if (alcoholtool_->isMinimized()) alcoholtool_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -538,7 +561,7 @@ void QBrew::toolsHydrometer()
     hydrometertool_->raise();
     if (hydrometertool_->isMinimized()) hydrometertool_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -554,7 +577,7 @@ void QBrew::toolsDatabase()
     databasetool_->raise();
     if (databasetool_->isMinimized()) databasetool_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -570,7 +593,7 @@ void QBrew::optionsStatusbar(bool on)
 {
     statusBar()->setVisible(on);
     state_.window.statusbar = on;
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -580,7 +603,7 @@ void QBrew::optionsStatusbar(bool on)
 
 void QBrew::optionsConfigure()
 {
-    statusBar()->showMessage(QString("Configuring %1 ...").arg(PACKAGE), 2000);
+    statusBar()->showMessage(tr("Configuring %1 ...").arg(PACKAGE), 2000);
 
     if (!configure_) {
         configure_ = new Configure(this);
@@ -602,7 +625,7 @@ void QBrew::optionsConfigure()
     configure_->raise();
     if (configure_->isMinimized()) configure_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -616,14 +639,14 @@ void QBrew::optionsConfigure()
 
 void QBrew::helpContents()
 {
-    QString home = docBase() + HELP_FILE;
+    QString home = docBase() + tr(HELP_FILE);
 
     if (!handbook_) handbook_ = new HelpViewer(home, 0);
     handbook_->show();
     handbook_->raise();
     if (handbook_->isMinimized()) handbook_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -633,14 +656,14 @@ void QBrew::helpContents()
 
 void QBrew::helpPrimer()
 {
-    QString home = docBase() + PRIMER_FILE;
+    QString home = docBase() + tr(PRIMER_FILE);
 
     if (!primer_) primer_ = new HelpViewer(home, 0);
     primer_->show();
     primer_->raise();
     if (primer_->isMinimized()) primer_->showNormal();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -662,14 +685,14 @@ void QBrew::helpAbout()
 {
     QString message;
 
-    message = "<center><nobr><big><strong>" + TITLE + " Version "
+    message = "<center><nobr><big><strong>" + TITLE + tr(" Version ")
         + VERSION + "</strong></big></nobr></center>";
-    message += "<p align=center><strong>" + DESCRIPTION + "</strong></p>";
-    message += "<p align=center>" + COPYRIGHT + ' ' + AUTHOR + "</p>";
-    message += "<p align=center><small>Contributions by "
+    message += "<p align=center><strong>" + tr(DESCRIPTION) + "</strong></p>";
+    message += "<p align=center>" + tr(COPYRIGHT) + ' ' + AUTHOR + "</p>";
+    message += tr("<p align=center><small>Contributions by ")
         + CONTRIBUTORS + "</small></p>";
 
-    QMessageBox::about(this, "About " + TITLE, message);
+    QMessageBox::about(this, tr("About ") + TITLE, message);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -696,10 +719,10 @@ void QBrew::applyGeneralState(const GenConfigState &state)
     }
     if (state.recentnum < oldstate.recentnum) {
         while (state_.general.recentfiles.count() > state_.general.recentnum) {
-            state_.general.recentfiles.pop_back();
+            state_.general.recentfiles.removeLast();
         }
     }
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -723,14 +746,11 @@ void QBrew::applyRecipeState(const RecipeConfigState &state)
     if (state.style != oldstate.style) {
         data_->setDefaultStyle(state.style);
     }
-    if (state.hopform != oldstate.hopform) {
-        data_->setDefaultHopForm(state.hopform);
-    }
-    if (state.mash != oldstate.mash) {
-        data_->setDefaultMash(state.mash);
+    if (state.hoptype != oldstate.hoptype) {
+        data_->setDefaultHopType(state.hoptype);
     }
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -744,6 +764,9 @@ void QBrew::applyCalcState(const CalcConfigState &state)
     state_.calc = state;
 
     // apply state changes
+    if (state.steepyield != oldstate.steepyield) {
+        data_->setSteepYield(state.steepyield);
+    }
     if (state.efficiency != oldstate.efficiency) {
         data_->setEfficiency(state.efficiency);
     }
@@ -759,19 +782,27 @@ void QBrew::applyCalcState(const CalcConfigState &state)
                                           Volume::liter));
             data_->setDefaultGrainUnit(Weight::kilogram);
             data_->setDefaultHopUnit(Weight::gram);
+            data_->setDefaultTempUnit(Temperature::celsius);
         } else if (state.units == UNIT_US) {
             data_->setDefaultSize(Volume(state_.recipe.batch,
                                           Volume::gallon));
             data_->setDefaultGrainUnit(Weight::pound);
             data_->setDefaultHopUnit(Weight::ounce);
+            data_->setDefaultTempUnit(Temperature::fahrenheit);
+        }
+        // delete hydrometer tool
+        if (hydrometertool_) {
+            delete hydrometertool_;
+            hydrometertool_ = 0;
         }
     }
 
+
     // recalculate
     recipe_->recalc();
     view_->flush();
 
-    statusBar()->showMessage(READY, 2000);
+    statusBar()->showMessage(tr(READY), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -782,7 +813,7 @@ void QBrew::applyCalcState(const CalcConfigState &state)
 void QBrew::saveConfig()
 {
     writeConfig();
-    statusBar()->showMessage("Saved configuration", 2000);
+    statusBar()->showMessage(tr("Saved configuration"), 2000);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -792,7 +823,7 @@ void QBrew::saveConfig()
 
 void QBrew::readConfig()
 {
-    QSettings config("usermode.org", "QBrew");
+    QSettings config("usermode", "qbrew");
     config.beginGroup(QString("/") + PACKAGE);
 
     // read general config
@@ -819,14 +850,21 @@ void QBrew::readConfig()
         config.value(CONF_RECIPE_BATCH, state_.recipe.batch).toDouble();
     state_.recipe.style =
         config.value(CONF_RECIPE_STYLE, state_.recipe.style).toString();
-    state_.recipe.hopform =
-        config.value(CONF_RECIPE_HOPFORM, state_.recipe.hopform).toString();
-    state_.recipe.mash =
-        config.value(CONF_RECIPE_MASH, state_.recipe.mash).toBool();
+    // TODO: CONF_RECIPE_HOPFORM is deprecated (0.4.0)
+    if (config.contains(CONF_RECIPE_HOPFORM)) {
+        state_.recipe.hoptype =
+            config.value(CONF_RECIPE_HOPFORM, state_.recipe.hoptype).toString();
+        config.remove(CONF_RECIPE_HOPFORM);
+    } else {
+        state_.recipe.hoptype =
+            config.value(CONF_RECIPE_HOPTYPE, state_.recipe.hoptype).toString();
+    }
     config.endGroup();
 
     // read calc config
     config.beginGroup(CONFGROUP_CALC);
+    state_.calc.steepyield =
+        config.value(CONF_CALC_STEEPYIELD, state_.calc.steepyield).toDouble();
     state_.calc.efficiency =
         config.value(CONF_CALC_EFFICIENCY, state_.calc.efficiency).toDouble();
     state_.calc.morey =
@@ -847,7 +885,7 @@ void QBrew::readConfig()
 
 void QBrew::writeConfig()
 {
-    QSettings config("usermode.org", "QBrew");
+    QSettings config("usermode", "qbrew");
     config.beginGroup(QString("/") + PACKAGE);
 
     // write general config
@@ -865,12 +903,12 @@ void QBrew::writeConfig()
     config.beginGroup(CONFGROUP_RECIPE);
     config.setValue(CONF_RECIPE_BATCH, (double)state_.recipe.batch);
     config.setValue(CONF_RECIPE_STYLE, state_.recipe.style);
-    config.setValue(CONF_RECIPE_HOPFORM, state_.recipe.hopform);
-    config.setValue(CONF_RECIPE_MASH, state_.recipe.mash);
+    config.setValue(CONF_RECIPE_HOPTYPE, state_.recipe.hoptype);
     config.endGroup();
 
     // write calc config
     config.beginGroup(CONFGROUP_CALC);
+    config.setValue(CONF_CALC_STEEPYIELD, (double)state_.calc.steepyield);
     config.setValue(CONF_CALC_EFFICIENCY, (double)state_.calc.efficiency);
     config.setValue(CONF_CALC_MOREY, state_.calc.morey);
     config.setValue(CONF_CALC_TINSETH, state_.calc.tinseth);
@@ -887,7 +925,7 @@ void QBrew::writeConfig()
 
 void QBrew::restoreState()
 {
-    QSettings config("usermode.org", "QBrew");
+    QSettings config("usermode", "qbrew");
     config.beginGroup(QString("/") + PACKAGE);
 
     // read window state
@@ -903,6 +941,10 @@ void QBrew::restoreState()
     // read general state
     config.beginGroup(CONFGROUP_GENERAL);
     state_.general.recentfiles = config.value(CONF_GEN_RECENTFILES).toStringList();
+    while (state_.general.recentfiles.count() > state_.general.recentnum) {
+        state_.general.recentfiles.removeLast();
+    }
+
     config.endGroup();
 
     config.endGroup();
@@ -920,7 +962,7 @@ void QBrew::restoreState()
 void QBrew::saveState()
 {
     // load config from settings
-    QSettings config("usermode.org", "QBrew");
+    QSettings config("usermode", "qbrew");
     config.beginGroup(QString("/") + PACKAGE);
 
     // write window state
@@ -959,20 +1001,25 @@ bool QBrew::openFile(const QString &filename)
             } else {
                 // load was unsuccessful
                 QMessageBox::warning(this, TITLE,
-                                     QString("Unable to load the recipe ")
+                                     tr("Unable to load the recipe ")
                                      .arg(QFileInfo(filename_).fileName()));
                 return false;
             }
         } else {
+            bool status = false;
             // attempt to import file
-            if (recipe_->importRecipe(filename)) {
-                // set filename to the default (forces a saveas)
-                filename_ = DEFAULT_FILE;
-                setFileCaption(filename_);
-            } else {
+            if (recipe_->beerXmlFormat(filename)) {
+                status = recipe_->importBeerXml(filename);
+                if (status) {
+                    // set filename to the default (forces a saveas)
+                    filename_ = DEFAULT_FILE;
+                    setFileCaption(filename_);
+                }
+            }
+            if (!status) {
                 // import was unsuccessful
                 QMessageBox::warning(this, TITLE,
-                                     QString("Unable to import the file %1")
+                                     tr("Unable to import the file %1")
                                      .arg(QFileInfo(filename).fileName()));
                 return false;
             }
@@ -1023,7 +1070,7 @@ bool QBrew::backupFile()
     if (backed_) return true;
 
     bool status = false;
-    if ((!filename_.isEmpty()) && (filename_ != DEFAULT_FILE)) {
+    if (!filename_.isEmpty() && (filename_ != tr(DEFAULT_FILE))) {
         if (QFile::exists(filename_ + '~'))
             QFile::remove(filename_ + '~');
         status = QFile::copy(filename_, filename_ + '~');
@@ -1077,10 +1124,11 @@ void QBrew::addRecent(const QString &filename)
 void QBrew::autoSave()
 {
     if (!recipe_->modified()) return;
-    statusBar()->showMessage("Autosaving recipe...", 2000);
-    if ((filename_.isEmpty()) || (filename_ == DEFAULT_FILE)) {
+    statusBar()->showMessage(tr("Autosaving recipe..."), 2000);
+    if ((filename_.isEmpty()) || (filename_ == tr(DEFAULT_FILE))) {
         recipe_->saveRecipe(autosavename_);
     } else {
+        if (state_.general.autobackup) backupFile();
         recipe_->saveRecipe(filename_);
     }
     // remove "modified" from caption
@@ -1097,10 +1145,10 @@ void QBrew::setFileCaption(const QString &filename)
     setWindowModified(false); // clear modified *
 
     QString shownname;
-    if (filename.isEmpty()) shownname = DEFAULT_FILE;
+    if (filename.isEmpty()) shownname = tr(DEFAULT_FILE);
     else                    shownname = QFileInfo(filename).fileName();
 
-    setWindowTitle(QString("%1 - %2[*]").arg(TITLE).arg(shownname));
+    setWindowTitle(QString("%1 - %2[*]").arg(TITLE.constData()).arg(shownname));
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1110,11 +1158,11 @@ void QBrew::setFileCaption(const QString &filename)
 
 int QBrew::querySave()
 {
-    return QMessageBox::question(this, TITLE + " - Save?",
-                                    "<p>Do you wish to save your work first?",
-                                    QMessageBox::Yes,
-                                    QMessageBox::No,
-                                    QMessageBox::Cancel);
+    return QMessageBox::question(this, TITLE + tr(" - Save?"),
+                                 tr("<p>Do you wish to save your work first?"),
+                                 QMessageBox::Yes,
+                                 QMessageBox::No,
+                                 QMessageBox::Cancel);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1124,12 +1172,12 @@ int QBrew::querySave()
 
 int QBrew::queryOverwrite(const QString filename)
 {
-    return QMessageBox::question(this, TITLE + " - Overwrite?",
-                                    QString("<p>Are you sure you want to "
-                                            "overwrite the file \"%1\"")
-                                    .arg(filename),
-                                    QMessageBox::Yes,
-                                    QMessageBox::Cancel);
+    return QMessageBox::question(this, TITLE + tr(" - Overwrite?"),
+                                 tr("<p>Are you sure you want to "
+                                    "overwrite the file \"%1\"")
+                                 .arg(filename),
+                                 QMessageBox::Yes,
+                                 QMessageBox::Cancel);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1160,7 +1208,7 @@ void QBrew::closeEvent(QCloseEvent* e)
               e->accept();
               break;
           case QMessageBox::Cancel:
-              statusBar()->showMessage(READY, 2000);
+              statusBar()->showMessage(tr(READY), 2000);
               e->ignore();
               break;
           case QMessageBox::No:
@@ -1175,7 +1223,9 @@ void QBrew::closeEvent(QCloseEvent* e)
 // -----------
 // Filter events
 
-bool QBrew::eventFilter(QObject *obj, QEvent *event) {
+bool QBrew::eventFilter(QObject *obj, QEvent *event)
+{
+    // necessary on Mac
     if (event->type() == QEvent::FileOpen) {
         QFileOpenEvent *openevent = static_cast<QFileOpenEvent *>(event);
         fileOpen(openevent->file());
@@ -1207,7 +1257,7 @@ QString QBrew::dataBase()
         base += "/";
     }
 
-#elif defined(Q_WS_MACX)
+#elif defined(Q_WS_MAC)
     if (QRegExp("Contents/MacOS/?$").indexIn(base) != -1) {
         // we're pointing inside an application bundle
         base += "/../Resources/";
@@ -1243,7 +1293,7 @@ QString QBrew::docBase()
         base += "/doc/";
     }
 
-#elif defined(Q_WS_MACX)
+#elif defined(Q_WS_MAC)
     if (QRegExp("Contents/MacOS/?$").indexIn(base) != -1) {
         // we're pointing inside an application bundle
         base += "/../Resources/en.lproj/";
