@@ -39,7 +39,6 @@
 #include "configstate.h"
 
 class QCloseEvent;
-class QPrinter;
 class QTimer;
 
 class AlcoholTool;
@@ -49,6 +48,7 @@ class DatabaseTool;
 class HelpViewer;
 class HydrometerTool;
 class Recipe;
+class TextPrinter;
 class View;
 
 class QBrew : public QMainWindow {
@@ -78,6 +78,8 @@ class QBrew : public QMainWindow {
     void fileSaveAs();
     // export the recipe to non-native format
     void fileExport();
+    // print preview
+    void filePrintPreview();
     // print the recipe
     void filePrint();
 
@@ -182,7 +184,7 @@ private:
 
     QTimer *autosave_;
     QString autosavename_;
-    QPrinter *printer_;
+    TextPrinter *textprinter_;
 };
 
 #endif // QBREW_H
