@@ -66,6 +66,14 @@ Unit* Unit::unit(const QString &symbol)
         return 0;
 }
 
+/**
+ * Equivalence operator.
+ */
+bool Unit::operator==(const Unit &u) const
+{
+    return ((name_ == u.name_) && (symbol_ == u.symbol_));
+}
+
 // Quantity Class ///////////////////////////////////////////////////////////
 
 Unit Quantity::generic("unit", "unit");
@@ -92,7 +100,7 @@ bool Quantity::operator==(const Quantity &q) const
 }
 
 /**
- * Convert Quanity to unit.
+ * Convert Quantity to unit.
  */
 void Quantity::convert(const Unit &u)
 {
@@ -306,6 +314,41 @@ void Volume::initialize()
     initialized_ = true;
 }
 
+// Temperature Class //////////////////////////////////////////////////////////
+
+Unit Temperature::fahrenheit("fahrenheit", "F");
+Unit Temperature::celsius("celsius", "C");
+
+bool Temperature::initialized_ = false;
+
+/**
+ * Constructor
+ */
+Temperature::Temperature(double amount, const Unit &unit) 
+    : Quantity(amount, unit)
+{
+    if (!initialized_) initialize();
+}
+
+/**
+ * Conversion constructor. Converts from base Quantity.
+ */
+Temperature::Temperature(const Quantity &q)
+    : Quantity(q)
+{
+    if (!initialized_) initialize();
+    // TODO: throw if nonconvertable
+}
+
+/**
+ * Initialize the class units.
+ */
+void Temperature::initialize()
+{
+    fahrenheit.addConversion(celsius, fahrenheit2celsius);
+    celsius.addConversion(fahrenheit, celsius2fahrenheit);
+}
+
 // Conversion Functions //////////////////////////////////////////////////
 
 // TODO: double check formulas
@@ -435,3 +478,9 @@ double milliliter2hectoliter(double value)
 
 double milliliter2liter(double value)
     { return value / 1000.0; }
+
+double fahrenheit2celsius(double value)
+    { return (value - 32.0) / 1.8; }
+
+double celsius2fahrenheit(double value)
+    { return (value * 1.8) + 32.0; }
