@@ -65,6 +65,9 @@ class Unit {
     // Return pointer to Unit if it exists
     static Unit* unit(const QString &symbol);
 
+    // equivalence operator
+    bool operator==(const Unit &u) const;
+
  private:
     Unit(const Unit&);
     Unit operator=(const Unit&);
@@ -197,6 +200,34 @@ class Volume : public Quantity
     static bool initialized_;
 };
 
+class Temperature : public Quantity
+{
+ public:
+    // Constructor
+    Temperature(double amount, const Unit &unit);
+    /// Default constructor
+    Temperature();
+    /// Construct from string
+    Temperature(const QString &from, const Unit &defaultunit = fahrenheit);
+    // Copy constructor
+    Temperature(const Temperature &t);
+    // Conversion constructor
+    Temperature(const Quantity &q);
+    // destructor
+    ~Temperature();
+
+ public:
+    static Unit fahrenheit;
+    static Unit celsius;
+
+ private:
+    // initialize the temperature units
+    static void initialize();
+
+ private:
+    static bool initialized_;
+};
+
 // Conversion Prototypes ////////////////////////////////////////////////////
 
 double gram2kilogram(double value);
@@ -243,6 +274,9 @@ double milliliter2gallon(double value);
 double milliliter2hectoliter(double value);
 double milliliter2liter(double value);
 
+double fahrenheit2celsius(double value);
+double celsius2fahrenheit(double value);
+
 // Inlined Methods //////////////////////////////////////////////////////////
 
 inline QString Unit::name() const
@@ -311,4 +345,16 @@ inline Volume::Volume(const QString &from, const Unit &defaultunit)
 inline Volume::~Volume()
     { ; }
 
+inline Temperature::Temperature(const Temperature &t)
+    : Quantity(t) { ; }
+
+inline Temperature::Temperature()
+    : Quantity(0.0, fahrenheit) { ; }
+
+inline Temperature::Temperature(const QString &from, const Unit &defaultunit)
+    : Quantity(from, defaultunit) { ; }
+
+inline Temperature::~Temperature()
+    { ; }
+
 #endif // QUANTITY_H
