@@ -13,10 +13,10 @@
 #include <QDomDocument>
 #include <QFile>
 #include <QMessageBox>
-#include <QPrinter>
 #include <QTextDocument>
 #include <QTextStream>
 
+#include "textprinter.h"
 #include "data.h"
 #include "recipe.h"
 #include "resource.h"
@@ -27,6 +27,10 @@
 
 using namespace Resource;
 
+const QByteArray Recipe::EXTRACT_STRING = QT_TRANSLATE_NOOP("recipe", "Extract");
+const QByteArray Recipe::PARTIAL_STRING = QT_TRANSLATE_NOOP("recipe", "Partial Mash");
+const QByteArray Recipe::ALLGRAIN_STRING = QT_TRANSLATE_NOOP("recipe", "All Grain");
+
 //////////////////////////////////////////////////////////////////////////////
 // Construction, destruction                                                //
 //////////////////////////////////////////////////////////////////////////////
@@ -36,8 +40,8 @@ using namespace Resource;
 // --------
 // Default constructor
 Recipe::Recipe(QObject *parent)
-        : QObject(parent), modified_(false), title_(), brewer_(), mash_(false),
-          size_(5.0, Volume::gallon), style_(),  grains_(), hops_(), miscs_(),
+        : QObject(parent), modified_(false), title_(), brewer_(),
+          size_(5.0, Volume::gallon), style_(), grains_(),  hops_(), miscs_(),
           recipenotes_(), batchnotes_(), og_(0.0), ibu_(0), srm_(0)
 { ; }
 
@@ -57,7 +61,6 @@ void Recipe::newRecipe()
 {
     title_.clear();
     brewer_.clear();
-    mash_ = Data::instance()->defaultMash();
     size_ = Data::instance()->defaultSize();
     style_ = Data::instance()->defaultStyle();
     grains_.clear();
@@ -85,7 +88,7 @@ bool Recipe::nativeFormat(const QString &filename)
     QFile datafile(filename);
     if (!datafile.open(QFile::ReadOnly | QFile::Text)) {
         // error opening file
-        qWarning("Error: Cannot open %s", qPrintable(filename));
+        qWarning() << "Error: Cannot open" << filename;
         datafile.close();
         return false;
     }
@@ -110,6 +113,49 @@ bool Recipe::nativeFormat(const QString &filename)
     return true;
 }
 
+// TODO: make BeerXML stuff a plugin?
+
+/////////////////////////////////////////////////////////////////////////////
+// beerXmlFormat()
+// ---------------
+// Is the recipe in BeerXML format?
+// Defined as XML with "<RECIPES>" and "<RECIPE>", VERSION 1
+// Note that BeerXML 1.0 is poorly designed format
+
+bool Recipe::beerXmlFormat(const QString &filename)
+{
+    QFile datafile(filename);
+    if (!datafile.open(QFile::ReadOnly | QFile::Text)) {
+        // error opening file
+        qWarning() << "Error: Cannot open" << filename;
+        datafile.close();
+        return false;
+    }
+
+    // parse document
+    QDomDocument doc;
+    bool status = doc.setContent(&datafile);
+    datafile.close();
+    if (!status) return false;
+
+    // check the document type
+    QDomElement root = doc.documentElement();
+    if (root.tagName() != tagRECIPES) return false;
+
+    // check for RECIPE
+    QDomElement element, sub;
+    element = root.firstChildElement(tagRECIPE);
+    if (!element.isNull()) {
+        // check VERSION
+        sub = element.firstChildElement(tagVERSION);
+        if (!sub.isNull()) {
+            if (sub.text() == "1") return true;
+        }
+    }
+
+    return false;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // loadRecipe()
 // --------------
@@ -121,9 +167,9 @@ bool Recipe::loadRecipe(const QString &filename)
     QFile datafile(filename);
     if (!datafile.open(QFile::ReadOnly | QFile::Text)) {
         // error opening file
-        qWarning("Error: Cannot open %s", qPrintable(filename));
+        qWarning() << "Error: Cannot open" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Cannot read file %1:\n%2")
+                             tr("Cannot read file %1:\n%2")
                              .arg(filename)
                              .arg(datafile.errorString()));
         datafile.close();
@@ -135,15 +181,15 @@ bool Recipe::loadRecipe(const QString &filename)
     // open dom recipe
     QDomDocument doc;
     doc.setContent(&datafile);
-   datafile.close();
+    datafile.close();
 
     // check the doc type and stuff
     QDomElement root = doc.documentElement();
     if (root.tagName() != tagRecipe) {
         // wrong file type
-        qWarning("Error: Wrong file type %s", qPrintable(filename));
+        qWarning() << "Error: Wrong file type" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Wrong file type for %1").arg(filename));
+                             tr("Wrong file type for %1").arg(filename));
         QApplication::restoreOverrideCursor();
          return false;
     }
@@ -152,9 +198,9 @@ bool Recipe::loadRecipe(const QString &filename)
     if (root.attribute(attrApplication) != PACKAGE) {
         // check generator if no application
         if (root.attribute(attrGenerator) != PACKAGE) {
-            qWarning("Not a recipe file for %s", PACKAGE);
+            qWarning() << "Not a recipe file for" << TITLE;
             QMessageBox::warning(0, TITLE,
-                                 QString("Not a recipe for %1").arg(PACKAGE));
+                                 tr("Not a recipe for %1").arg(TITLE.data()));
             QApplication::restoreOverrideCursor();
              return false;
         }
@@ -163,134 +209,112 @@ bool Recipe::loadRecipe(const QString &filename)
     // check file version
     if (root.attribute(attrVersion) < RECIPE_PREVIOUS) {
         // too old of a version
-        qWarning("Error: Unsupported version %s", qPrintable(filename));
+        qWarning() << "Error: Unsupported version" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Unsupported version %1").arg(filename));
+                             tr("Unsupported version %1").arg(filename));
         QApplication::restoreOverrideCursor();
          return false;
     }
 
-    // Note: for some of these tags, only one in a document makes sense.
-    // But if there is more than one, process them in order, with later
-    // ones overwriting the earlier
-    QDomNodeList nodes, subnodes;
-    QDomElement element, subelement;
-    int n, m;
+    // Note: only use first tag if multiple single-use tags in doc
+    QDomNodeList nodes;
+    QDomElement element, sub;
 
     // get title
-    nodes = root.elementsByTagName(tagTitle);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            setTitle(element.text());
-        }
+    element = root.firstChildElement(tagTitle);
+    if (element.isNull()) {
+        qDebug() << "Warning:: missing DOM element" << tagTitle;
+    } else {
+        setTitle(element.text());
     }
     // get brewer
-    nodes = root.elementsByTagName(tagBrewer);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            setBrewer(element.text());
-        }
+    element = root.firstChildElement(tagBrewer);
+    if (element.isNull()) {
+        qDebug() << "Warning:: missing DOM element" << tagBrewer;
+    } else {
+        setBrewer(element.text());
     }
     // get style
-    nodes = root.elementsByTagName(tagStyle);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // TODO: load/save entire style
-            setStyle(element.text());
-        }
+    element = root.firstChildElement(tagStyle);
+    if (element.isNull()) {
+        qDebug() << "Warning:: missing DOM element" << tagStyle;
+    } else {
+        // TODO: load/save entire style
+        setStyle(element.text());
     }
-    // get batch settings
-    nodes = root.elementsByTagName(tagBatch);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
+    // get batch settings // TODO: eliminate this tag, use quantity, efficiency
+    element = root.firstChildElement(tagBatch);
+    if (!element.isNull()) {
+        if (element.attribute(attrQuantity) != QString()) {
             setSize(Volume(element.attribute(attrQuantity), Volume::gallon));
-            setMashed(element.attribute(attrMash).toLower() == "true");
+        } else if (element.attribute(attrSize) != QString()) {
+            // deprecated tag
+            setSize(Volume(element.attribute(attrSize), Volume::gallon));
         }
     }
+
     // get notes
     recipenotes_.clear();
     batchnotes_.clear();
-    nodes = root.elementsByTagName(tagNotes);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            if (element.hasAttribute(attrClass)) {
-                if (element.attribute(attrClass) == classRecipe) {
-                    if (!recipenotes_.isEmpty()) recipenotes_.append('\n');
-                    recipenotes_.append(element.text());
-                } else if (element.attribute(attrClass) == classBatch) {
-                    if (!batchnotes_.isEmpty()) batchnotes_.append('\n');
-                    batchnotes_.append(element.text());
-                }
+    element = root.firstChildElement(tagNotes);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagNotes)) {
+        if (element.hasAttribute(attrClass)) {
+            if (element.attribute(attrClass) == classRecipe) {
+                if (!recipenotes_.isEmpty()) recipenotes_.append('\n');
+                recipenotes_.append(element.text());
+            } else if (element.attribute(attrClass) == classBatch) {
+                if (!batchnotes_.isEmpty()) batchnotes_.append('\n');
+                batchnotes_.append(element.text());
             }
         }
     }
 
     // get all grains tags
     grains_.clear();
-    nodes = root.elementsByTagName(tagGrains);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all grain tags
-            subnodes = element.elementsByTagName(tagGrain);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    addGrain(Grain(subelement.text(),
-                                   Weight(subelement.attribute(attrQuantity),
-                                          Weight::pound),
-                                   subelement.attribute(attrExtract).toDouble(),
-                                   subelement.attribute(attrColor).toDouble(),
-                                   subelement.attribute(attrUse)));
-                }
-            }
+    element = root.firstChildElement(tagGrains);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagGrains)) {
+        // get all grain tags
+        sub = element.firstChildElement(tagGrain);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagGrain)) {
+            addGrain(Grain(sub.text(),
+                           Weight(sub.attribute(attrQuantity), Weight::pound),
+                           sub.attribute(attrExtract).toDouble(),
+                           sub.attribute(attrColor).toDouble(),
+                           sub.attribute(attrType, Grain::OTHER_STRING),
+                           sub.attribute(attrUse)));
         }
     }
 
     // get all hops tags
     hops_.clear();
-    nodes = root.elementsByTagName(tagHops);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
+    element = root.firstChildElement(tagHops);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagHops)) {
             // get all hop tags
-            subnodes = element.elementsByTagName(tagHop);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    addHop(Hop(subelement.text(),
-                               Weight(subelement.attribute(attrQuantity),
-                                      Weight::ounce),
-                               subelement.attribute(attrForm),
-                               subelement.attribute(attrAlpha).toDouble(),
-                               subelement.attribute(attrTime).toUInt()));
-                }
-            }
+        sub = element.firstChildElement(tagHop);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagHop)) {
+            // TODO: attrForm is deprecated 0.4.0
+            QString hoptype = sub.attribute(attrType);
+            if (hoptype == QString()) hoptype = sub.attribute(attrForm);
+            addHop(Hop(sub.text(),
+                       Weight(sub.attribute(attrQuantity), Weight::ounce),
+                       hoptype,
+                       sub.attribute(attrAlpha).toDouble(),
+                       sub.attribute(attrTime).toUInt()));
         }
     }
 
     // get all misc tags
     miscs_.clear();
-    nodes = root.elementsByTagName(tagMiscIngredients);
-    for (n=0; n<nodes.count(); ++n) {
-        if (nodes.item(n).isElement()) {
-            element = nodes.item(n).toElement();
-            // get all misc tags
-            subnodes = element.elementsByTagName(tagMiscIngredient);
-            for (m=0; m<subnodes.count(); m++) {
-                if (subnodes.item(m).isElement()) {
-                    subelement = subnodes.item(m).toElement();
-                    addMisc(Misc(subelement.text(),
-                                 Quantity(subelement.attribute(attrQuantity),
-                                          Quantity::generic),
-                                 subelement.attribute(attrNotes)));
-                }
-            }
+    element = root.firstChildElement(tagMiscs);
+    for (; !element.isNull(); element=element.nextSiblingElement(tagMiscs)) {
+        // get all hop tags
+        sub = element.firstChildElement(tagMisc);
+        for (; !sub.isNull(); sub=sub.nextSiblingElement(tagMisc)) {
+            addMisc(Misc(sub.text(),
+                         Quantity(sub.attribute(attrQuantity),
+                                  Quantity::generic),
+                         sub.attribute(attrType, Misc::OTHER_STRING),
+                         sub.attribute(attrNotes)));
         }
     }
 
@@ -335,10 +359,10 @@ bool Recipe::saveRecipe(const QString &filename)
     element = doc.createElement(tagStyle);
     element.appendChild(doc.createTextNode(style_.name()));
     root.appendChild(element);
+    root.appendChild(element);
     // batch settings
     element = doc.createElement(tagBatch);
     element.setAttribute(attrQuantity, size_.toString());
-    element.setAttribute(attrMash, mash_ ? "true" : "false");
     root.appendChild(element);
     // notes
     if (!recipenotes_.isEmpty()) {
@@ -364,7 +388,8 @@ bool Recipe::saveRecipe(const QString &filename)
         subelement.setAttribute(attrQuantity, grain.weight().toString());
         subelement.setAttribute(attrExtract, grain.extract());
         subelement.setAttribute(attrColor, grain.color());
-        subelement.setAttribute(attrUse, grain.useString());
+        subelement.setAttribute(attrType, grain.type());
+        subelement.setAttribute(attrUse, grain.use());
         element.appendChild(subelement);
     }
     root.appendChild(element);
@@ -376,7 +401,7 @@ bool Recipe::saveRecipe(const QString &filename)
         subelement = doc.createElement(tagHop);
         subelement.appendChild(doc.createTextNode(hop.name()));
         subelement.setAttribute(attrQuantity, hop.weight().toString());
-        subelement.setAttribute(attrForm, hop.form());
+        subelement.setAttribute(attrType, hop.type());
         subelement.setAttribute(attrAlpha, hop.alpha());
         subelement.setAttribute(attrTime, hop.time());
         element.appendChild(subelement);
@@ -384,12 +409,13 @@ bool Recipe::saveRecipe(const QString &filename)
     root.appendChild(element);
 
     // miscingredients elements
-    element = doc.createElement(tagMiscIngredients);
+    element = doc.createElement(tagMiscs);
     foreach(Misc misc, miscs_) {
         // iterate through misc list
-        subelement = doc.createElement(tagMiscIngredient);
+        subelement = doc.createElement(tagMisc);
         subelement.appendChild(doc.createTextNode(misc.name()));
         subelement.setAttribute(attrQuantity, misc.quantity().toString());
+        subelement.setAttribute(attrType, misc.type());
         subelement.setAttribute(attrNotes, misc.notes());
         element.appendChild(subelement);
     }
@@ -399,9 +425,9 @@ bool Recipe::saveRecipe(const QString &filename)
     QFile datafile(filename);
     if (!datafile.open(QFile::WriteOnly | QFile::Text)) {
         // error opening file
-        qWarning("Error: Cannot open file %s", qPrintable(filename));
+        qWarning() << "Error: Cannot open file" << filename;
         QMessageBox::warning(0, TITLE,
-                             QString("Cannot write file %1:\n%2")
+                             tr("Cannot write file %1:\n%2")
                              .arg(filename)
                              .arg(datafile.errorString()));
         datafile.close();
@@ -421,34 +447,38 @@ bool Recipe::saveRecipe(const QString &filename)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// ImportRecipe()
-// -------------
-// Import recipe from another format
+// previewRecipe()
+// ---------------
+// Preview the recipe (assumes textprinter has been setup)
 
-bool Recipe::importRecipe(const QString &/*filename*/)
+void Recipe::previewRecipe(TextPrinter *textprinter)
 {
-    // TODO: stubby
-    return false;
+    // TODO: waiting for Qt 4.4.0, and hopefully a better print infrastructure
+    if (!textprinter) return;
+    QTextDocument document;
+    document.setHtml(recipeHTML());
+    textprinter->preview(&document);
 }
 
+    void previewRecipe(TextPrinter *textprinter, QWidget *wparent);
 //////////////////////////////////////////////////////////////////////////////
 // printRecipe()
 // ---------------
-// Print the recipe (assumes printer has been setup)
+// Print the recipe (assumes textprinter has been setup)
 
-void Recipe::printRecipe(QPrinter *printer)
+void Recipe::printRecipe(TextPrinter *textprinter)
 {
-    if (!printer) return;
+    if (!textprinter) return;
     QTextDocument document;
     document.setHtml(recipeHTML());
-    document.print(printer);
+    textprinter->print(&document);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 // Miscellaneous                                                            //
 //////////////////////////////////////////////////////////////////////////////
 
-//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////////////////////////////////////////////////
 // setStyle()
 // ----------
 // Set style from string
@@ -503,21 +533,21 @@ void Recipe::addMisc(const Misc &m)
 // ------------
 // Return type of recipe
 
-int Recipe::recipeType()
+QString Recipe::method()
 {
     int extract = 0;
     int mash = 0;
 
     foreach(Grain grain, grains_) {
-        if (grain.use() == USE_MASHED) mash++;
-        else if (grain.use() == USE_EXTRACT) extract++;
+        if (grain.use() == Grain::MASHED_STRING) mash++;
+        else if (grain.use() == Grain::EXTRACT_STRING) extract++;
     }
 
     if (mash > 0) {
-        if (extract > 0) return TypePartial;
-        else             return TypeAllGrain;
+        if (extract > 0) return PARTIAL_STRING;
+        else             return ALLGRAIN_STRING;
     }
-    return TypeExtract;
+    return EXTRACT_STRING;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -543,29 +573,24 @@ void Recipe::recalc()
 
 double Recipe::calcOG()
 {
-    const double STEEP_YIELD = 0.50;
-
     double yield;
     double est = 0.0;
     foreach(Grain grain, grains_) {
         yield = grain.yield();
-        switch (grain.use()) {
-            case USE_MASHED:
-                // adjust for mash efficiency
-                yield *= Data::instance()->efficiency();
-                break;
-            case USE_STEEPED:
+        if (grain.use() == Grain::MASHED_STRING) {
+            // adjust for mash efficiency
+            yield *= Data::instance()->efficiency();
+        } else if (grain.use() == Grain::STEEPED_STRING) {
                 // steeped grains don't yield nearly as much as mashed grains
-                yield *= STEEP_YIELD;
-                break;
-            case USE_EXTRACT:
-                break;  // no modifications necessary
-            default:
-                break;
+                yield *= Data::instance()->steepYield();
         }
         est += yield;
     }
-    est /= size_.amount(Volume::gallon);
+    if (size_.amount()) {
+        est /= size_.amount(Volume::gallon);
+    } else {
+        est = 0.0;
+    }
     return est + 1.0;
 }
 
@@ -590,12 +615,17 @@ int Recipe::calcIBU()
 
 int Recipe::calcRagerIBU()
 {
+// TODO: update this (and other) hop calculations
     double bitterness = 0.0;
     foreach(Hop hop, hops_) {
         bitterness += hop.HBU() * Data::instance()->utilization(hop.time());
-        // TODO: we should also correct for hop form
+        // TODO: we should also correct for hop type
+    }
+    if (size_.amount()) {
+        bitterness /= size_.amount(Volume::gallon);
+    } else {
+        bitterness = 0.0;
     }
-    bitterness /= size_.amount(Volume::gallon);
     // correct for boil gravity
     if (og_ > 1.050) bitterness /= 1.0 + ((og_ - 1.050) / 0.2);
     return (int)round(bitterness);
@@ -628,7 +658,11 @@ int Recipe::calcTinsethIBU()
         ibu = (COEFF1 * pow(COEFF2, (og_ - 1.0))) *
             (1.0 - exp(-COEFF3 * hop.time())) *
             (hop.alpha()) * hop.weight().amount(Weight::ounce) * 1000.0;
-        ibu /= (size_.amount(Volume::gallon)) * COEFF4;
+        if (size_.amount()) {
+            ibu /= (size_.amount(Volume::gallon) * COEFF4);
+        } else {
+            ibu = 0.0;
+        }
         bitterness += ibu;
     }
     bitterness *= (GPO / LPG) / 100.0;
@@ -646,7 +680,11 @@ int Recipe::calcSRM()
     foreach(Grain grain, grains_) {
         srm += grain.HCU();
     }
-    srm /= size_.amount(Volume::gallon);
+    if (size_.amount()) {
+        srm /= size_.amount(Volume::gallon);
+    } else {
+        srm = 0.0;
+    }
 
     // switch between two possible calculations
     if (Data::instance()->morey()) {
@@ -683,13 +721,12 @@ double Recipe::FGEstimate()
 
 double Recipe::ABV() // recipe version
 {
-    double fg = FGEstimate();
-    return ABW(og_, fg) * fg / 0.79;
+    return (ABV(og_, FGEstimate()));
 }
 
 double Recipe::ABV(double og, double fg) // static version
 { 
-    return ABW(og, fg) * fg / 0.79;
+    return (og - fg) * 1.29;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -705,11 +742,7 @@ double Recipe::ABW() // recipe version
  
 double Recipe::ABW(double og, double fg)  // static version
 {
-    double oe, ae, re;
-    oe = SgToP(og);
-    ae = SgToP(fg);
-    re = (0.1808 * oe) + (0.8192 * ae); // real extract
-    return ((oe - re) / (2.0665 - 0.010665 * oe) / 100.0);
+    return (ABV(og, fg) * 0.785);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -717,7 +750,8 @@ double Recipe::ABW(double og, double fg)  // static version
 // -------
 // Convert specific gravity to degrees plato
 
-double Recipe::SgToP(double sg) {
+double Recipe::SgToP(double sg)
+{
     return ((-463.37) + (668.72*sg) - (205.35 * sg * sg));
 }
 
@@ -727,7 +761,8 @@ double Recipe::SgToP(double sg) {
 // Convert extract potential to percent yield
 
 // TODO: need to double check this, as well as terms
-double Recipe::extractToYield(double extract) {
+double Recipe::extractToYield(double extract)
+{
     const double SUCROSE = 46.21415;
     return (((extract-1.0)*1000.0) / SUCROSE);
 }
@@ -737,7 +772,8 @@ double Recipe::extractToYield(double extract) {
 // ----------------
 // Convert percent yield to extract potential
 
-double Recipe::yieldToExtract(double yield) {
+double Recipe::yieldToExtract(double yield)
+{
     const double SUCROSE = 46.21415;
     return ((yield*SUCROSE)/1000.0)+1.0;
 }
