@@ -42,11 +42,17 @@
 #include "misc.h"
 #include "style.h"
 
-class QPrinter;
+class TextPrinter;
 
 class Recipe : public QObject {
     Q_OBJECT
 public:
+    // TODO: make sure am comparing lowercase
+    // recipe strings
+    static const QByteArray EXTRACT_STRING;
+    static const QByteArray PARTIAL_STRING;
+    static const QByteArray ALLGRAIN_STRING;
+
     // default constructor
     Recipe(QObject *parent);
     virtual ~Recipe();
@@ -57,19 +63,23 @@ public:
     bool loadRecipe(const QString &filename);
     // save the current recipe
     bool saveRecipe(const QString &filename);
+    // preview the recipe
+    void previewRecipe(TextPrinter *textprinter);
     // print the recipe
-    void printRecipe(QPrinter *printer);
+    void printRecipe(TextPrinter *textprinter);
     // is the file in native format?
     bool nativeFormat(const QString &filename);
+    // is the file in BeerXml format?
+    bool beerXmlFormat(const QString &filename);
 
-    // import a recipe from another format
-    bool importRecipe(const QString &filename);
+    // import a recipe from another BeerXML format
+    bool importBeerXml(const QString &filename);
     // export the recipe as html
     bool exportHtml(const QString &filename);
     // export the recipe to BeerXML format
     bool exportBeerXML(const QString &filename);
     // export the recipe as pdf
-    bool exportPdf(const QString &filename);
+    bool exportPdf(TextPrinter *textprinter, const QString &filename);
     // export the recipe as html
     bool exportText(const QString &filename);
 
@@ -78,8 +88,6 @@ public:
     void setTitle(const QString &t);
     const QString& brewer() const;
     void setBrewer(const QString &b);
-    bool mashed() const;
-    void setMashed(bool m);
     const Volume &size() const;
     void setSize(const Volume &s);
     const Style &style() const;
@@ -90,10 +98,6 @@ public:
     const QString& batchNotes() const;
     void setBatchNotes(const QString &n);
 
-    // return type of recipe
-    enum RecipeType { TypeExtract, TypePartial, TypeAllGrain };
-    int recipeType();
-
     // add an ingredient to the recipe
     void addGrain(const Grain &g);
     void addHop(const Hop &h);
@@ -112,6 +116,8 @@ public:
     int SRM();
     // return estimated final gravity
     double FGEstimate();
+    // return method of recipe
+    QString method();
 
     // return alcohol %v
     double ABV();
@@ -156,7 +162,6 @@ private:
 
     QString title_;
     QString brewer_;
-    bool mash_;
 
     Volume size_;
     Style style_;
@@ -187,12 +192,6 @@ inline const QString &Recipe::brewer() const
 inline void Recipe::setBrewer(const QString &b)
     { brewer_ = b; setModified(true); }
 
-inline bool Recipe::mashed() const
-    { return mash_; }
-
-inline void Recipe::setMashed(bool m)
-    { mash_ = m; setModified(true); }
-
 inline const Volume &Recipe::size() const
     { return size_; }
 
