@@ -33,10 +33,11 @@
 #ifndef RESOURCE_H
 #define RESOURCE_H
 
+#include <QDebug>
 #include <QString>
 
 #define PACKAGE "qbrew"
-#define VERSION "0.3.10"
+#define VERSION "0.4.0"
 
 // some stuff to differentiate between platforms
 #if defined(Q_WS_X11)
@@ -52,84 +53,97 @@ namespace Resource {
 ///////////////////////////////////////////////////////////////////
 // general application values
 
-const QString TITLE           = "QBrew";
-const QString DESCRIPTION     = "A Homebrewer's Recipe Calculator";
-const QString COPYRIGHT       = "Copyright 1999-2007";
-const QString AUTHOR          = "David Johnson";
-const QString AUTHOR_EMAIL    = "david@usermode.org";
-const QString CONTRIBUTORS    = "Lee Henderson, "
+const QByteArray TITLE        = "QBrew";
+const QByteArray DESCRIPTION  = QT_TRANSLATE_NOOP("description",
+                                "A Homebrewer's Recipe Calculator");
+const QByteArray COPYRIGHT    = QT_TRANSLATE_NOOP("copyright",
+                                "Copyright 1999-2007");
+const QByteArray AUTHOR       = "David Johnson";
+const QByteArray AUTHOR_EMAIL = "david@usermode.org";
+const QByteArray CONTRIBUTORS = "Lee Henderson, "
                                 "Rob Hudson, "
                                 "Abe Kabakoff, "
                                 "Stephen Lowrie, "
                                 "Michal Palczewski, "
-                                "Kevin Pullin";
+                                "Kevin Pullin, "
+                                "Tobias Toedter";
 
-const QString READY           = "Ready";
+const QByteArray READY        = QT_TRANSLATE_NOOP("message",
+                                "Ready");
 
 const QChar DEGREE            = QChar(0xB0);  // ISO 8859-1
 
 ///////////////////////////////////////////////////////////////////
 // file locations and stuff
 
-const QString FILE_EXT           = "qbrew";
-const QString FILE_FILTER        = "QBrew files (*.qbrew)";
-const QString TEXT_FILTER        = "Text files (*.txt)";
-const QString HTML_FILTER        = "HTML files (*.html *htm)";
-const QString BEERXML_FILTER     = "BeerXML recipes (*.xml)";
-const QString PDF_FILTER         = "PDF files (*.pdf)";
-const QString ALL_FILTER         = "All files (*)";
-const QString OPEN_FILTER        = FILE_FILTER + ";;"
-//                                 + BEERXML_FILTER + ";;"
-                                   + ALL_FILTER;
-const QString SAVE_FILTER        = FILE_FILTER + ";;"
-                                   + ALL_FILTER;
-const QString EXPORT_EXT         = "html";
-const QString EXPORT_FILTER      = HTML_FILTER + ";;"
+const QByteArray FILE_EXT        = PACKAGE;
+const QByteArray FILE_FILTER     = QT_TRANSLATE_NOOP("file filter",
+                                   "QBrew files (*.qbrew)");
+const QByteArray TEXT_FILTER     = QT_TRANSLATE_NOOP("file filter",
+                                   "Text files (*.txt)");
+const QByteArray HTML_FILTER     = QT_TRANSLATE_NOOP("file filter",
+                                   "HTML files (*.html *.htm)");
+const QByteArray BEERXML_FILTER  = QT_TRANSLATE_NOOP("file filter",
+                                   "BeerXML recipes (*.xml)");
+const QByteArray PDF_FILTER      = QT_TRANSLATE_NOOP("file filter",
+                                   "PDF files (*.pdf)");
+const QByteArray ALL_FILTER      = QT_TRANSLATE_NOOP("file filter",
+                                   "All files (*)");
+const QByteArray OPEN_FILTER     = QT_TRANSLATE_NOOP("file filter",
+                                   FILE_FILTER + ";;"
+                                   + BEERXML_FILTER + ";;"
+                                   + ALL_FILTER);
+const QByteArray SAVE_FILTER     = QT_TRANSLATE_NOOP("file filter",
+                                   FILE_FILTER + ";;"
+                                   + ALL_FILTER);
+const QByteArray EXPORT_FILTER   = QT_TRANSLATE_NOOP("file filter",
+                                   HTML_FILTER + ";;"
                                    + BEERXML_FILTER + ";;"
                                    + PDF_FILTER + ";;"
-                                   + TEXT_FILTER;
+                                   + TEXT_FILTER);
 
-const QString DATA_FILE           = "qbrewdata";
-const QString HELP_FILE          = "handbook-index.html";
-const QString PRIMER_FILE        = "primer.html";
-const QString DEFAULT_FILE       = "untitled";
+const QByteArray DATA_FILE       = "qbrewdata";
+const QByteArray HELP_FILE       = "handbook-index.html";
+const QByteArray PRIMER_FILE     = "primer.html";
+const QByteArray DEFAULT_FILE    = QT_TRANSLATE_NOOP("file name", "untitled");
 
 // previous valid data formats
-const QString RECIPE_PREVIOUS    = "0.1.7";
-const QString DATA_PREVIOUS      = "0.3.0";
+const QByteArray RECIPE_PREVIOUS = "0.1.7";
+const QByteArray DATA_PREVIOUS   = "0.3.0";
 
 ///////////////////////////////////////////////////////////////////
 // configuration strings
 
-const QString CONFGROUP_WINDOW      = "/window";
-const QString CONF_WIN_STATUSBAR    = "/statusbar";
-const QString CONF_WIN_MAINWINDOW   = "/mainwindow";
-const QString CONF_WIN_SIZE         = "/size";
+const QByteArray CONFGROUP_WINDOW      = "/window";
+const QByteArray CONF_WIN_STATUSBAR    = "/statusbar";
+const QByteArray CONF_WIN_MAINWINDOW   = "/mainwindow";
+const QByteArray CONF_WIN_SIZE         = "/size";
 
-const QString CONFGROUP_GENERAL     = "/general";
-const QString CONF_GEN_LOOK_FEEL    = "/lookfeel";
-const QString CONF_GEN_SHOW_SPLASH  = "/showsplash";
-const QString CONF_GEN_AUTOSAVE     = "/autosave";
-const QString CONF_GEN_SAVEINTERVAL = "/saveinterval";
-const QString CONF_GEN_AUTOBACKUP   = "/autobackup";
-const QString CONF_GEN_LOADLAST     = "/loadlast";
-const QString CONF_GEN_RECENTFILES  = "/recentfiles";
-const QString CONF_GEN_RECENTNUM    = "/recentnum";
+const QByteArray CONFGROUP_GENERAL     = "/general";
+const QByteArray CONF_GEN_LOOK_FEEL    = "/lookfeel";
+const QByteArray CONF_GEN_SHOW_SPLASH  = "/showsplash";
+const QByteArray CONF_GEN_AUTOSAVE     = "/autosave";
+const QByteArray CONF_GEN_SAVEINTERVAL = "/saveinterval";
+const QByteArray CONF_GEN_AUTOBACKUP   = "/autobackup";
+const QByteArray CONF_GEN_LOADLAST     = "/loadlast";
+const QByteArray CONF_GEN_RECENTFILES  = "/recentfiles";
+const QByteArray CONF_GEN_RECENTNUM    = "/recentnum";
 
-const QString CONFGROUP_RECIPE       = "/recipedefaults";
-const QString CONF_RECIPE_BATCH      = "/batch";
-const QString CONF_RECIPE_STYLE      = "/style";
-const QString CONF_RECIPE_HOPFORM    = "/hopform";
-const QString CONF_RECIPE_MASH       = "/mash";
+const QByteArray CONFGROUP_RECIPE       = "/recipedefaults";
+const QByteArray CONF_RECIPE_BATCH      = "/batch";
+const QByteArray CONF_RECIPE_STYLE      = "/style";
+ const QByteArray CONF_RECIPE_HOPFORM    = "/hopform"; // TODO: deprecated 0.4.0
+const QByteArray CONF_RECIPE_HOPTYPE    = "/hoptype";
 
-const QString CONFGROUP_CALC         = "/calc";
-const QString CONF_CALC_EFFICIENCY   = "/efficiency";
-const QString CONF_CALC_MOREY        = "/morey";
-const QString CONF_CALC_TINSETH      = "/tinseth";
-const QString CONF_CALC_UNITS        = "/units";
+const QByteArray CONFGROUP_CALC         = "/calc";
+const QByteArray CONF_CALC_STEEPYIELD   = "/steepyield";
+const QByteArray CONF_CALC_EFFICIENCY   = "/efficiency";
+const QByteArray CONF_CALC_MOREY        = "/morey";
+const QByteArray CONF_CALC_TINSETH      = "/tinseth";
+const QByteArray CONF_CALC_UNITS        = "/units";
 
 //////////////////////////////////////////////////////////////////////////////
-// XML Format Strings
+// XML Format Strings (need to be QString)
 
 const QString tagRecipe             = "recipe";
 const QString attrApplication       = "application";
@@ -137,7 +151,7 @@ const QString attrGenerator         = "generator";
 const QString tagTitle              = "title";
 const QString tagBrewer             = "brewer";
 const QString tagBatch              = "batch";
-const QString attrMash              = "mash";
+const QString attrEfficiency        = "efficiency";
 const QString tagNotes              = "notes";
 const QString attrClass             = "class";
 const QString classRecipe           = tagRecipe;
@@ -158,16 +172,18 @@ const QString attrSRMHigh           = "srmhigh";
 const QString tagGrains             = "grains";
 const QString tagGrain              = "grain";
 const QString attrQuantity          = "quantity";
+const QString attrSize              = "size"; // TODO: deprecated
 const QString attrExtract           = "extract";
 const QString attrColor             = "color";
+const QString attrType              = "type";
 const QString attrUse               = "use";
 const QString tagHops               = "hops";
 const QString tagHop                = "hop";
 const QString attrForm              = "form";
 const QString attrAlpha             = "alpha";
 const QString attrTime              = "time";
-const QString tagMiscIngredients    = "miscingredients"; // TODO: rename
-const QString tagMiscIngredient     = "miscingredient";
+const QString tagMiscs              = "miscingredients"; // TODO: rename
+const QString tagMisc               = "miscingredient";
 const QString attrNotes             = "notes";
 const QString tagUtilization        = "utilization";
 const QString tagEntry              = "entry";
@@ -195,6 +211,7 @@ const QString tagYEAST              = "YEAST";
 const QString tagMISCS              = "MISCS";
 const QString tagMISC               = "MISC";
 const QString tagNOTES              = "NOTES";
+const QString tagTASTENOTES         = "TASTE_NOTES";
 const QString tagWATERS             = "WATERS";
 
 const QString tagOGMIN              = "OG_MIN";
@@ -207,6 +224,7 @@ const QString tagCOLORMIN           = "COLOR_MIN";
 const QString tagCOLORMAX           = "COLOR_MAX";
 
 const QString tagAMOUNT             = "AMOUNT";
+const QString tagAMOUNTISWEIGHT     = "AMOUNT_IS_WEIGHT";
 const QString tagYIELD              = "YIELD";
 const QString tagCOLOR              = "COLOR";
 
@@ -215,24 +233,11 @@ const QString tagUSE                = "USE";
 const QString tagTIME               = "TIME";
 const QString tagFORM               = "FORM";
 
-const QString TYPE_EXTRACT          = "Extract";
-const QString TYPE_PARTIAL          = "Partial Mash";
-const QString TYPE_ALLGRAIN         = "All Grain";
-
 ///////////////////////////////////////////////////////////////////
 // Misc
 
-const QString UNIT_METRIC           = "Metric";
-const QString UNIT_US               = "US";
-
-const QString HOP_PELLET            = "pellet";
-const QString HOP_PLUG              = "plug";
-const QString HOP_WHOLE             = "whole";
-
-const QString GRAIN_EXTRACT         = "extract";
-const QString GRAIN_MASHED          = "mashed";
-const QString GRAIN_STEEPED         = "steeped";
-const QString GRAIN_OTHER           = "other";
+const QByteArray UNIT_METRIC        = QT_TRANSLATE_NOOP("units", "Metric");
+const QByteArray UNIT_US            = QT_TRANSLATE_NOOP("units", "US");
 
 }; // namespace Resource
 
