@@ -39,9 +39,6 @@
 
 class Style {
 public:
-    // fields (columns in view)
-    enum { NAME, OGLOW, OGHI, FGLOW, FGHI, IBULOW, IBUHI, SRMLOW, SRMHI, COUNT };
-
     // default constructor
     Style();
     // constructor
