@@ -15,8 +15,7 @@
 #include "data.h"
 #include "style.h"
 #include "styledelegate.h"
-
-const int extra = 1; // always display one extra blank row
+#include "stylemodel.h"
 
 StyleDelegate::StyleDelegate(QObject *parent) : QItemDelegate(parent) {}
 
@@ -32,19 +31,19 @@ QWidget *StyleDelegate::createEditor(QWidget *parent,
     QString suffix;
 
     // can only edit name on blank row
-    bool blank = index.row() >= index.model()->rowCount() - extra;
+    bool blank = index.row() >= index.model()->rowCount();
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Style::NAME:
+      case StyleModel::NAME:
           edit = new QLineEdit(parent);
           edit->installEventFilter(const_cast<StyleDelegate*>(this));
           return edit;
 
-      case Style::OGLOW:
-      case Style::OGHI:
-      case Style::FGLOW:
-      case Style::FGHI:
+      case StyleModel::OGLOW:
+      case StyleModel::OGHI:
+      case StyleModel::FGLOW:
+      case StyleModel::FGHI:
           if (blank) return 0;
           dspin = new QDoubleSpinBox(parent);
           dspin->setDecimals(3);
@@ -53,8 +52,8 @@ QWidget *StyleDelegate::createEditor(QWidget *parent,
           dspin->installEventFilter(const_cast<StyleDelegate*>(this));
           return dspin;
 
-      case Style::IBULOW:
-      case Style::IBUHI:
+      case StyleModel::IBULOW:
+      case StyleModel::IBUHI:
           if (blank) return 0;
           spin = new QSpinBox(parent);
           spin->setRange(0, 120);
@@ -62,8 +61,8 @@ QWidget *StyleDelegate::createEditor(QWidget *parent,
           spin->installEventFilter(const_cast<StyleDelegate*>(this));
           return spin;
 
-      case Style::SRMLOW:
-      case Style::SRMHI:
+      case StyleModel::SRMLOW:
+      case StyleModel::SRMHI:
           if (blank) return 0;
           spin = new QSpinBox(parent);
           spin->setRange(0, 50);
@@ -87,25 +86,25 @@ void StyleDelegate::setEditorData(QWidget *editor,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Style::NAME:
+      case StyleModel::NAME:
           edit = static_cast<QLineEdit*>(editor);
           if (!edit) return;
           edit->setText(value.toString());
           break;
 
-      case Style::OGLOW:
-      case Style::OGHI:
-      case Style::FGLOW:
-      case Style::FGHI:
+      case StyleModel::OGLOW:
+      case StyleModel::OGHI:
+      case StyleModel::FGLOW:
+      case StyleModel::FGHI:
           dspin = static_cast<QDoubleSpinBox*>(editor);
           if (!dspin) return;
           dspin->setValue(value.toDouble());
           break;
 
-      case Style::IBULOW:
-      case Style::IBUHI:
-      case Style::SRMLOW:
-      case Style::SRMHI:
+      case StyleModel::IBULOW:
+      case StyleModel::IBUHI:
+      case StyleModel::SRMLOW:
+      case StyleModel::SRMHI:
           spin = static_cast<QSpinBox*>(editor);
           if (!spin) return;
           spin->setValue(value.toUInt());
@@ -126,27 +125,27 @@ void StyleDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 
     // different kind of editor for each column
     switch (index.column()) {
-      case Style::NAME:
+      case StyleModel::NAME:
           edit = static_cast<QLineEdit*>(editor);
           if (!edit) return;
           value = edit->text();
           model->setData(index, value);
           break;
 
-      case Style::OGLOW:
-      case Style::OGHI:
-      case Style::FGLOW:
-      case Style::FGHI:
+      case StyleModel::OGLOW:
+      case StyleModel::OGHI:
+      case StyleModel::FGLOW:
+      case StyleModel::FGHI:
           dspin = static_cast<QDoubleSpinBox*>(editor);
           if (!dspin) return;
           value = dspin->value();
           model->setData(index, value);
           break;
 
-      case Style::IBULOW:
-      case Style::IBUHI:
-      case Style::SRMLOW:
-      case Style::SRMHI:
+      case StyleModel::IBULOW:
+      case StyleModel::IBUHI:
+      case StyleModel::SRMLOW:
+      case StyleModel::SRMHI:
           spin = static_cast<QSpinBox*>(editor);
           if (!spin) return;
           value = spin->value();
