@@ -14,6 +14,8 @@
 #include "data.h"
 #include "stylemodel.h"
 
+using namespace Resource;
+
 //////////////////////////////////////////////////////////////////////////////
 // StyleModel()
 // ------------
@@ -51,62 +53,62 @@ QVariant StyleModel::data(const QModelIndex &index, int role) const
     // column is the style "field"
     if (role == Qt::DisplayRole) {
         switch (index.column()) {
-          case Style::NAME:
+          case NAME:
               return style.name();
-          case Style::OGLOW:
+          case OGLOW:
               return QString::number(style.oglow_, 'f', 3);
-          case Style::OGHI:
+          case OGHI:
               return QString::number(style.oghi_, 'f', 3);
-          case Style::FGLOW:
+          case FGLOW:
               return QString::number(style.fglow_, 'f', 3);
-          case Style::FGHI:
+          case FGHI:
               return QString::number(style.fghi_, 'f', 3);
-          case Style::IBULOW:
+          case IBULOW:
               return QString::number(style.ibulow_);
-          case Style::IBUHI:
+          case IBUHI:
               return QString::number(style.ibuhi_);
-          case Style::SRMLOW:
+          case SRMLOW:
               return QString::number(style.srmlow_);
-          case Style::SRMHI:
+          case SRMHI:
               return QString::number(style.srmhi_);
           default:
               return QVariant();
         }
     } else if (role == Qt::EditRole) {
         switch (index.column()) {
-          case Style::NAME:
+          case NAME:
               return style.name();
-          case Style::OGLOW:
+          case OGLOW:
               return style.oglow_;
-          case Style::OGHI:
+          case OGHI:
               return style.oghi_;
-          case Style::FGLOW:
+          case FGLOW:
               return style.fglow_;
-          case Style::FGHI:
+          case FGHI:
               return style.fghi_;
-          case Style::IBULOW:
+          case IBULOW:
               return style.ibulow_;
-          case Style::IBUHI:
+          case IBUHI:
               return style.ibuhi_;
-          case Style::SRMLOW:
+          case SRMLOW:
               return style.srmlow_;
-          case Style::SRMHI:
+          case SRMHI:
               return style.srmhi_;
           default:
               return QVariant();
         }
     } else if (role == Qt::TextAlignmentRole) {
         switch (index.column()) {
-          case Style::NAME:
+          case NAME:
               return Qt::AlignLeft;
-          case Style::OGLOW:
-          case Style::OGHI:
-          case Style::FGLOW:
-          case Style::FGHI:
-          case Style::IBULOW:
-          case Style::IBUHI:
-          case Style::SRMLOW:
-          case Style::SRMHI:
+          case OGLOW:
+          case OGHI:
+          case FGLOW:
+          case FGHI:
+          case IBULOW:
+          case IBUHI:
+          case SRMLOW:
+          case SRMHI:
           default:
               return Qt::AlignRight;
         }
@@ -133,13 +135,13 @@ bool StyleModel::setData(const QModelIndex &index,
     if (!index.isValid()) return false;
     if (role != Qt::EditRole) return false;
     if ((row >= list_->count())
-        && (column != Style::NAME)) return false;
+        && (column != NAME)) return false;
 
     // grab existing style
     if (row < list_->count()) style = list_->value(row);
 
     switch (column) {
-      case Style::NAME:
+      case NAME:
           // editing name as several special cases
           name = value.toString();
 
@@ -166,35 +168,35 @@ bool StyleModel::setData(const QModelIndex &index,
           style.setName(name);
           break;
 
-      case Style::OGLOW:
+      case OGLOW:
           style.oglow_ = value.toDouble();
           break;
 
-      case Style::OGHI:
+      case OGHI:
           style.oghi_ = value.toDouble();
           break;
 
-      case Style::FGLOW:
+      case FGLOW:
           style.fglow_ = value.toDouble();
           break;
 
-      case Style::FGHI:
+      case FGHI:
           style.fghi_ = value.toDouble();
           break;
 
-      case Style::IBULOW:
+      case IBULOW:
           style.ibulow_ = value.toUInt();
           break;
 
-      case Style::IBUHI:
+      case IBUHI:
           style.ibuhi_ = value.toUInt();
           break;
 
-      case Style::SRMLOW:
+      case SRMLOW:
           style.srmlow_ = value.toUInt();
           break;
 
-      case Style::SRMHI:
+      case SRMHI:
           style.srmhi_ = value.toUInt();
           break;
 
@@ -206,8 +208,8 @@ bool StyleModel::setData(const QModelIndex &index,
     emit modified();
 
     // whole row may have changed
-    emit dataChanged(index.sibling(row, Style::NAME),
-                     index.sibling(row, Style::SRMHI));
+    emit dataChanged(index.sibling(row, NAME),
+                     index.sibling(row, SRMHI));
 
     return true;
 }
@@ -222,7 +224,7 @@ bool StyleModel::insertRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only insert one row at a time
     if ((row < 0) || (row >= list_->count())) row = list_->count();
 
-    Style style = Data::instance()->style("Generic");
+    Style style = Data::instance()->style(tr("Generic"));
 
     beginInsertRows(QModelIndex(), row, row);
     list_->insert(row, style);
@@ -241,10 +243,11 @@ bool StyleModel::removeRows(int row, int count, const QModelIndex&)
     if (count != 1) return false; // only remove one row at a time
     if ((row < 0) || (row >= list_->count())) return false;
 
-    if (QMessageBox::question(QApplication::activeWindow(),
-                              Resource::TITLE + " - Delete?",
-                              "Do you wish to remove this entry?",
-                              "Remove", "Cancel")) {
+    int status = QMessageBox::question(QApplication::activeWindow(),
+                               TITLE + tr(" - Delete?"),
+                               tr("Do you wish to remove this entry?"),
+                               QMessageBox::Yes | QMessageBox::Cancel);
+    if (status == QMessageBox::Cancel) {
         return false;
     }
 
@@ -265,24 +268,24 @@ QVariant StyleModel::headerData(int section, Qt::Orientation orientation,
 {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-          case Style::NAME:
-              return "Style";
-          case Style::OGLOW:
-              return "Min. OG";
-          case Style::OGHI:
-              return "Max. OG";
-          case Style::FGLOW:
-              return "Min. FG";
-          case Style::FGHI:
-              return "Max. FG";
-          case Style::IBULOW:
-              return "Min. IBU";
-          case Style::IBUHI:
-              return "Max. IBU";
-          case Style::SRMLOW:
-              return "Min. SRM";
-          case Style::SRMHI:
-              return "Max. SRM";
+          case NAME:
+              return tr("Style");
+          case OGLOW:
+              return tr("Min. OG");
+          case OGHI:
+              return tr("Max. OG");
+          case FGLOW:
+              return tr("Min. FG");
+          case FGHI:
+              return tr("Max. FG");
+          case IBULOW:
+              return tr("Min. IBU");
+          case IBUHI:
+              return tr("Max. IBU");
+          case SRMLOW:
+              return tr("Min. SRM");
+          case SRMHI:
+              return tr("Max. SRM");
            default:
               return QVariant();
         }
@@ -320,7 +323,7 @@ int StyleModel::rowCount(const QModelIndex &) const
 
 int StyleModel::columnCount(const QModelIndex &) const
 {
-    return Style::COUNT;
+    return COUNT;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -335,31 +338,31 @@ void StyleModel::sort(int column, Qt::SortOrder order)
     foreach(Style style, *list_) {
         QString field;
         switch (column) {
-          case Style::NAME:
+          case NAME:
               field = style.name();
               break;
-          case Style::OGLOW:
+          case OGLOW:
               field = QString::number(style.oglow_).rightJustified(6,'0');
               break;
-          case Style::OGHI:
+          case OGHI:
               field = QString::number(style.oghi_).rightJustified(6,'0');
               break;
-          case Style::FGLOW:
+          case FGLOW:
               field = QString::number(style.fglow_).rightJustified(6,'0');
               break;
-          case Style::FGHI:
+          case FGHI:
               field = QString::number(style.fghi_).rightJustified(6,'0');
               break;
-          case Style::IBULOW:
+          case IBULOW:
               field = QString::number(style.ibulow_).rightJustified(6,'0');
               break;
-          case Style::IBUHI:
+          case IBUHI:
               field = QString::number(style.ibuhi_).rightJustified(6,'0');
               break;
-          case Style::SRMLOW:
+          case SRMLOW:
               field = QString::number(style.srmlow_).rightJustified(6,'0');
               break;
-          case Style::SRMHI:
+          case SRMHI:
               field = QString::number(style.srmhi_).rightJustified(6,'0');
               break;
           default:
