@@ -42,6 +42,9 @@
 class StyleModel : public QAbstractTableModel {
     Q_OBJECT
 public:
+    // model columns
+    enum { NAME, OGLOW, OGHI, FGLOW, FGHI, IBULOW, IBUHI, SRMLOW, SRMHI, COUNT };
+
     StyleModel(QObject *parent, StyleList *list);
     ~StyleModel();
 
