@@ -9,6 +9,7 @@
 
 #include <QHeaderView>
 #include <QTableView>
+#include <QLocale>
 
 #include "data.h"
 #include "recipe.h"
@@ -41,6 +42,9 @@ View::View(QWidget *parent, Recipe *recipe)
     // get current font information
     QFont bold(font());
     bold.setBold(true);
+    QFontMetrics fm(font());
+    unsigned mh = (unsigned)(fm.lineSpacing() * 1.5);
+    unsigned mw = fm.width('M');
 
     // additional setup
     ui.ogreclabel->setFont(bold);
@@ -53,56 +57,77 @@ View::View(QWidget *parent, Recipe *recipe)
     ui.abv->setFont(bold);
     ui.abwlabel->setFont(bold);
     ui.abw->setFont(bold);
+    ui.fglabel->setFont(bold);
+    ui.fg->setFont(bold);
 
     // grain page
     QWidget *widget = new QWidget();
     grainpage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Grains");
+    ui.ingredients->addTab(widget, tr("&Grains"));
 
     grainmodel_ = new GrainModel(this, recipe_->grains());
     grainpage.view->setModel(grainmodel_);
     QItemDelegate *delegate = new GrainDelegate(this);
     grainpage.view->setItemDelegate(delegate);
 
+    grainpage.view->verticalHeader()->setDefaultSectionSize(mh);
     grainpage.view->verticalHeader()->hide();
     grainpage.view->horizontalHeader()->setClickable(true);
     grainpage.view->horizontalHeader()->setHighlightSections(false);
 
+    grainpage.view->setColumnWidth(GrainModel::NAME, 20*mw);
+    grainpage.view->setColumnWidth(GrainModel::WEIGHT, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::EXTRACT, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::COLOR, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::TYPE, 8*mw);
+    grainpage.view->setColumnWidth(GrainModel::USE, 8*mw);
+
     // hop page
     widget = new QWidget();
     hoppage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Hops");
+    ui.ingredients->addTab(widget, tr("&Hops"));
 
     hopmodel_ = new HopModel(this, recipe_->hops());
     hoppage.view->setModel(hopmodel_);
     delegate = new HopDelegate(this);
     hoppage.view->setItemDelegate(delegate);
 
+    hoppage.view->verticalHeader()->setDefaultSectionSize(mh);
     hoppage.view->verticalHeader()->hide();
     hoppage.view->horizontalHeader()->setClickable(true);
     hoppage.view->horizontalHeader()->setHighlightSections(false);
 
+    hoppage.view->setColumnWidth(HopModel::NAME, 20*mw);
+    hoppage.view->setColumnWidth(HopModel::WEIGHT, 8*mw);
+    hoppage.view->setColumnWidth(HopModel::ALPHA, 8*mw);
+    hoppage.view->setColumnWidth(HopModel::TIME, 8*mw);
+    hoppage.view->setColumnWidth(HopModel::TYPE, 8*mw);
+
     // misc page
     widget = new QWidget();
     miscpage.setupUi(widget);
-    ui.ingredients->addTab(widget, "&Miscellaneous");
+    ui.ingredients->addTab(widget, tr("&Miscellaneous"));
 
     miscmodel_ = new MiscModel(this, recipe_->miscs());
     miscpage.view->setModel(miscmodel_);
     delegate = new MiscDelegate(this);
     miscpage.view->setItemDelegate(delegate);
 
+    miscpage.view->verticalHeader()->setDefaultSectionSize(mh);
     miscpage.view->verticalHeader()->hide();
     miscpage.view->horizontalHeader()->setClickable(true);
     miscpage.view->horizontalHeader()->setHighlightSections(false);
 
+    miscpage.view->setColumnWidth(MiscModel::NAME, 20*mw);
+    miscpage.view->setColumnWidth(MiscModel::QUANTITY, 8*mw);
+    miscpage.view->setColumnWidth(MiscModel::TYPE, 8*mw);
+    miscpage.view->horizontalHeader()->setStretchLastSection(true);
+
     // note page
     notepage_ = new NotePage(0, recipe_);
-    ui.ingredients->addTab(notepage_, "&Notes");
+    ui.ingredients->addTab(notepage_, tr("&Notes"));
 
     // widget connections
-    connect(grainmodel_, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-            grainpage.view, SLOT(resizeRowsToContents()));
     connect(grainmodel_, SIGNAL(modified()),
             this, SLOT(modelModified()));
     connect(grainpage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -112,8 +137,6 @@ View::View(QWidget *parent, Recipe *recipe)
     connect(grainpage.removebutton, SIGNAL(clicked()),
             grainpage.view, SLOT(removeIngredient()));
 
-    connect(hopmodel_, SIGNAL(rowsInserted (const QModelIndex&, int, int)),
-            hoppage.view, SLOT(resizeRowsToContents()));
     connect(hopmodel_, SIGNAL(modified()),
             this, SLOT(modelModified()));
     connect(hoppage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -123,8 +146,6 @@ View::View(QWidget *parent, Recipe *recipe)
     connect(hoppage.removebutton, SIGNAL(clicked()),
             hoppage.view, SLOT(removeIngredient()));
 
-    connect(miscmodel_, SIGNAL(rowsInserted (const QModelIndex&, int, int)),
-            miscpage.view, SLOT(resizeRowsToContents()));
     connect(miscmodel_, SIGNAL(modified()),
             this, SLOT(modelModified()));
     connect(miscpage.view->horizontalHeader(), SIGNAL(sectionClicked(int)),
@@ -142,8 +163,6 @@ View::View(QWidget *parent, Recipe *recipe)
             this, SLOT(setBrewer(const QString &)));
     connect(ui.sizespin, SIGNAL(valueChanged(double)),
             this, SLOT(setSize(double)));
-    connect(ui.mashcheck, SIGNAL(toggled(bool)),
-            this, SLOT(setMash(bool)));
 
     connect(recipe_, SIGNAL(recipeChanged()), this, SLOT(flush()));
     connect(recipe_, SIGNAL(recipeModified()), this, SLOT(refresh()));
@@ -198,16 +217,6 @@ void View::setSize(double size)
     recipe_->setSize(Volume(size, recipe_->size().unit()));
 }
 
-//////////////////////////////////////////////////////////////////////////////
-// setMash()
-// ---------------------
-// set mashed / unmashed
-
-void View::setMash(bool mash)
-{
-    recipe_->setMashed(mash);
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 // Miscellaneous                                                             //
 ///////////////////////////////////////////////////////////////////////////////
@@ -239,9 +248,7 @@ void View::flush()
     ui.breweredit->setText(recipe_->brewer());
 
     ui.sizespin->setValue(recipe_->size().amount());
-
     ui.sizespin->setSuffix(" " + recipe_->size().unit().name());
-    ui.mashcheck->setChecked(recipe_->mashed());
 
     // set style combo to style
     ui.stylecombo->clear();
@@ -263,31 +270,9 @@ void View::flush()
 
     // reset ingredient views
     grainmodel_->flush();
-    grainpage.view->resizeRowsToContents();
     hopmodel_->flush();
-    hoppage.view->resizeRowsToContents();
     miscmodel_->flush();
-    miscpage.view->resizeRowsToContents();
     notepage_->refresh();
-
-    QFontMetrics fm(font());
-    unsigned mw = fm.width('M');
-
-    grainpage.view->setColumnWidth(Grain::NAME, 20*mw);
-    grainpage.view->setColumnWidth(Grain::QUANTITY, 8*mw);
-    grainpage.view->setColumnWidth(Grain::EXTRACT, 8*mw);
-    grainpage.view->setColumnWidth(Grain::COLOR, 8*mw);
-    grainpage.view->setColumnWidth(Grain::USE, 8*mw);
-
-    hoppage.view->setColumnWidth(Hop::NAME, 20*mw);
-    hoppage.view->setColumnWidth(Hop::QUANTITY, 8*mw);
-    hoppage.view->setColumnWidth(Hop::ALPHA, 8*mw);
-    hoppage.view->setColumnWidth(Hop::TIME, 8*mw);
-    hoppage.view->setColumnWidth(Hop::FORM, 8*mw);
-
-    miscpage.view->setColumnWidth(Misc::NAME, 20*mw);
-    miscpage.view->setColumnWidth(Misc::QUANTITY, 8*mw);
-    miscpage.view->horizontalHeader()->setStretchLastSection(true);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -298,24 +283,28 @@ void View::flush()
 void View::refresh()
 {
     const Style &style = recipe_->style();
+    QLocale locale = QLocale::system();
 
     // beer style has changed, so update labels in stylelayout_
-    ui.stylebox->setTitle(QString("%1 characteristics")
+    ui.stylebox->setTitle(tr("%1 characteristics",
+                             "Beer style characteristics, e.g. Generic ale")
                           .arg(ui.stylecombo->currentText()));
 
-    ui.ogmin->setText(QString::number(style.OGLow(), 'f', 3));
-    ui.ogmax->setText(QString::number(style.OGHi(), 'f', 3));
-    ui.ogrec->setText(QString::number(recipe_->OG(), 'f', 3));
+    ui.ogmin->setText(locale.toString(style.OGLow(), 'f', 3));
+    ui.ogmax->setText(locale.toString(style.OGHi(), 'f', 3));
+    ui.ogrec->setText(locale.toString(recipe_->OG(), 'f', 3));
 
-    ui.ibumin->setText(QString::number(style.IBULow()));
-    ui.ibumax->setText(QString::number(style.IBUHi()));
-    ui.iburec->setText(QString::number(recipe_->IBU()));
+    ui.ibumin->setText(locale.toString(style.IBULow()));
+    ui.ibumax->setText(locale.toString(style.IBUHi()));
+    ui.iburec->setText(locale.toString(recipe_->IBU()));
 
-    ui.srmmin->setText(QString::number(style.SRMLow()) + Resource::DEGREE);
-    ui.srmmax->setText(QString::number(style.SRMHi()) + Resource::DEGREE);
-    ui.srmrec->setText(QString::number(recipe_->SRM()) + Resource::DEGREE);
+    ui.srmmin->setText(locale.toString(style.SRMLow()) + Resource::DEGREE);
+    ui.srmmax->setText(locale.toString(style.SRMHi()) + Resource::DEGREE);
+    ui.srmrec->setText(locale.toString(recipe_->SRM()) + Resource::DEGREE);
 
-    ui.fg->setText(QString::number(recipe_->FGEstimate(), 'f', 3));
-    ui.abv->setText(QString::number(recipe_->ABV() * 100.0, 'f', 1) + "%");
-    ui.abw->setText(QString::number(recipe_->ABW() * 100.0, 'f', 1) + "%");
+    ui.fg->setText(locale.toString(recipe_->FGEstimate(), 'f', 3));
+    ui.abv->setText(QString(tr("%1%"))
+                    .arg(locale.toString(recipe_->ABV() * 100.0, 'f', 1)));
+    ui.abw->setText(QString(tr("%1%"))
+                    .arg(locale.toString(recipe_->ABW() * 100.0, 'f', 1)));
 }
