@@ -61,8 +61,6 @@ public slots:
     void setBrewer(const QString &brewer);
     // set the recipe size
     void setSize(double size);
-    // set mashed / unmashed
-    void setMash(bool mash);
 
     // model has been modified
     void modelModified();
@@ -82,9 +80,6 @@ private:
     HopModel *hopmodel_;
     MiscModel *miscmodel_;
 
-    QTableView *hopview_;
-    QTableView *miscview_;
-
     NotePage *notepage_;
 };
 
